@@ -31,32 +31,33 @@ html_start_box(__('About Cacti'), '100%', '', '3', 'center', '');
 ?>
 
 <tr class='tableHeader'>
-	<td class='tableSubHeaderColumn' colspan="2">
-		<font class='textSubHeaderDark'><?php print __('Version %s', CACTI_VERSION); ?></font>
+	<td class='tableSubHeaderColumn' colspan='2'>
+		<font class='textSubHeaderDark'><?php print get_cacti_version_text(); ?></font>
 	</td>
 </tr>
 <tr>
-	<td valign="top" class="odd" class="textArea">
-		<div style='float:right;'><a href="http://www.cacti.net/"><img align="right" src="images/cacti_about_logo.gif" alt="raXnet"></a></div>
-		
+	<td valign='top' class='odd' class='textArea'>
+		<div style='float:right;'><a href='http://www.cacti.net/'><img class='right' src='images/cacti_about_logo.gif' alt='raXnet'></a></div>
+
 		<p><?php print __('Cacti is designed to be a complete graphing solution based on the RRDtool\'s framework. Its goal is to make a network administrator\'s job easier by taking care of all the necessary details necessary to create meaningful graphs.'); ?></p>
 
 		<p><?php print __('Please see the official %sCacti website%s for information, support, and updates.', '<a href="http://www.cacti.net/?version=' . CACTI_VERSION . '">', '</a>'); ?></p>
 
 		<p><strong><?php print __('Cacti Developers'); ?></strong><br>
-		<ul type="disc">
+		<ul type='disc'>
 			<li>Ian Berry <i>(raX)</i></li>
 			<li>Larry Adams <i>(TheWitness)</i></li>
 			<li>Tony Roman <i>(rony)</i></strong></li>
 			<li>J.P. Pasnak, CD <i>(Linegod)</i></strong></li>
-			<li>Jimmy Conner<i>(cigamit)</i></li>
-			<li>Reinhard Scheck<i>(gandalf)</i></li>
-			<li>Andreas Braun<i>(browniebraun)</i></li>
+			<li>Jimmy Conner <i>(cigamit)</i></li>
+			<li>Reinhard Scheck <i>(gandalf)</i></li>
+			<li>Andreas Braun <i>(browniebraun)</i></li>
+			<li>Mark Brugnoli-Vinten <i>(netniV)</i></li>
 		</ul>
 		</p>
 
 		<p><strong><?php print __('Thanks'); ?></a></strong><br>
-		<ul type="disc">
+		<ul type='disc'>
 			<li>
 				<?php print __('A very special thanks to %sTobi Oetiker%s, the creator of %sRRDtool%s and the very popular %sMRTG%s.', '<a href="http://tobi.oetiker.ch/"><strong>', '</strong></a>', '<a href="http://www.rrdtool.org/">', '</a>', '<a href="http://www.rrdtool.org">', '</a>'); ?>
 			</li>
