@@ -23,21 +23,24 @@
 */
 
 include('./include/auth.php');
-include_once('./lib/utility.php');
 include_once('./lib/api_graph.php');
 include_once('./lib/api_tree.php');
 include_once('./lib/api_data_source.php');
 include_once('./lib/api_aggregate.php');
-include_once('./lib/template.php');
+include_once('./lib/data_query.php');
 include_once('./lib/html_tree.php');
 include_once('./lib/html_form_template.php');
+include_once('./lib/poller.php');
+include_once('./lib/reports.php');
 include_once('./lib/rrd.php');
-include_once('./lib/data_query.php');
+include_once('./lib/template.php');
+include_once('./lib/utility.php');
 
 aggregate_prune_graphs();
 
 $graph_actions = array(
 	1 => __('Delete'),
+	4 => __('Place Graphs on Report'),
 	2 => __('Migrate Aggregate to use a Template'),
 	3 => __('Create New Aggregate from Aggregates')
 );
@@ -75,7 +78,7 @@ function add_tree_names_to_actions_array() {
 	/* add a list of tree names to the actions dropdown */
 	$trees = db_fetch_assoc('SELECT id,name FROM graph_tree ORDER BY name');
 
-	if (sizeof($trees)) {
+	if (cacti_sizeof($trees)) {
 		foreach ($trees as $tree) {
 			$graph_actions['tr_' . $tree['id']] = __('Place on a Tree (%s)', $tree['name']);
 		}
@@ -268,6 +271,19 @@ function form_actions() {
 			} elseif (get_request_var('drp_action') == '3') { // create aggregate from aggregate
 				$aggregate_name = get_request_var('aggregate_name');
 				api_aggregate_create($aggregate_name, $selected_items);
+			} elseif (get_request_var('drp_action') == '4') { // add graphs to report
+                $good = true;
+                for ($i=0;($i<cacti_count($selected_items));$i++) {
+                    if (!reports_add_graphs(get_filter_request_var('report_id'), $selected_items[$i], get_request_var('timespan'), get_request_var('align'))) {
+                        raise_message('reports_add_error');
+                        $good = false;
+                        break;
+                    }
+                }
+
+                if ($good) {
+                    raise_message('reports_graphs_added');
+                }
 			} elseif (get_request_var('drp_action') == '10') { // associate with aggregate
 				api_aggregate_associate($selected_items);
 			} elseif (get_request_var('drp_action') == '11') { // dis-associate with aggregate
@@ -275,8 +291,8 @@ function form_actions() {
 			} elseif (preg_match('/^tr_([0-9]+)$/', get_request_var('drp_action'), $matches)) { // place on tree
 				get_filter_request_var('tree_id');
 				get_filter_request_var('tree_item_id');
-				for ($i=0;($i<count($selected_items));$i++) {
-					api_tree_item_save(0, get_nfilter_request_var('tree_id'), TREE_ITEM_TYPE_GRAPH, get_nfilter_request_var('tree_item_id'), '', $selected_items[$i], 0, 0, 0, false);
+				for ($i=0;($i<cacti_count($selected_items));$i++) {
+					api_tree_item_save(0, get_nfilter_request_var('tree_id'), TREE_ITEM_TYPE_GRAPH, get_nfilter_request_var('tree_item_id'), '', $selected_items[$i], 0, 0, 0, 0, false);
 				}
 			}
 		}
@@ -295,7 +311,7 @@ function form_actions() {
 			input_validate_input_number($matches[1]);
 			/* ==================================================== */
 
-			$graph_list .= '<li>' . get_graph_title($matches[1]) . '</li>';
+			$graph_list .= '<li>' . html_escape(get_graph_title($matches[1])) . '</li>';
 			$graph_array[$i] = $matches[1];
 
 			$i++;
@@ -311,7 +327,7 @@ function form_actions() {
 
 	html_start_box($graph_actions{get_request_var('drp_action')}, '60%', '', '3', 'center', '');
 
-	if (isset($graph_array) && sizeof($graph_array)) {
+	if (isset($graph_array) && cacti_sizeof($graph_array)) {
 		if (get_request_var('drp_action') == '1') { // delete
 			print "<tr>
 				<td class='textArea'>
@@ -320,7 +336,7 @@ function form_actions() {
 				</td>
 			</tr>\n";
 
-			$save_html = "<input type='button' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __esc('Continue') . "' title='" . __esc('Delete Graph(s)') . "'>";
+			$save_html = "<input type='button' class='ui-button ui-corner-all ui-widget' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' class='ui-button ui-corner-all ui-widget' value='" . __esc('Continue') . "' title='" . __esc('Delete Graph(s)') . "'>";
 		} elseif (get_request_var('drp_action') == '2') { // migrate to aggregate
 			/* determine the common graph template if any */
 			foreach ($_POST as $var => $val) {
@@ -343,7 +359,7 @@ function form_actions() {
 				FROM graph_templates_item
 				WHERE task_item_id IN ($task_items) AND graph_template_id>0");
 
-			if (sizeof($graph_templates) > 1) {
+			if (cacti_sizeof($graph_templates) > 1) {
 				print "<tr>
 					<td class='textArea'>
 						<p>" . __('The selected Aggregate Graphs represent elements from more than one Graph Template.') . "</p>
@@ -352,7 +368,7 @@ function form_actions() {
 					</td>
 				</tr>\n";
 
-				$save_html = "<input type='button' value='" . __esc('Return') . "' onClick='cactiReturnTo()'>";
+				$save_html = "<input type='button' class='ui-button ui-corner-all ui-widget' value='" . __esc('Return') . "' onClick='cactiReturnTo()'>";
 			} else {
 				$graph_template      = $graph_templates[0]['graph_template_id'];
 
@@ -362,7 +378,7 @@ function form_actions() {
 					ORDER BY name',
 					array($graph_template));
 
-				if (sizeof($aggregate_templates)) {
+				if (cacti_sizeof($aggregate_templates)) {
 					print "<tr>
 						<td class='textArea' colspan='2'>
 							<p>" . __('Click \'Continue\' and the following Aggregate Graph(s) will be migrated to use the Aggregate Template that you choose below.') . "</p>
@@ -381,7 +397,7 @@ function form_actions() {
 						</td>
 					</tr>\n";
 
-					$save_html = "<tr><td colspan='2' align='right'><input type='button' value='" . __esc('Cancel'). "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __esc('Continue') . "' title='" . __esc('Delete Graph(s)') . "'></td></tr>";
+					$save_html = "<tr><td colspan='2' class='right'><input type='button' class='ui-button ui-corner-all ui-widget' value='" . __esc('Cancel'). "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' class='ui-button ui-corner-all ui-widget' value='" . __esc('Continue') . "' title='" . __esc('Delete Graph(s)') . "'></td></tr>";
 				} else {
 					print "<tr>
 						<td class='textArea'>
@@ -392,7 +408,7 @@ function form_actions() {
 						</td>
 					</tr>\n";
 
-					$save_html = "<input type='button' value='" . __esc('Return') . "' onClick='cactiReturnTo()'>";
+					$save_html = "<input type='button' class='ui-button ui-corner-all ui-widget' value='" . __esc('Return') . "' onClick='cactiReturnTo()'>";
 				}
 			}
 		} elseif (get_request_var('drp_action') == '3') { // create aggregate from aggregates
@@ -404,9 +420,42 @@ function form_actions() {
 			</tr>\n";
 
 			print "	<tr><td class='textArea' width='170'>" . __('Aggregate Name:') . "</td></tr>\n";
-			print "	<tr><td class='textArea'><input name='aggregate_name' size='40' value='" . __esc('New Aggregate') . "'></td></tr>\n";
+			print "	<tr><td class='textArea'><input type='text' class='ui-state-default ui-corner-all' name='aggregate_name' size='40' value='" . __esc('New Aggregate') . "'></td></tr>\n";
 
-			$save_html = "<input type='button' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __esc('Continue') . "' title='" . __esc('Delete Graph(s)') . "'>";
+			$save_html = "<input type='button' class='ui-button ui-corner-all ui-widget' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' class='ui-button ui-corner-all ui-widget' value='" . __esc('Continue') . "' title='" . __esc('Delete Graph(s)') . "'>";
+		} elseif (get_request_var('drp_action') == '4') {
+			global $alignment, $graph_timespans;
+
+			$reports = db_fetch_assoc_prepared('SELECT id, name
+				FROM reports
+				WHERE user_id = ?
+				ORDER BY name',
+				array($_SESSION['sess_user_id']));
+
+			if (cacti_sizeof($reports)) {
+				print "<tr>
+					<td class='textArea'>
+						<p>" . __('Click \'Continue\' to add the selected Graphs to the Report below.') . "</p>
+						<div class='itemlist'><ul>$graph_list</ul></div>
+					</td>
+				</tr>
+				<tr><td>" . __('Report Name') . '<br>';
+				form_dropdown('report_id', $reports, 'name', 'id', '', '', '0');
+				print '</td></tr>';
+
+				print '<tr><td>' . __('Timespan') . '<br>';
+				form_dropdown('timespan',$graph_timespans, '', '', '', '', read_user_setting('default_timespan'));
+				print '</td></tr>';
+
+				print '<tr><td>' . __('Align') . '<br>';
+				form_dropdown('align',$alignment, '', '', '', '', REPORTS_ALIGN_CENTER);
+				print "</td></tr>\n";
+
+				$save_html = "<input type='button' class='ui-button ui-corner-all ui-widget' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' class='ui-button ui-corner-all ui-widget' value='" . __esc('Continue') . "' title='" . __esc('Add Graphs to Report') . "'>";
+			} else {
+				print "<tr><td class='even'><span class='textError'>" . __('You currently have no reports defined.') . "</span></td></tr>\n";
+				$save_html = "<input type='button' class='ui-button ui-corner-all ui-widget' value='" . __esc('Return') . "' onClick='cactiReturnTo()'>";
+			}
 		} elseif (get_request_var('drp_action') == '10') { // associate with aggregate
 			print "<tr>
 				<td class='textArea'>
@@ -415,7 +464,7 @@ function form_actions() {
 				</td>
 			</tr>\n";
 
-			$save_html = "<input type='button' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __esc('Continue') . "' title='" . __esc('Associate Graph(s)') . "'>";
+			$save_html = "<input type='button' class='ui-button ui-corner-all ui-widget' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' class='ui-button ui-corner-all ui-widget' value='" . __esc('Continue') . "' title='" . __esc('Associate Graph(s)') . "'>";
 		} elseif (get_request_var('drp_action') == '11') { // dis-associate with aggregate
 			print "<tr>
 				<td class='textArea'>
@@ -424,7 +473,7 @@ function form_actions() {
 				</td>
 			</tr>\n";
 
-			$save_html = "<input type='button' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __esc('Continue') . "' title='" . __esc('Dis-Associate Graph(s)') . "'>";
+			$save_html = "<input type='button' class='ui-button ui-corner-all ui-widget' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' class='ui-button ui-corner-all ui-widget' value='" . __esc('Continue') . "' title='" . __esc('Dis-Associate Graph(s)') . "'>";
 		} elseif (preg_match("/^tr_([0-9]+)$/", get_request_var('drp_action'), $matches)) { // place on tree
 			print "<tr>
 				<td class='textArea'>
@@ -433,13 +482,14 @@ function form_actions() {
 					<p>" . __('Destination Branch:') . "<br>"; grow_dropdown_tree($matches[1], '0', 'tree_item_id', '0'); print "</p>
 				</td>
 			</tr>\n
-			<input type='hidden' name='tree_id' value='" . $matches[1] . "'>\n";
+			<input type='hidden' name='tree_id' value='" . html_escape($matches[1]) . "'>\n";
 
-			$save_html = "<input type='button' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __esc('Continue') . "' title='" . __esc('Place Graph(s) on Tree') . "'>";
+			$save_html = "<input type='button' class='ui-button ui-corner-all ui-widget' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' class='ui-button ui-corner-all ui-widget' value='" . __esc('Continue') . "' title='" . __esc('Place Graph(s) on Tree') . "'>";
 		}
 	} else {
-		print "<tr><td class='even'><span class='textError'>" . __('You must select at least one graph.') . "</span></td></tr>\n";
-		$save_html = "<input type='button' value='" . __esc('Return') . "' onClick='cactiReturnTo()'>";
+		raise_message(40);
+		header('Location: aggregate_graphs.php?header=false');
+		exit;
 	}
 
 	print "	<tr>
@@ -551,7 +601,7 @@ function graph_edit() {
 		$header_label = '[edit: ' . html_escape(get_graph_title(get_request_var('id'))) . ']';
 	}
 
-	if (sizeof($aginfo)) {
+	if (cacti_sizeof($aginfo)) {
 		if ($aginfo['aggregate_template_id'] > 0) {
 			$template = db_fetch_row_prepared('SELECT *
 				FROM aggregate_graph_templates
@@ -606,7 +656,7 @@ function graph_edit() {
 	print "<div class='aggtabs'><nav><ul role='tablist'>\n";
 
 	$i = 0;
-	if (sizeof($aggregate_tabs)) {
+	if (cacti_sizeof($aggregate_tabs)) {
 		foreach (array_keys($aggregate_tabs) as $tab_short_name) {
 			if ($tab_short_name == 'details' || (!isempty_request_var('id'))) {
 				print "<li class='subTab'><a class='tab " . ($tab_short_name == $current_tab ? "selected'" : "'") .
@@ -635,7 +685,7 @@ function graph_edit() {
 
 	if (!isempty_request_var('id') && $current_tab == 'preview') {
 		print "<ul style='float:right;'><li><a class='pic' href='" . html_escape('aggregate_graphs.php?action=edit&id=' . get_request_var('id') . '&tab=' . get_request_var('tab') .  '&debug=' . (isset($_SESSION['graph_debug_mode']) ? '0' : '1')) . "'>" . $message . "</a></li></ul></nav>\n</div></div>\n";
-	} elseif (!isempty_request_var('id') && $current_tab == 'details' && (!sizeof($template))) {
+	} elseif (!isempty_request_var('id') && $current_tab == 'details' && (!cacti_sizeof($template))) {
 		print "<ul style='float:right;'><li><a id='toggle_items' class='pic' href='#'>" . __('Show Item Details') . "</a></li></ul></nav>\n</div></div>\n";
 	} else {
 		print "</nav></div></div>\n";
@@ -678,7 +728,7 @@ function graph_edit() {
 
 	/* we will show the templated representation only when when there is a template and propagation is enabled */
 	if (!isempty_request_var('id') && $current_tab == 'details') {
-		if (sizeof($template)) {
+		if (cacti_sizeof($template)) {
 			print "<div id='templated'>";
 
 			html_start_box(__('Aggregate Graph %s', $header_label), '100%', true, '3', 'center', '');
@@ -840,7 +890,7 @@ function graph_edit() {
 		<?php
 
 		/* graph item list goes here */
-		if (empty($graphs['graph_template_id']) && sizeof($template) == 0) {
+		if (empty($graphs['graph_template_id']) && cacti_sizeof($template) == 0) {
 			item();
 		}
 
@@ -879,7 +929,7 @@ function graph_edit() {
 
 		form_hidden_box('save_component_graph','1','');
 		form_hidden_box('save_component_input','1','');
-		form_hidden_box('rrdtool_version', read_config_option('rrdtool_version'), '');
+		form_hidden_box('rrdtool_version', get_rrdtool_version(), '');
 		form_save_button($referer, 'return', 'id');
 
 		echo '</div>';
@@ -907,7 +957,7 @@ function graph_edit() {
 		function dynamic() {
 			if ($('#scale_log_units')) {
 				$('#scale_log_units').prop('disabled', true);
-				if (($('#rrdtool_version').val() != 'rrd-1.0.x') &&
+				if (($('#rrdtool_version').val() != '1.0.0') &&
 					($('#auto_scale_log').is(':checked'))) {
 					$('#scale_log_units').prop('disabled', true);
 				}
@@ -917,7 +967,7 @@ function graph_edit() {
 		function changeScaleLog() {
 			if ($('#scale_log_units')) {
 				$('#scale_log_units').prop('disabled', true);
-				if (($('#rrdtool_version').val() != 'rrd-1.0.x') &&
+				if (($('#rrdtool_version').val() != '1.0.0') &&
 					($('#auto_scale_log').is(':checked'))) {
 					$('#scale_log_units').prop('disabled', false);
 				}
@@ -1029,7 +1079,7 @@ function aggregate_items() {
 						<?php print __('Search');?>
 					</td>
 					<td>
-						<input type='text' id='rfilter' size='45' onChange='applyFilter()' value='<?php print get_request_var('rfilter');?>'>
+						<input type='text' class='ui-state-default ui-corner-all' id='rfilter' size='45' onChange='applyFilter()' value='<?php print get_request_var('rfilter');?>'>
 					</td>
 					<td>
 						<?php print __('Graphs');?>
@@ -1038,7 +1088,7 @@ function aggregate_items() {
 						<select id='rows' onChange='applyFilter()'>
 							<option value='-1'<?php print (get_request_var('rows') == '-1' ? ' selected>':'>') . __('Default');?></option>
 							<?php
-							if (sizeof($item_rows) > 0) {
+							if (cacti_sizeof($item_rows) > 0) {
 								foreach ($item_rows as $key => $value) {
 									print "<option value='" . $key . "'"; if (get_request_var('rows') == $key) { print ' selected'; } print '>' . html_escape($value) . "</option>\n";
 								}
@@ -1054,8 +1104,8 @@ function aggregate_items() {
 					</td>
 					<td>
 						<span>
-							<input id='refresh' type='button' value='<?php print __esc('Go');?>' title='<?php print __esc('Set/Refresh Filters');?>'>
-							<input id='clear' type='button' onClick='clearFilter()' value='<?php print __esc('Clear');?>' title='<?php print __esc('Clear Filters');?>'>
+							<input type='button' class='ui-button ui-corner-all ui-widget' id='refresh' value='<?php print __esc('Go');?>' title='<?php print __esc('Set/Refresh Filters');?>'>
+							<input type='button' class='ui-button ui-corner-all ui-widget' id='clear' onClick='clearFilter()' value='<?php print __esc('Clear');?>' title='<?php print __esc('Clear Filters');?>'>
 						</span>
 					</td>
 				</tr>
@@ -1141,7 +1191,7 @@ function aggregate_items() {
 
 	html_header_sort_checkbox($display_text, get_request_var('sort_column'), get_request_var('sort_direction'), false, 'aggregate_graphs.php?action=edit&id=' . get_request_var('id'));
 
-	if (sizeof($graph_list) > 0) {
+	if (cacti_sizeof($graph_list) > 0) {
 		foreach ($graph_list as $graph) {
 			/* we're escaping strings here, so no need to escape them on form_selectable_cell */
 			form_alternate_row('line' . $graph['local_graph_id'], true);
@@ -1149,12 +1199,12 @@ function aggregate_items() {
 			if (validate_is_regex(get_request_var('rfilter'))) {
 				form_selectable_cell(filter_value($graph['title_cache'], get_request_var('rfilter')), $graph['local_graph_id']);
 			} else {
-				form_selectable_cell(get_request_var('rfilter') != '' ? aggregate_format_text(html_escape($graph['title_cache']), get_request_var('rfilter')) : html_escape($graph['title_cache']), $graph['local_graph_id']);
+				form_selectable_ecell(get_request_var('rfilter') != '' ? aggregate_format_text($graph['title_cache'], get_request_var('rfilter')) : $graph['title_cache'], $graph['local_graph_id']);
 			}
 
 			form_selectable_cell($graph['local_graph_id'], $graph['local_graph_id'], '', 'right');
 			form_selectable_cell(($graph['agg_graph_id'] != '' ? "<span class='associated'>" . __('Yes') . '</span>':"<span class='notAssociated'>" . __('No') . "</span>"), $graph['local_graph_id']);
-			form_selectable_cell($graph['height'] . 'x' . $graph['width'], $graph['local_graph_id'], '', 'right');
+			form_selectable_ecell($graph['height'] . 'x' . $graph['width'], $graph['local_graph_id'], '', 'right');
 			form_checkbox_cell($graph['title_cache'], $graph['local_graph_id']);
 			form_end_row();
 		}
@@ -1188,7 +1238,7 @@ function aggregate_make_sql_where($sql_where, $items, $field) {
 	$indentation = 0;
 	$termcount   = 0;
 
-	if (sizeof($items)) {
+	if (cacti_sizeof($items)) {
 		foreach($items as $i) {
 			$i = trim($i);
 			while (substr($i,0,1) == '(') {
@@ -1251,7 +1301,7 @@ function aggregate_format_text($text, $filter) {
 		}
 	}
 
-	if (sizeof($tags)) {
+	if (cacti_sizeof($tags)) {
 		foreach($tags as $k => $t) {
 			$text = str_replace("<<$k>>", "<span class='filteredValue'>" . html_escape($t) . "</span>", $text);
 		}
@@ -1357,7 +1407,7 @@ function aggregate_graph() {
 						<?php print __('Search');?>
 					</td>
 					<td>
-						<input type='text' id='filter' size='25' value='<?php print get_request_var('filter');?>'>
+						<input type='text' class='ui-state-default ui-corner-all' id='filter' size='25' value='<?php print get_request_var('filter');?>'>
 					</td>
 					<td>
 						<?php print __('Template');?>
@@ -1373,7 +1423,7 @@ function aggregate_graph() {
 								ON ag.aggregate_template_id=at.id
 								ORDER BY name');
 
-							if (sizeof($templates) > 0) {
+							if (cacti_sizeof($templates) > 0) {
 								foreach ($templates as $template) {
 									print "<option value='" . $template['id'] . "'"; if (get_request_var('template_id') == $template['id']) { print ' selected'; } print '>' . html_escape($template['name']) . "</option>\n";
 								}
@@ -1388,7 +1438,7 @@ function aggregate_graph() {
 						<select id='rows' onChange='applyFilter()'>
 							<option value='-1'<?php print (get_request_var('rows') == '-1' ? ' selected>':'>') . __('Default');?></option>
 							<?php
-							if (sizeof($item_rows) > 0) {
+							if (cacti_sizeof($item_rows) > 0) {
 								foreach ($item_rows as $key => $value) {
 									print "<option value='" . $key . "'"; if (get_request_var('rows') == $key) { print ' selected'; } print '>' . html_escape($value) . "</option>\n";
 								}
@@ -1398,8 +1448,8 @@ function aggregate_graph() {
 					</td>
 					<td>
 						<span>
-							<input type='button' id='refresh' value='<?php print __esc('Go');?>' title='<?php print __esc('Set/Refresh Filters');?>'>
-							<input type='button' id='clear' value='<?php print __esc('Clear');?>' title='<?php print __esc('Clear Filters');?>'>
+							<input type='button' class='ui-button ui-corner-all ui-widget' id='refresh' value='<?php print __esc('Go');?>' title='<?php print __esc('Set/Refresh Filters');?>'>
+							<input type='button' class='ui-button ui-corner-all ui-widget' id='clear' value='<?php print __esc('Clear');?>' title='<?php print __esc('Clear Filters');?>'>
 						</span>
 					</td>
 				</tr>
@@ -1470,7 +1520,7 @@ function aggregate_graph() {
 
 	html_header_sort_checkbox($display_text, get_request_var('sort_column'), get_request_var('sort_direction'), false, 'aggregate_graphs.php?filter=' . get_request_var('filter'));
 
-	if (sizeof($graph_list)) {
+	if (cacti_sizeof($graph_list)) {
 		foreach ($graph_list as $graph) {
 			/* we're escaping strings here, so no need to escape them on form_selectable_cell */
 			$template_name = html_escape($graph['name']);
@@ -1478,17 +1528,17 @@ function aggregate_graph() {
 			form_selectable_cell(filter_value(title_trim($graph['title_cache'], read_config_option('max_title_length')), get_request_var('filter'), 'aggregate_graphs.php?action=edit&id=' . $graph['local_graph_id']), $graph['local_graph_id']);
 			form_selectable_cell($graph['local_graph_id'], $graph['local_graph_id'], '', 'right');
 			form_selectable_cell((empty($graph['name']) ? '<em>' . __('None') . '</em>' : filter_value($template_name, get_request_var('filter'))), $graph['local_graph_id']);
-			form_selectable_cell($graph['height'] . 'x' . $graph['width'], $graph['local_graph_id'], '', 'right');
+			form_selectable_ecell($graph['height'] . 'x' . $graph['width'], $graph['local_graph_id'], '', 'right');
 			form_checkbox_cell($graph['title_cache'], $graph['local_graph_id']);
 			form_end_row();
 		}
 	} else {
-		print '<tr><td colspan="' . (sizeof($display_text)+1) . '"><em>' . __('No Aggregate Graphs Found') .'</em></td></tr>';
+		print '<tr><td colspan="' . (cacti_sizeof($display_text)+1) . '"><em>' . __('No Aggregate Graphs Found') .'</em></td></tr>';
 	}
 
 	html_end_box(false);
 
-	if (sizeof($graph_list)) {
+	if (cacti_sizeof($graph_list)) {
 		/* put the nav bar on the bottom as well */
 		print $nav;
 	}
@@ -1512,7 +1562,7 @@ function purge_old_graphs() {
 		LEFT JOIN graph_local AS gl ON pagi.local_graph_id=gl.id
 		WHERE gl.id IS NULL AND local_graph_id>0'), 'local_graph_id',  'local_graph_id');
 
-	if (sizeof($old_graphs)) {
+	if (cacti_sizeof($old_graphs)) {
 		db_execute('DELETE FROM aggregate_graphs_items
 			WHERE local_graph_id IN (' . implode(',', $old_graphs) . ')');
 	}
@@ -1529,7 +1579,7 @@ function purge_old_graphs() {
 		ON pag.local_graph_id=gl.id
 		WHERE gl.id IS NULL'), 'id', 'id');
 
-	if (sizeof($old_aggregates)) {
+	if (cacti_sizeof($old_aggregates)) {
 		db_execute('DELETE FROM graph_templates_item
 			WHERE local_graph_id IN (' . implode(',', $old_aggregates) . ')');
 
@@ -1540,7 +1590,7 @@ function purge_old_graphs() {
 			WHERE local_graph_id IN (' . implode(',', $old_aggregates) . ')');
 	}
 
-	if (sizeof($old_agg_ids)) {
+	if (cacti_sizeof($old_agg_ids)) {
 		db_execute('DELETE FROM aggregate_graphs_items
 			WHERE aggregate_graph_id IN (' . implode(',', $old_agg_ids) . ')');
 	}
