@@ -23,8 +23,9 @@
 */
 
 include('./include/auth.php');
-include_once('./lib/utility.php');
 include_once('./lib/api_aggregate.php');
+include_once('./lib/poller.php');
+include_once('./lib/utility.php');
 
 /* set default action */
 set_default_action();
@@ -184,7 +185,7 @@ function form_save_aggregate() {
 	$save['cdef_id']         = form_input_validate((($save['t_cdef_id']) ? get_filter_request_var('cdef_id') : 0), 'cdef_id', '', true, 3);
 
 	if (!is_error_message()) {
-		// sql_save will not give usefull return values when row key is 
+		// sql_save will not give usefull return values when row key is
 		// composed from multiple columns. need to manualy build query
 		$sql_set = 'SET ';
 		foreach ($save as $key => $value) {
@@ -298,24 +299,24 @@ function item_edit() {
 		$page_name  = 'aggregate_templates.php';
 	}else {
 		/* TODO redirect somewhere and show an error message, rather than die */
-		die();
+		die("We should have redirected somewhere but we ended up here instead" . PHP_EOL);
 	}
 
 	if (!isempty_request_var('id')) {
-		$template_item = db_fetch_row_prepared('SELECT * 
-			FROM graph_templates_item 
-			WHERE id = ?', 
+		$template_item = db_fetch_row_prepared('SELECT *
+			FROM graph_templates_item
+			WHERE id = ?',
 			array(get_request_var('id')));
 	}
 
 	/* override some template_item values from aggregate tables */
 	$item_overrides = db_fetch_row_prepared("SELECT *
-		FROM $table_name 
+		FROM $table_name
 		WHERE $id_field = ?
-		AND graph_templates_item_id = ?", 
+		AND graph_templates_item_id = ?",
 		array(get_request_var($id_field), get_request_var("id")));
 
-	if (sizeof($item_overrides) == 0) {
+	if (cacti_sizeof($item_overrides) == 0) {
 		/* this item is not currently in aggregate tables
 		 * item editor will not work in this case, so let's
 		 * save it now
@@ -329,9 +330,9 @@ function item_edit() {
 		aggregate_graph_items_save(array($item_new), $table_name);
 
 		$item_overrides = db_fetch_row_prepared("SELECT *
-			FROM $table_name 
+			FROM $table_name
 			WHERE $id_field = ?
-			AND graph_templates_item_id = ?", 
+			AND graph_templates_item_id = ?",
 			array(get_request_var($id_field), get_request_var("id")));
 	}
 
@@ -354,7 +355,7 @@ function item_edit() {
 		if (array_key_exists('t_' . $field_name, $item_overrides)) {
 			$form_array[$field_name]['sub_checkbox']  = array(
 				'name' => 't_' . $field_name,
-				'friendly_name' => __('Override this Value') . '<br>',
+				'friendly_name' => __esc('Override this Value') . '<br>',
 				'value' => ($item_overrides['t_'.$field_name] == 'on' ? 'on' : ''),
 				'on_change' => 'toggleFieldEnabled(this);'
 			);
@@ -381,7 +382,7 @@ function item_edit() {
 	form_hidden_box('_graph_type_id', (isset($template_item) ? $template_item['graph_type_id'] : '0'), '');
 	form_hidden_box('save_component_item', '1', '');
 	form_hidden_box('invisible_alpha', $form_array['alpha']['value'], 'FF');
-	form_hidden_box('rrdtool_version', read_config_option('rrdtool_version'), '');
+	form_hidden_box('rrdtool_version', get_rrdtool_version(), '');
 	form_hidden_box('aggregate_graph_id', get_request_var('aggregate_graph_id'), '0');
 	form_hidden_box('aggregate_template_id', get_request_var('aggregate_template_id'), '0');
 
@@ -435,5 +436,5 @@ function item_edit() {
 
 	</script>
 	<?php
-} 
+}
 
