@@ -36,6 +36,23 @@ switch (get_request_var('action')) {
 	case 'logout_everywhere':
 		api_auth_logout_everywhere();
 
+		break;
+	case 'clear_user_settings':
+		api_auth_clear_user_settings();
+
+		break;
+	case 'reset_default':
+		$name  = get_nfilter_request_var('name');
+
+		api_auth_clear_user_setting($name);
+
+		break;
+	case 'update_data':
+		$name  = get_nfilter_request_var('name');
+		$value = get_nfilter_request_var('value');
+
+		api_auth_update_user_setting($name, $value);
+
 		break;
 	default:
 		// We must exempt ourselves from the page refresh, or else the settings page could update while the user is making changes
@@ -44,7 +61,47 @@ switch (get_request_var('action')) {
 
 		unset($_SESSION['custom']);
 
-		settings();
+		/* ================= input validation ================= */
+		get_filter_request_var('tab', FILTER_VALIDATE_REGEXP, array('options' => array('regexp' => '/^([a-z_A-Z]+)$/')));
+		/* ==================================================== */
+
+		/* present a tabbed interface */
+		$tabs = array(
+			'general'  => array(
+				'display' => __('General'),
+				'url'     => $config['url_path'] . 'auth_profile.php?tab=general&header=false'
+			)
+		);
+
+		$tabs = api_plugin_hook_function('auth_profile_tabs', $tabs);
+
+		/* set the default tab */
+		load_current_session_value('tab', 'sess_profile_tabs', 'general');
+		$current_tab = get_nfilter_request_var('tab');
+
+		if (cacti_sizeof($tabs) > 1) {
+			$i = 0;
+
+			/* draw the tabs */
+			print "<div class='tabs'><nav><ul role='tablist'>\n";
+
+			foreach ($tabs as $tab_short_name => $attribs) {
+				print "<li class='subTab'><a class='tab" . (($tab_short_name == $current_tab) ? " selected'" : "'") .
+					" href='" . html_escape($attribs['url']) .
+					"'>" . $attribs['display'] . "</a></li>\n";
+
+				$i++;
+			}
+
+			print "</ul></nav></div>\n";
+		}
+
+		if ($current_tab == 'general') {
+			settings();
+			settings_javascript();
+		} else {
+			api_plugin_hook_function('auth_profile_run_action', get_request_var('tab'));
+		}
 
 		bottom_footer();
 		break;
@@ -58,7 +115,91 @@ function api_auth_logout_everywhere() {
 	$user = $_SESSION['sess_user_id'];
 
 	if (!empty($user)) {
-		db_execute_prepared('DELETE FROM user_auth_cache WHERE user_id=?', array($user));
+		db_execute_prepared('DELETE FROM user_auth_cache
+			WHERE user_id = ?',
+			array($user));
+	}
+}
+
+function api_auth_clear_user_settings() {
+	$user = $_SESSION['sess_user_id'];
+
+	if (!empty($user)) {
+		if (isset_request_var('tab') && get_nfilter_request_var('tab') == 'general') {
+			db_execute_prepared('DELETE FROM settings_user
+				WHERE user_id = ?',
+				array($user));
+
+			kill_session_var('sess_user_config_array');
+		} elseif (isset_request_var('tab')) {
+			api_plugin_hook('auth_profile_reset');
+		}
+
+		raise_message('37');
+	}
+}
+
+function api_auth_clear_user_setting($name) {
+	global $settings_user;
+
+	$user = $_SESSION['sess_user_id'];
+
+	if (!empty($user)) {
+		if (isset_request_var('tab') && get_nfilter_request_var('tab') == 'general') {
+			db_execute_prepared('DELETE FROM settings_user
+				WHERE user_id = ?
+				AND name = ?',
+				array($user, $name));
+
+			foreach($settings_user as $tab => $settings) {
+				if (isset($settings[$name])) {
+					if (isset($settings[$name]['default'])) {
+						db_execute_prepared('INSERT INTO settings_user
+							(name, value, user_id)
+							VALUES (?, ?, ?)',
+							array($name, $settings[$name]['default'], $user));
+
+						print $settings[$name]['default'];
+
+						kill_session_var('sess_user_config_array');
+
+						break;
+					}
+				}
+			}
+		} else {
+			api_plugin_hook_function('auth_profile_reset_value', $name);
+		}
+	}
+}
+
+function api_auth_update_user_setting($name, $value) {
+	global $settings_user;
+
+	$user = $_SESSION['sess_user_id'];
+
+	if (!empty($user)) {
+		if ($name == 'full_name' || $name == 'email_address') {
+			db_execute_prepared("UPDATE user_auth
+				SET $name = ?
+				WHERE id = ?",
+				array($value, $user));
+		} else {
+			foreach($settings_user as $tab => $settings) {
+				if (isset($settings[$name])) {
+					db_execute_prepared('REPLACE INTO settings_user
+						(name, value, user_id)
+						VALUES (?, ?, ?)',
+						array($name, $value, $user));
+
+					kill_session_var('sess_user_config_array');
+					kill_session_var('selected_theme');
+					kill_session_var('sess_user_language');
+
+					break;
+				}
+			}
+		}
 	}
 }
 
@@ -70,80 +211,28 @@ function form_save() {
 		db_execute_prepared("UPDATE user_auth
 			SET full_name = ?, email_address = ?
 			WHERE id = ?",
-			array(get_nfilter_request_var('full_name'), get_nfilter_request_var('email_address'), $_SESSION['sess_user_id']));
+			array(
+				get_nfilter_request_var('full_name'),
+				get_nfilter_request_var('email_address'),
+				$_SESSION['sess_user_id']
+			)
+		);
 	}
 
 	$errors = array();
 
 	// Save the users graph settings if they have permission
-	if (is_view_allowed('graph_settings') == true) {
-		foreach ($settings_user as $tab_short_name => $tab_fields) {
-			foreach ($tab_fields as $field_name => $field_array) {
-				/* Check every field with a numeric default value and reset it to default if the inputted value is not numeric  */
-				if (isset($field_array['default']) && is_numeric($field_array['default']) && !is_numeric(get_nfilter_request_var($field_name))) {
-					set_request_var($field_name, $field_array['default']);
-				}
-
-				if ($field_array['method'] == 'checkbox') {
-					if (isset_request_var($field_name)) {
-						db_execute_prepared("REPLACE INTO settings_user
-							(user_id, name, value)
-							VALUES (?, ?, 'on')",
-							array($_SESSION['sess_user_id'], $field_name));
-					} else {
-						db_execute_prepared("REPLACE INTO settings_user
-							(user_id, name, value)
-							VALUES (?, ?, '')",
-							array($_SESSION['sess_user_id'], $field_name));
-					}
-				} elseif ($field_array['method'] == 'checkbox_group') {
-					foreach ($field_array['items'] as $sub_field_name => $sub_field_array) {
-						if (isset_request_var($sub_field_name)) {
-							db_execute_prepared("REPLACE INTO settings_user
-								(user_id, name, value)
-								VALUES (?, ?, 'on')",
-								array($_SESSION['sess_user_id'], $sub_field_name));
-						} else {
-							db_execute_prepared("REPLACE INTO settings_user
-								(user_id, name, value)
-								VALUES (?, ?, '')",
-								array($_SESSION['sess_user_id'], $sub_field_name));
-						}
-					}
-				} elseif ($field_array['method'] == 'textbox_password') {
-					if (get_nfilter_request_var($field_name) != get_nfilter_request_var($field_name.'_confirm')) {
-						$_SESSION['sess_error_fields'][$field_name] = $field_name;
-						$_SESSION['sess_field_values'][$field_name] = get_nfilter_request_var($field_name);
-						$errors[4] = 4;
-					} elseif (isset_request_var($field_name)) {
-						db_execute_prepared('REPLACE INTO settings_user
-							(user_id, name, value)
-							VALUES (?, ?, ?)',
-							array($_SESSION['sess_user_id'], $field_name, get_nfilter_request_var($field_name)));
-					}
-				} elseif ((isset($field_array['items'])) && (is_array($field_array['items']))) {
-					foreach ($field_array['items'] as $sub_field_name => $sub_field_array) {
-						if (isset_request_var($sub_field_name)) {
-							db_execute_prepared('REPLACE INTO settings_user
-								(user_id, name, value)
-								VALUES (?, ?, ?)',
-								array($_SESSION['sess_user_id'], $sub_field_name, get_nfilter_request_var($sub_field_name)));
-						}
-					}
-				}else if (isset_request_var($field_name)) {
-					db_execute_prepared('REPLACE INTO settings_user
-						(user_id, name, value)
-						VALUES (?, ?, ?)',
-						array($_SESSION['sess_user_id'], $field_name, get_nfilter_request_var($field_name)));
-				}
-			}
-		}
+	if (is_view_allowed('graph_settings') == true && isset_request_var('tab') && get_nfilter_request_var('tab') == 'general') {
+		save_user_settings($_SESSION['sess_user_id']);
+	} elseif (isset_request_var('tab')) {
+		api_plugin_hook('auth_profile_save');
 	}
 
-	if (sizeof($errors) == 0) {
+	if (cacti_sizeof($errors) == 0) {
 		raise_message(1);
 	} else {
 		raise_message(35);
+
 		foreach($errors as $error) {
 			raise_message($error);
 		}
@@ -168,24 +257,33 @@ function settings() {
 		return;
 	}
 
+	$_SESSION['profile_referer'] = 'auth_profile.php';
+
 	if (get_request_var('action') == 'edit') {
 		if (isset($_SERVER['HTTP_REFERER'])) {
-			$timespan_sel_pos = strpos($_SERVER['HTTP_REFERER'],'&predefined_timespan');
-			if ($timespan_sel_pos) {
-				$_SERVER['HTTP_REFERER'] = substr($_SERVER['HTTP_REFERER'],0,$timespan_sel_pos);
+			$referer = $_SERVER['HTTP_REFERER'];
+
+			if (strpos($referer, 'auth_profile.php') === false) {
+				$timespan_sel_pos = strpos($referer, '&predefined_timespan');
+				if ($timespan_sel_pos) {
+					$referer = substr($referer, 0, $timespan_sel_pos);
+				}
+
+				$_SESSION['profile_referer'] = $referer;
 			}
 		}
-
-		$_SESSION['profile_referer'] = (isset($_SERVER['HTTP_REFERER']) ? $_SERVER['HTTP_REFERER']:'graph_view.php');
 	}
 
-	form_start('auth_profile.php');
+	form_start('auth_profile.php', 'chk');
 
 	html_start_box(__('User Account Details'), '100%', true, '3', 'center', '');
 
-	$current_user = db_fetch_row_prepared('SELECT * FROM user_auth WHERE id = ?', array($_SESSION['sess_user_id']));
+	$current_user = db_fetch_row_prepared('SELECT *
+		FROM user_auth
+		WHERE id = ?',
+		array($_SESSION['sess_user_id']));
 
-	if (!sizeof($current_user)) {
+	if (!cacti_sizeof($current_user)) {
 		return;
 	}
 
@@ -203,7 +301,7 @@ function settings() {
 		$graph_views[2] = __('Preview View');
 	}
 
-	if (sizeof($graph_views)) {
+	if (cacti_sizeof($graph_views)) {
 		$settings_user['general']['default_view_mode']['array'] = $graph_views;
 	} else {
 		unset($settings_user['general']['default_view_mode']);
@@ -235,6 +333,13 @@ function settings() {
 			'max_length' => '60',
 			'size' => '60'
 		),
+		'clear_settings' => array(
+			'method' => 'button',
+			'friendly_name' => __('Clear User Settings'),
+			'description' => __('Return all User Settings to Default values.'),
+			'value' => __('Clear User Settings'),
+			'on_click' => 'clearUserSettings()'
+		),
 		'private_data' => array(
 			'method' => 'button',
 			'friendly_name' => __('Clear Private Data'),
@@ -270,7 +375,7 @@ function settings() {
 			$settings_user['tree']['default_tree_id']['sql'] = get_allowed_trees(false, true);
 		}
 
-		html_start_box( __('User Settings'), '100%', true, '3', 'center', '');
+		html_start_box(__('User Settings'), '100%', true, '3', 'center', '');
 
 		foreach ($settings_user as $tab_short_name => $tab_fields) {
 			$collapsible = true;
@@ -288,14 +393,30 @@ function settings() {
 							$form_array[$field_name]['items'][$sub_field_name]['form_id'] = 1;
 						}
 
-						$form_array[$field_name]['items'][$sub_field_name]['value'] =  db_fetch_cell_prepared('SELECT value FROM settings_user WHERE name = ? AND user_id = ?', array($sub_field_name, $_SESSION['sess_user_id']));
+						$form_array[$field_name]['items'][$sub_field_name]['value'] =  db_fetch_cell_prepared('SELECT value
+							FROM settings_user
+							WHERE name = ?
+							AND user_id = ?',
+							array($sub_field_name, $_SESSION['sess_user_id']));
 					}
 				} else {
 					if (graph_config_value_exists($field_name, $_SESSION['sess_user_id'])) {
 						$form_array[$field_name]['form_id'] = 1;
 					}
 
-					$form_array[$field_name]['value'] = db_fetch_cell_prepared('SELECT value FROM settings_user WHERE name = ? AND user_id = ?', array($field_name, $_SESSION['sess_user_id']));
+					$user_row = db_fetch_row_prepared('SELECT value
+						FROM settings_user
+						WHERE name = ?
+						AND user_id = ?',
+						array($field_name, $_SESSION['sess_user_id']));
+
+					if (cacti_sizeof($user_row)) {
+						$form_array[$field_name]['user_set'] = true;
+						$form_array[$field_name]['value'] = $user_row['value'];
+					} else {
+						$form_array[$field_name]['user_set'] = false;
+						$form_array[$field_name]['value'] = null;
+					}
 				}
 			}
 
@@ -303,10 +424,10 @@ function settings() {
 				array(
 					'config' => array(
 						'no_form_tag' => true
-						),
+					),
 					'fields' => $form_array
-					)
-				);
+				)
+			);
 		}
 
 		print "</td></tr>\n";
@@ -314,15 +435,30 @@ function settings() {
 		html_end_box(true, true);
 	}
 
-	?>
-	<script type="text/javascript">
+	form_hidden_box('save_component_graph_config','1','');
 
-	var themeFonts=<?php print read_config_option('font_method');?>;
-	var themeChanged = false;
-	var langChanged = false;
+	form_save_buttons(array(array('id' => 'return', 'value' => __esc('Return'))));
+
+	form_end();
+}
+
+function settings_javascript() {
+	global $config;
+
+	?>
+	<script type='text/javascript'>
+
+	var themeFonts   = <?php print read_config_option('font_method');?>;
+	var currentTab   = '<?php print get_nfilter_request_var('tab');?>';
 	var currentTheme = '<?php print get_selected_theme();?>';
 	var currentLang  = '<?php print read_config_option('user_language');?>';
 
+	function clearUserSettings() {
+		$.get('auth_profile.php?action=clear_user_settings', function() {
+			document.location = 'auth_profile.php?newtheme=1';
+		});
+	}
+
 	function clearPrivateData() {
 		Storages.localStorage.removeAll();
 		Storages.sessionStorage.removeAll();
@@ -368,16 +504,16 @@ function settings() {
 
 	function graphSettings() {
 		if (themeFonts == 1) {
-				$('#row_fonts').hide();
-				$('#row_custom_fonts').hide();
-				$('#row_title_size').hide();
-				$('#row_title_font').hide();
-				$('#row_legend_size').hide();
-				$('#row_legend_font').hide();
-				$('#row_axis_size').hide();
-				$('#row_axis_font').hide();
-				$('#row_unit_size').hide();
-				$('#row_unit_font').hide();
+			$('#row_fonts').hide();
+			$('#row_custom_fonts').hide();
+			$('#row_title_size').hide();
+			$('#row_title_font').hide();
+			$('#row_legend_size').hide();
+			$('#row_legend_font').hide();
+			$('#row_axis_size').hide();
+			$('#row_axis_font').hide();
+			$('#row_unit_size').hide();
+			$('#row_unit_font').hide();
 		} else {
 			var custom_fonts = $('#custom_fonts').is(':checked');
 
@@ -408,61 +544,79 @@ function settings() {
 		}
 	}
 
-	function themeChange() {
-		if ($('#selected_theme').val() != currentTheme) {
-			themeChanged = true;
-		} else {
-			themeChanged = false;
-		}
-	}
-
-	function langChange() {
-		if ($('#user_language').val() != currentLang) {
-			langChanged = true;
-		} else {
-			langChanged = false;
-		}
-	}
-
 	$(function() {
 		graphSettings();
 
-		$('#navigation').show();
-		$('#navigation_right').show();
+		$('#navigation, #navigation_right').show();
 
 		$('input[value="<?php print __esc('Save');?>"]').unbind().click(function(event) {
 			event.preventDefault();
-            if (themeChanged != true && langChanged != true) {
-                $.post('auth_profile.php?header=false', $('input, select, textarea').serialize()).done(function(data) {
-					loadPageNoHeader('auth_profile.php?action=noreturn&header=false');
-                });
-            } else {
-                $.post('auth_profile.php?header=false', $('input, select, textarea').serialize()).done(function(data) {
-                    document.location = 'auth_profile.php?newtheme=1';
-                });
-            }
+			$.post('auth_profile.php?header=false', $('input, select, textarea').serialize()).done(function(data) {
+				loadPageNoHeader('auth_profile.php?action=noreturn&header=false');
+			});
 		});
 
-		$('#selected_theme').change(function() {
-			themeChange();
+		$('#auth_profile_edit2 .formData, #auth_profile_noreturn2 .formData').each(function() {
+			if ($(this).find('select, input[type!="button"]').length) {
+				$(this).parent().hover(
+					function() {
+						var id = $(this).find('select, input[type!="button"]').attr('id');
+
+						$('<a class="resetHover" data-id="'+id+'" style="padding-left:10px" href="#"><?php print __('Reset');?></a>').appendTo($(this));
+						$('.resetHover').on('click', function(event) {
+							event.preventDefault();
+
+							var id = $(this).attr('data-id');
+
+							if (id != undefined) {
+								$.get('auth_profile.php?tab='+currentTab+'&action=reset_default&name='+id, function(data) {
+									if (id != 'selected_theme' && id != 'user_language') {
+										if ($('#'+id).is(':checkbox')) {
+											if (data == 'on') {
+												$('#'+id).prop('checked', true);
+											} else {
+												$('#'+id).prop('checked', false);
+											}
+										} else {
+											$('#'+id).val(data);
+											if ($('#'+id).selectmenu('instance')) {
+												$('#'+id).selectmenu('refresh');
+											}
+										}
+									} else {
+										document.location = 'auth_profile.php?action=edit';
+									}
+								});
+							}
+						});
+					},
+					function() {
+						$('.resetHover').remove();
+					}
+				);
+			}
 		});
 
-		$('#user_language').change(function() {
-			langChange();
+		$('select, input[type!="button"]').unbind().keyup(function() {
+			name  = $(this).attr('id');
+			value = $(this).val();
+			$.get('auth_profile.php?tab='+currentTab+'&action=update_data&name='+name+'&value='+value, function() {
+			});
+		}).change(function() {
+			name  = $(this).attr('id');
+			value = $(this).val();
+			$.get('auth_profile.php?tab='+currentTab+'&action=update_data&name='+name+'&value='+value, function() {
+				if (name == 'selected_theme' || name == 'user_language') {
+					document.location = 'auth_profile.php?action=edit';
+				}
+			});
 		});
 
-		$('input[value="<?php print __esc('Return');?>"]').unbind().click(function(event) {
-			document.location = '<?php print html_escape(isset($_SESSION['profile_referer']) ? $_SESSION['profile_referer']:'auth_profile.php');?>';
+		$('#return').click(function() {
+			document.location = '<?php print $_SESSION['profile_referer'];?>';
 		});
 	});
 
 	</script>
 	<?php
-
-	form_hidden_box('save_component_graph_config','1','');
-
-	form_save_buttons(array(array('id' => 'return', 'value' => __esc('Return')), array('id' => 'save', 'value' => __esc('Save'))));
-
-	form_end();
 }
-
