@@ -23,16 +23,9 @@
  +-------------------------------------------------------------------------+
 */
 
-/* do NOT run this script through a web browser */
-if (!isset($_SERVER['argv'][0]) || isset($_SERVER['REQUEST_METHOD'])  || isset($_SERVER['REMOTE_ADDR'])) {
-	die('<br>This script is only meant to run at the command line.');
-}
-
-/* We are not talking to the browser */
-$no_http_headers = true;
+require(__DIR__ . '/include/cli_check.php');
 
 /* include important functions */
-include_once('./include/global.php');
 include_once($config['base_path'] . '/lib/poller.php');
 include_once($config['base_path'] . '/lib/boost.php');
 
@@ -68,8 +61,8 @@ if (trim($result) == '') {
 	}
 	$result_array = explode("\n", $result);
 
-	if (sizeof($result_array)) {
-		$result = $result_array[sizeof($result_array)-2];
+	if (cacti_sizeof($result_array)) {
+		$result = $result_array[cacti_sizeof($result_array)-2];
 	} else {
 		$result = 'ERROR: Detected unknown error';
 	}
