@@ -2,7 +2,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2017 The Cacti Group                                 |
+ | Copyright (C) 2004-2018 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -21,24 +21,17 @@
  +-------------------------------------------------------------------------+
  | http://www.cacti.net/                                                   |
  +-------------------------------------------------------------------------+
- */
+*/
 
-/* do NOT run this script through a web browser */
-if (!isset($_SERVER['argv'][0]) || isset($_SERVER['REQUEST_METHOD'])  || isset($_SERVER['REMOTE_ADDR'])) {
-	die('<br><strong>This script is only meant to run at the command line.</strong>');
-}
-
-$no_http_headers = true;
-
-include(dirname(__FILE__).'/../include/global.php');
-include_once($config['base_path'].'/lib/api_automation_tools.php');
-include_once($config['base_path'].'/lib/api_tree.php');
+require(__DIR__ . '/../include/cli_check.php');
+require_once($config['base_path'] . '/lib/api_automation_tools.php');
+require_once($config['base_path'] . '/lib/api_tree.php');
 
 /* process calling arguments */
 $parms = $_SERVER['argv'];
 array_shift($parms);
 
-if (sizeof($parms)) {
+if (cacti_sizeof($parms)) {
 	/* setup defaults */
 	$type       = '';  # tree or node
 	$name       = '';  # Name of a tree or node
@@ -47,6 +40,7 @@ if (sizeof($parms)) {
 	$treeId     = 0;   # When creating a node, it has to go in a tree
 	$nodeType   = '';  # Should be 'header', 'graph' or 'host' when creating a node
 	$graphId    = 0;   # The ID of the graph to add (gets added to parentNode)
+	$siteId     = 0;   # The ID of the site to add
 
 	$sortMethods = array('manual' => 1, 'alpha' => 2, 'natural' => 4, 'numeric' => 3);
 	$nodeTypes   = array('header' => 1, 'graph' => 2, 'host' => 3);
@@ -60,8 +54,10 @@ if (sizeof($parms)) {
 	$displayNodes   = false;
 	$displayRRAs    = false;
 	$displayGraphs  = false;
+	$displaySites   = false;
 
 	$hosts          = getHosts();
+	$sites          = getSites();
 
 	foreach($parms as $parameter) {
 		if (strpos($parameter, '=')) {
@@ -123,6 +119,10 @@ if (sizeof($parms)) {
 			case '--list-graphs':
 				$displayGraphs = true;
 
+				break;
+			case '--list-sites':
+				$displaySites = true;
+
 				break;
 			case '--host-group-style':
 				$hostGroupStyle = trim($value);
@@ -132,19 +132,24 @@ if (sizeof($parms)) {
 			case '-V':
 			case '-v':
 				display_version();
-				exit;
+				exit(0);
 			case '--help':
 			case '-H':
 			case '-h':
 				display_help();
-				exit;
+				exit(0);
 			default:
-				echo "ERROR: Invalid Argument: ($arg)\n\n";
+				print "ERROR: Invalid Argument: ($arg)\n\n";
 				display_help();
 				exit(1);
 		}
 	}
 
+	if ($displaySites) {
+		displaySites($sites, $quietMode);
+		exit(0);
+	}
+
 	if ($displayHosts) {
 		displayHosts($hosts, $quietMode);
 		exit(0);
@@ -157,8 +162,8 @@ if (sizeof($parms)) {
 
 	if ($displayNodes) {
 		if (!isset($treeId)) {
-			echo "ERROR: You must supply a tree_id before you can list its nodes\n";
-			echo "Try --list-trees\n";
+			print "ERROR: You must supply a tree_id before you can list its nodes\n";
+			print "Try --list-trees\n";
 			exit(1);
 		}
 
@@ -173,8 +178,8 @@ if (sizeof($parms)) {
 
 	if ($displayGraphs) {
 		if (!isset($hostId) || $hostId == 0) {
-			echo "ERROR: You must supply a host_id before you can list its graphs\n";
-			echo "Try --list-hosts\n";
+			print "ERROR: You must supply a host_id before you can list its graphs\n";
+			print "Try --list-hosts\n";
 			exit(1);
 		}
 
@@ -185,7 +190,7 @@ if (sizeof($parms)) {
 	if ($type == 'tree') {
 		# Add a new tree
 		if (empty($name)) {
-			echo "ERROR: You must supply a name with --name\n";
+			print "ERROR: You must supply a name with --name\n";
 			display_help();
 			exit(1);
 		}
@@ -200,14 +205,14 @@ if (sizeof($parms)) {
 			$sortMethod == 'natural') {
 			$treeOpts['sort_type'] = $sortMethods[$sortMethod];
 		} else {
-			echo "ERROR: Invalid sort-method: ($sortMethod)\n";
+			print "ERROR: Invalid sort-method: ($sortMethod)\n";
 			display_help();
 			exit(1);
 		}
 
 		$existsAlready = db_fetch_cell("SELECT id FROM graph_tree WHERE name = '$name'");
 		if ($existsAlready) {
-			echo "ERROR: Not adding tree - it already exists - tree-id: ($existsAlready)\n";
+			print "ERROR: Not adding tree - it already exists - tree-id: ($existsAlready)\n";
 			exit(1);
 		}
 
@@ -215,23 +220,24 @@ if (sizeof($parms)) {
 
 		api_tree_sort_branch(0, $treeId);
 
-		echo "Tree Created - tree-id: ($treeId)\n";
+		print "Tree Created - tree-id: ($treeId)\n";
 
 		exit(0);
 	} elseif ($type == 'node') {
 		# Add a new node to a tree
 		if ($nodeType == 'header'||
 			$nodeType == 'graph' ||
+			$nodeType == 'site' ||
 			$nodeType == 'host') {
 			$itemType = $nodeTypes[$nodeType];
 		} else {
-			echo "ERROR: Invalid node-type: ($nodeType)\n";
+			print "ERROR: Invalid node-type: ($nodeType)\n";
 			display_help();
 			exit(1);
 		}
 
 		if (!is_numeric($parentNode)) {
-			echo "ERROR: parent-node $parentNode must be numeric > 0\n";
+			print "ERROR: parent-node $parentNode must be numeric > 0\n";
 			display_help();
 			exit(1);
 		} elseif ($parentNode > 0 ) {
@@ -241,7 +247,7 @@ if (sizeof($parms)) {
 				AND id=$parentNode");
 
 			if (!isset($parentNodeExists)) {
-				echo "ERROR: parent-node $parentNode does not exist\n";
+				print "ERROR: parent-node $parentNode does not exist\n";
 				exit(1);
 			}
 		}
@@ -249,7 +255,7 @@ if (sizeof($parms)) {
 		if ($nodeType == 'header') {
 			# Header --name must be given
 			if (empty($name)) {
-				echo "ERROR: You must supply a name with --name\n";
+				print "ERROR: You must supply a name with --name\n";
 				display_help();
 				exit(1);
 			}
@@ -257,46 +263,59 @@ if (sizeof($parms)) {
 			# Blank out the graphId, hostID and host_grouping_style  fields
 			$graphId        = 0;
 			$hostId         = 0;
+			$siteId         = 0;
 			$hostGroupStyle = 1;
 		}else if($nodeType == 'graph') {
 			# Blank out name, hostID, host_grouping_style
 			$name           = '';
 			$hostId         = 0;
+			$siteId         = 0;
 			$hostGroupStyle = 1;
 
-			$graphs = db_fetch_assoc('SELECT id 
+			$graphs = db_fetch_assoc('SELECT id
 				FROM graph_local
 				WHERE graph_local.id=' . $graphId);
-		
-			if (!sizeof($graphs)) {
-				echo "ERROR: No such graph-id ($graphId) exists. Try --list-graphs\n";
+
+			if (!cacti_sizeof($graphs)) {
+				print "ERROR: No such graph-id ($graphId) exists. Try --list-graphs\n";
+				exit(1);
+			}
+		}else if ($nodeType == 'site') {
+			# Blank out graphId, name fields
+			$graphId        = 0;
+			$hostId         = 0;
+			$name           = '';
+
+			if (!isset($sites[$siteId])) {
+				print "ERROR: No such site-id ($siteId) exists. Try --list-sites\n";
 				exit(1);
 			}
 		}else if ($nodeType == 'host') {
 			# Blank out graphId, name fields
 			$graphId        = 0;
+			$siteId         = 0;
 			$name           = '';
 
 			if (!isset($hosts[$hostId])) {
-				echo "ERROR: No such host-id ($hostId) exists. Try --list-hosts\n";
+				print "ERROR: No such host-id ($hostId) exists. Try --list-hosts\n";
 				exit(1);
 			}
 
 			if ($hostGroupStyle != 1 && $hostGroupStyle != 2) {
-				echo "ERROR: Host Group Style must be 1 or 2 (Graph Template or Data Query Index)\n";
+				print "ERROR: Host Group Style must be 1 or 2 (Graph Template or Data Query Index)\n";
 				display_help();
 				exit(1);
 			}
 		}
 
 		# $nodeId could be a Header Node, a Graph Node, or a Host node.
-		$nodeId = api_tree_item_save(0, $treeId, $itemType, $parentNode, $name, $graphId, $hostId, $hostGroupStyle, $sortMethods[$sortMethod], false);
+		$nodeId = api_tree_item_save(0, $treeId, $itemType, $parentNode, $name, $graphId, $hostId, $siteId, $hostGroupStyle, $sortMethods[$sortMethod], false);
 
-		echo "Added Node node-id: ($nodeId)\n";
+		print "Added Node node-id: ($nodeId)\n";
 
 		exit(0);
 	} else {
-		echo "ERROR: Unknown type: ($type)\n";
+		print "ERROR: Unknown type: ($type)\n";
 		display_help();
 		exit(1);
 	}
@@ -307,34 +326,37 @@ if (sizeof($parms)) {
 
 /*  display_version - displays version information */
 function display_version() {
-	$version = get_cacti_version();
-	echo "Cacti Add Tree Utility, Version $version, " . COPYRIGHT_YEARS . "\n";
+	$version = get_cacti_cli_version();
+	print "Cacti Add Tree Utility, Version $version, " . COPYRIGHT_YEARS . "\n";
 }
 
 function display_help() {
 	display_version();
 
-	echo "\nusage: add_tree.php  --type=[tree|node] [type-options] [--quiet]\n\n";
-	echo "Tree options:\n";
-	echo "    --name=[Tree Name]\n";
-	echo "    --sort-method=[manual|alpha|natural|numeric]\n\n";
-	echo "Node options:\n";
-	echo "    --node-type=[header|host|graph]\n";
-	echo "    --tree-id=[ID]\n";
-	echo "    [--parent-node=[ID] [Node Type Options]]\n\n";
-	echo "Header node options:\n";
-	echo "    --name=[Name]\n\n";
-	echo "Host node options:\n";
-	echo "    --host-id=[ID]\n";
-	echo "    [--host-group-style=[1|2]]\n";
-	echo "    (host group styles:\n";
-	echo "     1 = Graph Template,\n";
-	echo "     2 = Data Query Index)\n\n";
-	echo "Graph node options:\n";
-	echo "    --graph-id=[ID]\n\n";
-	echo "List Options:\n";
-	echo "    --list-hosts\n";
-	echo "    --list-trees\n";
-	echo "    --list-nodes --tree-id=[ID]\n";
-	echo "    --list-graphs --host-id=[ID]\n";
+	print "\nusage: add_tree.php  --type=[tree|node] [type-options] [--quiet]\n\n";
+	print "Tree options:\n";
+	print "    --name=[Tree Name]\n";
+	print "    --sort-method=[manual|alpha|natural|numeric]\n\n";
+	print "Node options:\n";
+	print "    --node-type=[header|site|host|graph]\n";
+	print "    --tree-id=[ID]\n";
+	print "    [--parent-node=[ID] [Node Type Options]]\n\n";
+	print "Header node options:\n";
+	print "    --name=[Name]\n\n";
+	print "Site node options:\n";
+	print "    --site-id=[ID]\n";
+	print "Host node options:\n";
+	print "    --host-id=[ID]\n";
+	print "    [--host-group-style=[1|2]]\n";
+	print "    (host group styles:\n";
+	print "     1 = Graph Template,\n";
+	print "     2 = Data Query Index)\n\n";
+	print "Graph node options:\n";
+	print "    --graph-id=[ID]\n\n";
+	print "List Options:\n";
+	print "    --list-sites\n";
+	print "    --list-hosts\n";
+	print "    --list-trees\n";
+	print "    --list-nodes --tree-id=[ID]\n";
+	print "    --list-graphs --host-id=[ID]\n";
 }
