@@ -2,7 +2,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2017 The Cacti Group                                 |
+ | Copyright (C) 2004-2018 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -14,7 +14,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -23,36 +23,37 @@
  +-------------------------------------------------------------------------+
 */
 
-/* do NOT run this script through a web browser */
-if (!isset($_SERVER['argv'][0]) || isset($_SERVER['REQUEST_METHOD'])  || isset($_SERVER['REMOTE_ADDR'])) {
-	die('<br><strong>This script is only meant to run at the command line.</strong>');
-}
+require(__DIR__ . '/../include/cli_check.php');
+require_once($config['base_path'] . '/lib/api_automation_tools.php');
+require_once($config['base_path'] . '/lib/api_automation.php');
+require_once($config['base_path'] . '/lib/api_data_source.php');
+require_once($config['base_path'] . '/lib/api_graph.php');
+require_once($config['base_path'] . '/lib/api_device.php');
+require_once($config['base_path'] . '/lib/data_query.php');
+require_once($config['base_path'] . '/lib/poller.php');
+require_once($config['base_path'] . '/lib/snmp.php');
+require_once($config['base_path'] . '/lib/sort.php');
+require_once($config['base_path'] . '/lib/template.php');
+require_once($config['base_path'] . '/lib/utility.php');
 
 ini_set('max_execution_time', '0');
 
-$no_http_headers = true;
-
-include(dirname(__FILE__) . '/../include/global.php');
-include_once($config['base_path'] . '/lib/snmp.php');
-include_once($config['base_path'] . '/lib/data_query.php');
-include_once($config['base_path'] . '/lib/api_automation_tools.php');
-
 /* process calling arguments */
 $parms = $_SERVER['argv'];
 array_shift($parms);
 
 /* utility requires input parameters */
-if (sizeof($parms) == 0) {
+if (cacti_sizeof($parms) == 0) {
 	print "ERROR: You must supply input parameters\n\n";
 	display_help();
-	exit;
+	exit(1);
 }
 
-$debug    = FALSE;
+$debug    = false;
 $template = '';
 $hostid   = '';
 
-if (sizeof($parms)) {
+if (cacti_sizeof($parms)) {
 	foreach($parms as $parameter) {
 		if (strpos($parameter, '=')) {
 			list($arg, $value) = explode('=', $parameter);
@@ -74,22 +75,22 @@ if (sizeof($parms)) {
 				exit(0);
 			case '-d':
 			case '--debug':
-				$debug = TRUE;
+				$debug = true;
 				break;
 			case '--version':
 			case '-V':
 			case '-v':
 				display_version();
-				exit;
+				exit(0);
 			case '--help':
 			case '-H':
 			case '-h':
 				display_help();
-				exit;
+				exit(0);
 			default:
 				print 'ERROR: Invalid Parameter ' . $parameter . "\n\n";
 				display_help();
-				exit;
+				exit(1);
 		}
 	}
 }
@@ -107,7 +108,7 @@ if (strtolower($host_id) == 'all') {
 
 /* determine data queries to rerun */
 if (is_numeric($template)) {
-	$sql_where .= (strlen($sql_where) ? " AND host_template_id=$template": "WHERE host_template_id=$template");
+	$sql_where .= ($sql_where != '' ? " AND host_template_id=$template": "WHERE host_template_id=$template");
 } else {
 	print "ERROR: You must specify a Host Template to proceed.\n\n";
 	display_help();
@@ -118,17 +119,17 @@ if (is_numeric($template)) {
 if (db_fetch_cell("SELECT id FROM host_template WHERE id=$template") > 0) {
 	$hosts = db_fetch_assoc("SELECT * FROM host $sql_where");
 
-	if (sizeof($hosts)) {
+	if (cacti_sizeof($hosts)) {
 	foreach($hosts as $host) {
-		echo "NOTE: Updating Host '" . $host['description'] . "'\n";
+		print "NOTE: Updating Host '" . $host['description'] . "'\n";
 		$snmp_queries = db_fetch_assoc('SELECT snmp_query_id
 			FROM host_template_snmp_query
 			WHERE host_template_id=' . $host['host_template_id']);
 
-		if (sizeof($snmp_queries) > 0) {
-			echo "NOTE: Updating Data Queries. There were '" . sizeof($snmp_queries) . "' Found\n";
+		if (cacti_sizeof($snmp_queries) > 0) {
+			print "NOTE: Updating Data Queries. There were '" . cacti_sizeof($snmp_queries) . "' Found\n";
 			foreach ($snmp_queries as $snmp_query) {
-				echo "NOTE: Updating Data Query ID '" . $snmp_query['snmp_query_id'] . "'\n";
+				print "NOTE: Updating Data Query ID '" . $snmp_query['snmp_query_id'] . "'\n";
 				db_execute('REPLACE INTO host_snmp_query (host_id,snmp_query_id,reindex_method)
 					VALUES (' . $host['id'] . ', ' . $snmp_query['snmp_query_id'] . ',' . DATA_QUERY_AUTOINDEX_BACKWARDS_UPTIME . ')');
 
@@ -139,8 +140,8 @@ if (db_fetch_cell("SELECT id FROM host_template WHERE id=$template") > 0) {
 
 		$graph_templates = db_fetch_assoc('SELECT graph_template_id FROM host_template_graph WHERE host_template_id=' . $host['host_template_id']);
 
-		if (sizeof($graph_templates) > 0) {
-			echo "NOTE: Updating Graph Templates. There were '" . sizeof($graph_templates) . "' Found\n";
+		if (cacti_sizeof($graph_templates) > 0) {
+			print "NOTE: Updating Graph Templates. There were '" . cacti_sizeof($graph_templates) . "' Found\n";
 
 			foreach ($graph_templates as $graph_template) {
 				db_execute('REPLACE INTO host_graph (host_id, graph_template_id) VALUES (' . $host['id'] . ', ' . $graph_template['graph_template_id'] . ')');
@@ -153,29 +154,29 @@ if (db_fetch_cell("SELECT id FROM host_template WHERE id=$template") > 0) {
 	}
 	}
 } else {
-	echo "ERROR: The selected Host Template does not exist, try --list-host-templates\n\n";
+	print "ERROR: The selected Host Template does not exist, try --list-host-templates\n\n";
 	exit(1);
 }
 
 /*  display_version - displays version information */
 function display_version() {
-	$version = db_fetch_cell('SELECT cacti FROM version');
-	echo "Cacti Retemplate Host Utility, Version $version, " . COPYRIGHT_YEARS . "\n";
+	$version = get_cacti_cli_version();
+	print "Cacti Retemplate Host Utility, Version $version, " . COPYRIGHT_YEARS . "\n";
 }
 
 /*	display_help - displays the usage of the function */
 function display_help () {
 	display_version();
 
-	echo "\nusage: host_update_template.php --host-id=[host-id|all] [--host-template=[ID]] [--debug]\n\n";
-	echo "A utility to update Cacti devices with the latest Device Template\n\n";
-	echo "Required:\n";
-	echo "    --host-id=host_id|all - The host_id to have templates reapplied 'all' to do all hosts\n";
-	echo "    --host-template=ID    - Which Host Template to Refresh\n\n";
-	echo "Optional:\n";
-	echo "    --debug               - Display verbose output during execution\n\n";
-	echo "List Options:\n";
-	echo "    --list-host-templates - Lists all available Host Templates\n\n";
+	print "\nusage: host_update_template.php --host-id=[host-id|all] [--host-template=[ID]] [--debug]\n\n";
+	print "A utility to update Cacti devices with the latest Device Template\n\n";
+	print "Required:\n";
+	print "    --host-id=host_id|all - The host_id to have templates reapplied 'all' to do all hosts\n";
+	print "    --host-template=ID    - Which Host Template to Refresh\n\n";
+	print "Optional:\n";
+	print "    --debug               - Display verbose output during execution\n\n";
+	print "List Options:\n";
+	print "    --list-host-templates - Lists all available Host Templates\n\n";
 }
 
 function debug($message) {
