@@ -23,28 +23,21 @@
  +-------------------------------------------------------------------------+
 */
 
-/* do NOT run this script through a web browser */
-if (!isset($_SERVER['argv'][0]) || isset($_SERVER['REQUEST_METHOD'])  || isset($_SERVER['REMOTE_ADDR'])) {
-	die('<br><strong>This script is only meant to run at the command line.</strong>');
-}
-
-/* We are not talking to the browser */
-$no_http_headers = true;
-
-include(dirname(__FILE__).'/../include/global.php');
-include_once($config['base_path'].'/lib/api_automation_tools.php');
-include_once($config['base_path'].'/lib/utility.php');
-include_once($config['base_path'].'/lib/api_data_source.php');
-include_once($config['base_path'].'/lib/api_graph.php');
-include_once($config['base_path'].'/lib/snmp.php');
-include_once($config['base_path'].'/lib/data_query.php');
-include_once($config['base_path'].'/lib/api_device.php');
+require(__DIR__ . '/../include/cli_check.php');
+require_once($config['base_path'] . '/lib/api_automation_tools.php');
+require_once($config['base_path'] . '/lib/api_data_source.php');
+require_once($config['base_path'] . '/lib/api_device.php');
+require_once($config['base_path'] . '/lib/api_graph.php');
+require_once($config['base_path'] . '/lib/data_query.php');
+require_once($config['base_path'] . '/lib/snmp.php');
+require_once($config['base_path'] . '/lib/poller.php');
+require_once($config['base_path'] . '/lib/utility.php');
 
 /* process calling arguments */
 $parms = $_SERVER['argv'];
 array_shift($parms);
 
-if (sizeof($parms)) {
+if (cacti_sizeof($parms)) {
 	/* setup defaults */
 	$description   = '';
 	$ip            = '';
@@ -82,25 +75,21 @@ if (sizeof($parms)) {
 
 			break;
 		case '--version':
-			display_version();
-			exit;
-			break;
-		case '--version':
 		case '-V':
 		case '-v':
 			display_version();
-			exit;
+			exit(0);
 		case '--help':
 		case '-H':
 		case '-h':
 			display_help();
-			exit;
+			exit(0);
 		case '--quiet':
 			$quietMode = true;
 
 			break;
 		default:
-			echo "ERROR: Invalid Argument: ($arg)\n\n";
+			print "ERROR: Invalid Argument: ($arg)\n\n";
 			display_help();
 			exit(1);
 		}
@@ -115,30 +104,30 @@ if (sizeof($parms)) {
 	/* process host description */
 	if ($description > '') {
 		if ($debug) {
-			echo "Searching hosts by description...\n";
+			print "Searching hosts by description...\n";
 		}
 
 		$ids_host = preg_array_key_match("/$description/", $hosts);
-		if (sizeof($ids_host) == 0) {
-			echo "ERROR: Unable to find host in the database matching desciption ($description)\n";
+		if (cacti_sizeof($ids_host) == 0) {
+			print "ERROR: Unable to find host in the database matching desciption ($description)\n";
 			exit(1);
 		}
 	}
 
 	if ($ip > '') {
 		if ($debug) {
-			echo "Searching hosts by IP...\n";
+			print "Searching hosts by IP...\n";
 		}
 
 		$ids_ip = preg_array_key_match("/$ip/", $addresses);
-		if (sizeof($ids_ip) == 0) {
-			echo "ERROR: Unable to find host in the database matching IP ($ip)\n";
+		if (cacti_sizeof($ids_ip) == 0) {
+			print "ERROR: Unable to find host in the database matching IP ($ip)\n";
 			exit(1);
 		}
 	}
 
-	if (sizeof($ids_host) == 0 && sizeof($ids_ip) == 0) {
-		echo "ERROR: No matches found, was IP or Description set properly?\n";
+	if (cacti_sizeof($ids_host) == 0 && cacti_sizeof($ids_ip) == 0) {
+		print "ERROR: No matches found, was IP or Description set properly?\n";
 		exit(1);
 	}
 
@@ -147,7 +136,7 @@ if (sizeof($parms)) {
 
 	$ids_sql = implode(',',$ids);
 	if ($debug) {
-		echo "Finding devices with ids $ids_sql\n\n";
+		print "Finding devices with ids $ids_sql\n\n";
 	}
 
 	$hosts = db_fetch_assoc("SELECT id, hostname, description FROM host WHERE id IN ($ids_sql) ORDER by description");
@@ -158,25 +147,25 @@ if (sizeof($parms)) {
 			printf("%8.d | %30.s | %30.s\n",$host['id'],$host['hostname'],$host['description']);
 			$ids_found[] = $host['id'];
 		}
-		echo "\n";
+		print "\n";
 	}
 
 	if ($confirm) {
 		$ids_confirm = implode(', ',$ids_found);
 		if (!$quiet) {
-			echo "Removing devices with ids: $ids_confirm\n";
+			print "Removing devices with ids: $ids_confirm\n";
 		}
 		$host_id = api_device_remove_multi($ids);
 
 		if (is_error_message()) {
-			echo "ERROR: Failed to remove devices\n";
+			print "ERROR: Failed to remove devices\n";
 			exit(1);
 		} else {
-			echo "Success - removed device-ids: $ids_confirm\n";
+			print "Success - removed device-ids: $ids_confirm\n";
 			exit(0);
 		}
 	} else {
-		echo "Please use --confirm to remove these devices\n";
+		print "Please use --confirm to remove these devices\n";
 	}
 } else {
 	display_help();
@@ -185,23 +174,23 @@ if (sizeof($parms)) {
 
 /*  display_version - displays version information */
 function display_version() {
-	$version = get_cacti_version();
-	echo "Cacti Remove Device Utility, Version $version, " . COPYRIGHT_YEARS . "\n";
+	$version = get_cacti_cli_version();
+	print "Cacti Remove Device Utility, Version $version, " . COPYRIGHT_YEARS . "\n";
 }
 
 function display_help() {
 	display_version();
 
-	echo "\nusage: remove_device.php --description=[description] --ip=[IP]\n";
-	echo "    [--confirm] [--quiet]\n\n";
-	echo "Required:\n";
-	echo "    --description  the name that will be displayed by Cacti in the graphs\n";
-	echo "    --ip           self explanatory (can also be a FQDN)\n";
-	echo "   (either one or both fields can be used and may be regex)\n\n";
-	echo "Optional:\n";
-	echo "    -confirm       confirms that you wish to remove matches\n\n";
-	echo "List Options:\n";
-	echo "    --quiet - batch mode value return\n\n";
+	print "\nusage: remove_device.php --description=[description] --ip=[IP]\n";
+	print "    [--confirm] [--quiet]\n\n";
+	print "Required:\n";
+	print "    --description  the name that will be displayed by Cacti in the graphs\n";
+	print "    --ip           self explanatory (can also be a FQDN)\n";
+	print "   (either one or both fields can be used and may be regex)\n\n";
+	print "Optional:\n";
+	print "    -confirm       confirms that you wish to remove matches\n\n";
+	print "List Options:\n";
+	print "    --quiet - batch mode value return\n\n";
 }
 
 function preg_array_key_match($needle, $haystack) {
@@ -217,17 +206,17 @@ function preg_array_key_match($needle, $haystack) {
 	}
 
 	if ($debug) {
-		echo "Attempting to match against '$needle' against ".sizeof($haystack)." entries\n";
+		print "Attempting to match against '$needle' against ".cacti_sizeof($haystack)." entries\n";
 	}
 
 	foreach ($haystack as $str => $value) {
 		if ($debug) {
-			echo " - Key $str => Value $value\n";
+			print " - Key $str => Value $value\n";
 		}
 
 		if (preg_match ($needle, $str, $m)) {
 			if ($debug) {
-				echo "   + $str: $value\n";
+				print "   + $str: $value\n";
 			}
 			$matches[] = $value;
 		}
