@@ -23,22 +23,16 @@
  +-------------------------------------------------------------------------+
 */
 
-/* do NOT run this script through a web browser */
-if (!isset($_SERVER["argv"][0]) || isset($_SERVER['REQUEST_METHOD'])  || isset($_SERVER['REMOTE_ADDR'])) {
-	die("<br><strong>This script is only meant to run at the command line.</strong>");
-}
+require(__DIR__ . '/../include/cli_check.php');
 
-$no_http_headers = true;
-$proceed         = false;
-
-include(dirname(__FILE__) . "/../include/global.php");
+$hostId  = NULL;
+$proceed = false;
 
 /* process calling arguments */
-$parms = $_SERVER["argv"];
+$parms = $_SERVER['argv'];
 array_shift($parms);
-$hostId = NULL;
 
-if (sizeof($parms)) {
+if (cacti_sizeof($parms)) {
 	foreach($parms as $parameter) {
 		if (strpos($parameter, '=')) {
 			list($arg, $value) = explode('=', $parameter);
@@ -56,18 +50,18 @@ if (sizeof($parms)) {
 			case '-V':
 			case '-v':
 				display_version();
-				exit;
+				exit(0);
 			case '--help':
 			case '-H':
 			case '-h':
 				display_help();
-				exit;
+				exit(0);
 			case '--host-id':
 			case '--hostId':
 				$hostId = $value;
 				break;
 			default:
-				echo "ERROR: Invalid Argument: ($arg)\n\n";
+				print "ERROR: Invalid Argument: ($arg)\n\n";
 				display_help();
 				exit(1);
 		}
@@ -75,7 +69,7 @@ if (sizeof($parms)) {
 }
 
 if ($proceed == false) {
-	echo "\nFATAL: You Must Explicitally Instruct This Script to Proceed with the '--proceed' Option\n\n";
+	print "\nFATAL: You Must Explicitally Instruct This Script to Proceed with the '--proceed' Option\n\n";
 	display_help();
 	exit -1;
 }
@@ -93,7 +87,7 @@ if ($poller_running == "1") {
 	/* turn on the poller */
 	enable_poller();
 
-	echo "FATAL: The Poller is Currently Running\n";
+	print "FATAL: The Poller is Currently Running\n";
 	exit -4;
 }
 
@@ -125,15 +119,15 @@ foreach ($data_sources as $info) {
 	if (!is_dir($new_base_path)) {
 		/* see if we can create the dirctory for the new file */
 		if (mkdir($new_base_path, 0775)) {
-			echo "NOTE: New Directory '$new_base_path' Created for RRD Files\n";
+			print "NOTE: New Directory '$new_base_path' Created for RRD Files\n";
 			if ($config['cacti_server_os'] != 'win32') {
 				if (chown($new_base_path, $owner_id) && chgrp($new_base_path, $group_id)) {
-					echo "NOTE: New Directory '$new_base_path' Permissions Set\n";
+					print "NOTE: New Directory '$new_base_path' Permissions Set\n";
 				} else {
 					/* turn on the poller */
 					enable_poller();
 
-					echo "FATAL: Could not Set Permissions for Directory '$new_base_path'\n";
+					print "FATAL: Could not Set Permissions for Directory '$new_base_path'\n";
 					exit -5;
 				}
 			}
@@ -141,7 +135,7 @@ foreach ($data_sources as $info) {
 			/* turn on the poller */
 			enable_poller();
 
-			echo "FATAL: Could NOT Make New Directory '$new_base_path'\n";
+			print "FATAL: Could NOT Make New Directory '$new_base_path'\n";
 			exit -1;
 		}
 	}
@@ -150,22 +144,22 @@ foreach ($data_sources as $info) {
 	if (!file_exists($old_rrd_path)) {
 		$warn_count++;
 
-		echo "WARNING: Legacy RRA Path '$old_rrd_path' Does not exist, Skipping\n";
+		print "WARNING: Legacy RRA Path '$old_rrd_path' Does not exist, Skipping\n";
 
 		/* alter database */
 		update_database($info);
 	} elseif (link($old_rrd_path, $new_rrd_path)) {
 		$done_count++;
 
-		echo "NOTE: HardLink Complete:'" . $old_rrd_path . "' -> '" . $new_rrd_path . "'\n";
+		print "NOTE: HardLink Complete:'" . $old_rrd_path . "' -> '" . $new_rrd_path . "'\n";
 		if ($config['cacti_server_os'] != 'win32') {
 			if (chown($new_rrd_path, $owner_id) && chgrp($new_rrd_path, $group_id)) {
-				echo "NOTE: Permissions set for '$new_rrd_path'\n";
+				print "NOTE: Permissions set for '$new_rrd_path'\n";
 			} else {
 				/* turn on the poller */
 				enable_poller();
 
-				echo "FATAL: Could not Set Permissions for File '$new_rrd_path'\n";
+				print "FATAL: Could not Set Permissions for File '$new_rrd_path'\n";
 				exit -6;
 			}
 		}
@@ -174,19 +168,19 @@ foreach ($data_sources as $info) {
 		update_database($info);
 
 		if (unlink($old_rrd_path)) {
-			echo "NOTE: Old File '$old_rrd_path' Removed\n";
+			print "NOTE: Old File '$old_rrd_path' Removed\n";
 		} else {
 			/* turn on the poller */
 			enable_poller();
 
-			echo "FATAL: Old File '$old_rrd_path' Could not be removed\n";
+			print "FATAL: Old File '$old_rrd_path' Could not be removed\n";
 			exit -2;
 		}
 	} else {
 		/* turn on the poller */
 		enable_poller();
 
-		echo "FATAL: Could not Copy RRD File '$old_rrd_path' to '$new_rrd_path'\n";
+		print "FATAL: Could not Copy RRD File '$old_rrd_path' to '$new_rrd_path'\n";
 		exit -3;
 	}
 }
@@ -194,7 +188,7 @@ foreach ($data_sources as $info) {
 /* finally re-enable the poller */
 enable_poller();
 
-echo "NOTE: Process Complete, '$done_count' Completed, '$warn_count' Skipped\n";
+print "NOTE: Process Complete, '$done_count' Completed, '$warn_count' Skipped\n";
 
 /* update database */
 function update_database($info) {
@@ -208,7 +202,7 @@ function update_database($info) {
 		SET data_source_path='" . $info['new_data_source_path'] . "'
 		WHERE local_data_id=" . $info['local_data_id']);
 
-	echo "NOTE: Database Changes Complete for File '" . $info['new_rrd_path'] . "'\n";
+	print "NOTE: Database Changes Complete for File '" . $info['new_rrd_path'] . "'\n";
 }
 
 /* turn on the poller */
@@ -223,35 +217,35 @@ function disable_poller() {
 
 /*  display_version - displays version information */
 function display_version() {
-	$version = get_cacti_version();
-	echo "Cacti Structured Paths Creation Utility, Version $version, " . COPYRIGHT_YEARS . "\n";
+	$version = get_cacti_cli_version();
+	print "Cacti Structured Paths Creation Utility, Version $version, " . COPYRIGHT_YEARS . "\n";
 }
 
 function display_help() {
 	display_version();
 
-	echo "\nusage: structure_rra_paths.php [--host-id=N] [--proceed] [--version|-V|-v] [--help|-H|-h]\n\n"; 
-	echo "A simple interactive command line utility that converts a Cacti system from using\n";
-	echo "legacy RRA paths to using structured RRA paths with the following\n";
-	echo "naming convention: <path_rra>/host_id/local_data_id.rrd\n\n";
-	echo "This utility is designed for very large Cacti systems.\n\n";
-	echo "On Linux OS, superuser is required to apply file ownership.\n\n";
-	echo "The utility follows the process below:\n";
-	echo "  1) Disables the Cacti Poller\n";
-	echo "  2) Checks for a Running Poller.\n\n";
-	echo "If it Finds a Running Poller, it will:\n";
-	echo "  1) Re-enable the Poller\n";
-	echo "  2) Exit\n\n";
-	echo "Else, it will:\n";
-	echo "  1) Enable Structured Paths in the Console (Settings->Paths)\n\n";
-	echo "Then, for Each File, it will:\n";
-	echo "  1) Create the Structured Path, if Necessary\n";
-	echo "  2) Copy the File to the Strucured Path Using the New Name\n";
-	echo "  3) Alter the two Database Tables Required\n";
-	echo "  4) Remove the Old File\n\n";
-	echo "Once all Files are Complete, it will\n";
-	echo "  1) Re-enable the Cacti Poller\n\n";
-	echo "If the utility encounters a problem along the way, it will:\n";
-	echo "  1) Re-enable the poller\n";
-	echo "  2) Exit\n\n";
+	print "\nusage: structure_rra_paths.php [--host-id=N] [--proceed] [--version|-V|-v] [--help|-H|-h]\n\n"; 
+	print "A simple interactive command line utility that converts a Cacti system from using\n";
+	print "legacy RRA paths to using structured RRA paths with the following\n";
+	print "naming convention: <path_rra>/host_id/local_data_id.rrd\n\n";
+	print "This utility is designed for very large Cacti systems.\n\n";
+	print "On Linux OS, superuser is required to apply file ownership.\n\n";
+	print "The utility follows the process below:\n";
+	print "  1) Disables the Cacti Poller\n";
+	print "  2) Checks for a Running Poller.\n\n";
+	print "If it Finds a Running Poller, it will:\n";
+	print "  1) Re-enable the Poller\n";
+	print "  2) Exit\n\n";
+	print "Else, it will:\n";
+	print "  1) Enable Structured Paths in the Console (Settings->Paths)\n\n";
+	print "Then, for Each File, it will:\n";
+	print "  1) Create the Structured Path, if Necessary\n";
+	print "  2) Copy the File to the Strucured Path Using the New Name\n";
+	print "  3) Alter the two Database Tables Required\n";
+	print "  4) Remove the Old File\n\n";
+	print "Once all Files are Complete, it will\n";
+	print "  1) Re-enable the Cacti Poller\n\n";
+	print "If the utility encounters a problem along the way, it will:\n";
+	print "  1) Re-enable the poller\n";
+	print "  2) Exit\n\n";
 }
