@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2017 The Cacti Group                                 |
+ | Copyright (C) 2004-2018 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -25,12 +25,13 @@
 $guest_account=true;
 
 include('./include/auth.php');
-include_once('./lib/utility.php');
 include_once('./lib/clog_webapi.php');
+include_once('./lib/poller.php');
+include_once('./lib/utility.php');
 
 /* check edit/alter permissions */
 if (!clog_admin()) {
-	echo __('FATAL: YOU DO NO HAVE ACCESS TO THIS AREA OF CACTI');
+	echo __('FATAL: YOU DO NOT HAVE ACCESS TO THIS AREA OF CACTI');
 	exit;
 }
 
