@@ -22,7 +22,7 @@
  +-------------------------------------------------------------------------+
 */
 
-/* tick use required as of PHP 4.3.0 to accomodate signal handling */
+// tick use required as of PHP 4.3.0 to accomodate signal handling
 declare(ticks = 1);
 
 function sig_handler($signo) {
@@ -31,18 +31,18 @@ function sig_handler($signo) {
 		case SIGINT:
 			cacti_log('WARNING: Cacti Poller process terminated by user', true, 'POLLER');
 
-			/* record the process as having completed */
+			// record the process as having completed
 			record_cmdphp_done();
 			db_close();
 
 			exit;
 			break;
 		default:
-			/* ignore all other signals */
+			// ignore all other signals
 	}
 }
 
-/* function to assist in logging */
+// function to assist in logging
 function debug_level($host_id, $level) {
 	static $debug_levels = array();
 
@@ -59,29 +59,33 @@ function debug_level($host_id, $level) {
 	}
 }
 
-include(dirname(__FILE__) . '/include/global.php');
-include_once($config['base_path'] . '/lib/snmp.php');
-include_once($config['base_path'] . '/lib/poller.php');
-include_once($config['base_path'] . '/lib/rrd.php');
-include_once($config['base_path'] . '/lib/ping.php');
-include_once($config['library_path'] . '/variables.php');
+require_once(__DIR__ . '/include/cli_check.php');
+require_once($config['base_path'] . '/lib/snmp.php');
+require_once($config['base_path'] . '/lib/poller.php');
+require_once($config['base_path'] . '/lib/rrd.php');
+require_once($config['base_path'] . '/lib/ping.php');
 
-/* let the poller server know about cmd.php being finished */
+// let the poller server know about cmd.php being finished
 function record_cmdphp_done($pid = '') {
-	global $poller_id;
+	global $poller_id, $poller_db_cnn_id;
 
 	if ($pid == '') $pid = getmypid();
 
-	db_execute_prepared('UPDATE poller_time SET end_time=NOW() WHERE poller_id = ? AND pid = ?', array($poller_id, $pid));
+	db_execute_prepared('UPDATE poller_time
+		SET end_time=NOW()
+		WHERE poller_id = ?
+		AND pid = ?',
+		array($poller_id, $pid), true, $poller_db_cnn_id);
 }
 
-/* let cacti processes know that a poller has started */
+// let cacti processes know that a poller has started
 function record_cmdphp_started() {
-	global $poller_id;
+	global $poller_id, $poller_db_cnn_id;
 
 	db_execute_prepared("INSERT INTO poller_time
 		(poller_id, pid, start_time, end_time)
-		VALUES (?, ?, NOW(), '0000-00-00 00:00:00')", array($poller_id, getmypid()));
+		VALUES (?, ?, NOW(), '0000-00-00 00:00:00')",
+		array($poller_id, getmypid()), true, $poller_db_cnn_id);
 }
 
 function open_snmp_session($host_id, &$item) {
@@ -104,12 +108,31 @@ function open_snmp_session($host_id, &$item) {
 	}
 }
 
+function get_max_column_width() {
+	$pcol_data = db_fetch_row("SHOW COLUMNS FROM poller_output WHERE Field='output'");
+	$bcol_data = db_fetch_row("SHOW COLUMNS FROM poller_output_boost WHERE Field='output'");
+
+	if (isset($pcol_data['Type'])) {
+		$pcol = $pcol_data['Type'];
+		$data = explode('(', $pcol);
+		$pmax  = trim($data[1], ')');
+	}
+
+	if (cacti_sizeof($bcol_data)) {
+		$bcol = $bcol_data['Type'];
+		$data = explode('(', $bcol);
+		$bmax  = trim($data[1], ')');
+	}
+
+	return min($pmax, $bmax);
+}
+
 function display_version() {
 	$version = get_cacti_version();
 	echo "Cacti Legacy Host Data Collector, Version $version, " . COPYRIGHT_YEARS . "\n";
 }
 
-/*	display_help - displays the usage of the function */
+//	display_help - displays the usage of the function
 function display_help () {
 	display_version();
 
@@ -136,19 +159,14 @@ function debug($message) {
 	}
 }
 
-/* do NOT run this script through a web browser */
-if (!isset($_SERVER['argv'][0]) || isset($_SERVER['REQUEST_METHOD'])  || isset($_SERVER['REMOTE_ADDR'])) {
-	die('<br>This script is only meant to run at the command line.');
-}
-
-global $poller_id, $sessions, $downhosts;
+global $poller_id, $sessions, $downhosts, $remote_db_cnn_id;
 
 ini_set('max_execution_time', '0');
 ini_set('memory_limit', '512M');
 
 $no_http_headers = true;
 
-/* process calling arguments */
+// process calling arguments
 $parms = $_SERVER['argv'];
 array_shift($parms);
 
@@ -159,8 +177,9 @@ $debug     = false;
 $mibs      = false;
 $mode      = 'online';
 $poller_id = $config['poller_id'];
+$maxwidth  = get_max_column_width();
 
-if (sizeof($parms)) {
+if (cacti_sizeof($parms)) {
 	foreach($parms as $parameter) {
 		if (strpos($parameter, '=')) {
 			list($arg, $value) = explode('=', $parameter);
@@ -214,6 +233,14 @@ if (sizeof($parms)) {
 	}
 }
 
+global $poller_db_cnn_id, $remote_db_cnn_id;
+
+if ($config['poller_id'] > 1 && $config['connection'] == 'online') {
+	$poller_db_cnn_id = $remote_db_cnn_id;
+} else {
+	$poller_db_cnn_id = false;
+}
+
 if ($first == NULL || $last == NULL ) {
 	cacti_log('FATAL: You must either a host range, or no range at all using --first=N --last=N syntax!', true, 'POLLER');
 	exit(-1);
@@ -228,40 +255,42 @@ if ($first == NULL || $last == NULL ) {
 	exit(-1);
 }
 
-/* verify the poller_id */
+// verify the poller_id
 if (!is_numeric($poller_id) || $poller_id < 1) {
 	cacti_log('FATAL: The poller needs to be a positive numeric value', true, 'POLLER');
 	exit(-1);
-} else {
-	$exists = db_fetch_cell_prepared('SELECT COUNT(*) FROM host WHERE poller_id = ?', array($poller_id));
-
-	if (empty($exists)) {
-		cacti_log('FATAL: No devices matching this poller exist on the system', true, 'POLLER');
-		record_cmdphp_done();
-		db_close();
-		exit(-1);
-	}
 }
 
-/* notify cacti processes that a poller is running */
+// notify cacti processes that a poller is running
 record_cmdphp_started();
 
-/* install signal handlers for UNIX only */
+$exists = db_fetch_cell_prepared('SELECT COUNT(*)
+	FROM host
+	WHERE poller_id = ?',
+	array($poller_id));
+
+if (empty($exists)) {
+	record_cmdphp_done();
+	db_close();
+	exit(-1);
+}
+
+// install signal handlers for UNIX only
 if (function_exists('pcntl_signal')) {
 	pcntl_signal(SIGTERM, 'sig_handler');
 	pcntl_signal(SIGINT, 'sig_handler');
 }
 
-/* record the start time */
+// record the start time
 $start = microtime(true);
 
-/* initialize the polling items */
+// initialize the polling items
 $polling_items = array();
 
-/* determine how often the poller runs from settings */
+// determine how often the poller runs from settings
 $polling_interval = read_config_option('poller_interval');
 
-/* check arguments */
+// check arguments
 if ($allhost) {
 	if (isset($polling_interval)) {
 		$polling_items = db_fetch_assoc_prepared('SELECT ' . SQL_NO_CACHE . ' *
@@ -293,7 +322,7 @@ if ($allhost) {
 
 	$print_data_to_stdout = true;
 
-	/* get the number of polling items from the database */
+	// get the number of polling items from the database
 	$hosts = db_fetch_assoc_prepared('SELECT ' . SQL_NO_CACHE . ' *
 		FROM host
 		WHERE poller_id = ?
@@ -301,12 +330,12 @@ if ($allhost) {
 		ORDER BY id',
 		array($poller_id));
 
-	/* rework the hosts array to be searchable */
+	// rework the hosts array to be searchable
 	$hosts = array_rekey($hosts, 'id', $host_struc);
 
-	$host_count = sizeof($hosts);
+	$host_count = cacti_sizeof($hosts);
 
-	/* setup next polling interval */
+	// setup next polling interval
 	if (isset($polling_interval)) {
 		db_execute_prepared('UPDATE poller_item
 			SET rrd_next_step = rrd_next_step - ?
@@ -322,7 +351,7 @@ if ($allhost) {
 } else {
 	$print_data_to_stdout = false;
 	if ($first <= $last) {
-		/* address potential exploits */
+		// address potential exploits
 		input_validate_input_number($first);
 		input_validate_input_number($last);
 
@@ -336,7 +365,7 @@ if ($allhost) {
 			array($poller_id, $first, $last));
 
 		$hosts      = array_rekey($hosts, 'id', $host_struc);
-		$host_count = sizeof($hosts);
+		$host_count = cacti_sizeof($hosts);
 
 		if (isset($polling_interval)) {
 			$polling_items = db_fetch_assoc_prepared('SELECT ' . SQL_NO_CACHE . ' *
@@ -357,7 +386,7 @@ if ($allhost) {
 				AND rrd_next_step <= 0',
 				array($poller_id, POLLER_ACTION_SCRIPT_PHP, POLLER_ACTION_SCRIPT_PHP_COUNT, $first, $last));
 
-			/* setup next polling interval */
+			// setup next polling interval
 			db_execute_prepared('UPDATE poller_item
 				SET rrd_next_step = rrd_next_step - ?
 				WHERE poller_id = ?
@@ -394,14 +423,14 @@ if ($allhost) {
 
 		cacti_log('ERROR: Invalid Arguments.  This rist argument must be less than or equal to the first.', false, 'POLLER');
 
-		/* record the process as having completed */
+		// record the process as having completed
 		record_cmdphp_done();
 		db_close();
 		exit('-1');
 	}
 }
 
-if ((sizeof($polling_items) > 0) && (read_config_option('poller_enabled') == 'on')) {
+if ((cacti_sizeof($polling_items) > 0) && (read_config_option('poller_enabled') == 'on')) {
 	$failure_type = '';
 	$host_down    = false;
 	$new_host     = true;
@@ -410,11 +439,14 @@ if ((sizeof($polling_items) > 0) && (read_config_option('poller_enabled') == 'on
 	$output_array = array();
 	$output_count = 0;
 	$error_ds     = array();
+	$width_dses   = array();
 
-	/* create new ping socket for host pinging */
+	// create new ping socket for host pinging
 	$ping = new Net_Ping;
 
-	/* startup Cacti php polling server and include the include file for script processing */
+	/* startup Cacti php polling server and include the
+	 * include file for script processing
+	 */
 	if ($script_server_calls > 0) {
 		$cactides = array(
 			0 => array('pipe', 'r'), // stdin is a pipe that the child will read from
@@ -441,17 +473,17 @@ if ((sizeof($polling_items) > 0) && (read_config_option('poller_enabled') == 'on
 		if ($current_host != $last_host) {
 			$new_host = true;
 
-			/* assume the host is up */
+			// assume the host is up
 			$host_down = false;
 
-			/* assume we don't have to spike prevent */
+			// assume we don't have to spike prevent
 			$set_spike_kill = false;
 
 			$host_update_time = date('Y-m-d H:i:s'); // for poller update time
 
 			if ($last_host != '') {
-				if (sizeof($error_ds)) {
-					cacti_log('WARNING: Invalid Response(s), Errors[' . sizeof($error_ds) . '] Device[' . $last_host . '] Thread[1] DS[' . implode(', ', $error_ds) . ']', false, 'POLLER');
+				if (cacti_sizeof($error_ds)) {
+					cacti_log('WARNING: Invalid Response(s), Errors[' . cacti_sizeof($error_ds) . '] Device[' . $last_host . '] Thread[1] DS[' . implode(', ', $error_ds) . ']', false, 'POLLER');
 				}
 
 				$error_ds = array();
@@ -464,7 +496,7 @@ if ((sizeof($polling_items) > 0) && (read_config_option('poller_enabled') == 'on
 			$ping->host = $item;
 			$ping->port = $hosts[$host_id]['ping_port'];
 
-			/* perform the appropriate ping check of the host */
+			// perform the appropriate ping check of the host
 			if ($ping->ping($hosts[$host_id]['availability_method'], $hosts[$host_id]['ping_method'],
 				$hosts[$host_id]['ping_timeout'], $hosts[$host_id]['ping_retries'])) {
 				$host_down = false;
@@ -483,35 +515,38 @@ if ((sizeof($polling_items) > 0) && (read_config_option('poller_enabled') == 'on
 			}
 
 			if (!$host_down) {
-				/* do the reindex check for this host */
+				// do the reindex check for this host
 				$reindex = db_fetch_assoc_prepared('SELECT ' . SQL_NO_CACHE . ' pr.data_query_id, pr.action,
 					pr.op, pr.assert_value, pr.arg1
 					FROM poller_reindex AS pr
 					WHERE pr.host_id=?',
 					array($item['host_id']));
 
-				if (sizeof($reindex) && !$host_down) {
-					cacti_log("Device[$host_id] RECACHE: Processing " . sizeof($reindex) . " items in the auto reindex cache for '" . $item['hostname'] . "'.", $print_data_to_stdout, 'POLLER', debug_level($host_id, POLLER_VERBOSITY_DEBUG));
+				if (cacti_sizeof($reindex) && !$host_down) {
+					cacti_log("Device[$host_id] RECACHE: Processing " . cacti_sizeof($reindex) . " items in the auto reindex cache for '" . $item['hostname'] . "'.", $print_data_to_stdout, 'POLLER', debug_level($host_id, POLLER_VERBOSITY_DEBUG));
 
 					foreach ($reindex as $index_item) {
 						$assert_fail = false;
 
-						/* do the check */
+
+						// do the check
 						switch ($index_item['action']) {
 
-						case POLLER_ACTION_SNMP: /* snmp */
+						case POLLER_ACTION_SNMP: // snmp
 							open_snmp_session($host_id, $item);
 
+
 							if (isset($sessions[$host_id . '_' . $item['snmp_version'] . '_' . $item['snmp_port']])) {
-								$output = cacti_snmp_session_get($sessions[$host_id . '_' . $item['snmp_version'] . '_' . $item['snmp_port']], $index_item['arg1']);
+								$sessions[$host_id . '_' . $item['snmp_version'] . '_' . $item['snmp_port']]->quick_print = true;
+								$output = cacti_snmp_session_get($sessions[$host_id . '_' . $item['snmp_version'] . '_' . $item['snmp_port']], $index_item['arg1'], true);
 							} else {
 								$output = 'U';
 							}
 
-							cacti_log("Device[$host_id] RECACHE DQ[" . $index_item['data_query_id'] . '] OID: ' . $index_item['arg1'] . ', output: ' . $output, $print_data_to_stdout, 'POLLER', debug_level($host_id, POLLER_VERBOSITY_MEDIUM));
+							cacti_log("Device[$host_id] DQ[" . $index_item['data_query_id'] . '] RECACHE OID: ' . $index_item['arg1'] . ', (assert:' . $index_item['assert_value'] . ' ' . $index_item['op'] . ' output:' . $output . ')', $print_data_to_stdout, 'POLLER', debug_level($host_id, POLLER_VERBOSITY_MEDIUM));
 
 							break;
-						case POLLER_ACTION_SCRIPT: /* script (popen) */
+						case POLLER_ACTION_SCRIPT: // script (popen)
 							$output = trim(exec_poll($index_item['arg1']));
 
 							if (!is_numeric($output)) {
@@ -522,14 +557,14 @@ if ((sizeof($polling_items) > 0) && (read_config_option('poller_enabled') == 'on
 										$strout = strlen($output);
 									}
 
-									cacti_log("Device[$host_id] RECACHE DQ[" . $index_item['data_query_id'] . '] Warning: Result from Script not valid. Partial Result: ' . substr($output, 0, $strout), $print_data_to_stdout, 'POLLER');
+									cacti_log("Device[$host_id] DQ[" . $index_item['data_query_id'] . '] RECACHE Warning: Result from Script not valid. Partial Result: ' . substr($output, 0, $strout), $print_data_to_stdout, 'POLLER');
 								}
 							}
 
-							cacti_log("Device[$host_id] RECACHE DQ[" . $index_item['data_query_id'] . '] Script: ' . $index_item['arg1'] . ", output: $output", $print_data_to_stdout, 'POLLER', debug_level($host_id, POLLER_VERBOSITY_MEDIUM));
+							cacti_log("Device[$host_id] DQ[" . $index_item['data_query_id'] . '] RECACHE CMD: ' . $index_item['arg1'] . ", output: $output", $print_data_to_stdout, 'POLLER', debug_level($host_id, POLLER_VERBOSITY_MEDIUM));
 
 							break;
-						case POLLER_ACTION_SCRIPT_PHP: /* script (php script server) */
+						case POLLER_ACTION_SCRIPT_PHP: // script (php script server)
 							$output = trim(str_replace("\n", '', exec_poll_php($index_item['arg1'], $using_proc_function, $pipes, $cactiphp)));
 
 							if (!is_numeric($output)) {
@@ -540,77 +575,73 @@ if ((sizeof($polling_items) > 0) && (read_config_option('poller_enabled') == 'on
 										$strout = strlen($output);
 									}
 
-									cacti_log("Device[$host_id] RECACHE DQ[" . $index_item['data_query_id'] . '] WARNING: Result from Script Server not valid. Partial Result: ' . substr($output, 0, $strout), $print_data_to_stdout, 'POLLER');
+									cacti_log("Device[$host_id] DQ[" . $index_item['data_query_id'] . '] RECACHE WARNING: Result from Script Server not valid. Partial Result: ' . substr($output, 0, $strout), $print_data_to_stdout, 'POLLER');
 								}
 							}
 
-							cacti_log("Device[$host_id] RECACHE DQ[" . $index_item['data_query_id'] . '] Script Server: ' . $index_item['arg1'] . ", output: $output", $print_data_to_stdout, 'POLLER', debug_level($host_id, POLLER_VERBOSITY_MEDIUM));
+							cacti_log("Device[$host_id] DQ[" . $index_item['data_query_id'] . '] RECACHE SERVER: ' . $index_item['arg1'] . ", output: $output", $print_data_to_stdout, 'POLLER', debug_level($host_id, POLLER_VERBOSITY_MEDIUM));
 
 							break;
-						case POLLER_ACTION_SNMP_COUNT: /* snmp; count items */
+						case POLLER_ACTION_SNMP_COUNT: // snmp; count items
 							open_snmp_session($host_id, $item);
 
 							if (isset($sessions[$host_id . '_' . $item['snmp_version'] . '_' . $item['snmp_port']])) {
-								$output = sizeof(cacti_snmp_session_walk($sessions[$host_id . '_' . $item['snmp_version'] . '_' . $item['snmp_port']], $index_item['arg1']));
+								$output = cacti_sizeof(cacti_snmp_session_walk($sessions[$host_id . '_' . $item['snmp_version'] . '_' . $item['snmp_port']], $index_item['arg1']));
 							} else {
 								$output = 'U';
 							}
 
-							cacti_log("Device[$host_id] RECACHE DQ[" . $index_item['data_query_id'] . '] OID Count: ' . $index_item['arg1'] . ', output: ' . $output, $print_data_to_stdout, 'POLLER', debug_level($host_id, POLLER_VERBOSITY_MEDIUM));
+							cacti_log("Device[$host_id] DQ[" . $index_item['data_query_id'] . '] RECACHE OID COUNT: ' . $index_item['arg1'] . ', output: ' . $output, $print_data_to_stdout, 'POLLER', debug_level($host_id, POLLER_VERBOSITY_MEDIUM));
 
 							break;
-						case POLLER_ACTION_SCRIPT_COUNT: /* script (popen); count items */
-							/* count items found */
+						case POLLER_ACTION_SCRIPT_COUNT: // script (popen); count items
+							// count items found
 							$script_index_array = exec_into_array($index_item['arg1']);
-							$output = sizeof($script_index_array);
+							$output = cacti_sizeof($script_index_array);
 
-							cacti_log("Device[$host_id] RECACHE DQ[" . $index_item['data_query_id'] . '] Script Count: ' . $index_item['arg1'] . ", output: $output", $print_data_to_stdout, 'POLLER', debug_level($host_id, POLLER_VERBOSITY_MEDIUM));
+							cacti_log("Device[$host_id] DQ[" . $index_item['data_query_id'] . '] RECACHE CMD COUNT: ' . $index_item['arg1'] . ", output: $output", $print_data_to_stdout, 'POLLER', debug_level($host_id, POLLER_VERBOSITY_MEDIUM));
 
 							break;
-						case POLLER_ACTION_SCRIPT_PHP_COUNT: /* script (php script server); count items */
+						case POLLER_ACTION_SCRIPT_PHP_COUNT: // script (php script server); count items
 							$output = exec_into_array($index_item['arg1']);
-							$output = sizeof($output);
+							$output = cacti_sizeof($output);
 
-							cacti_log("Device[$host_id] RECACHE DQ[" . $index_item['data_query_id'] . '] Script Server Count: ' . $index_item['arg1'] . ", output: $output", $print_data_to_stdout, 'POLLER', debug_level($host_id, POLLER_VERBOSITY_MEDIUM));
+							cacti_log("Device[$host_id] DQ[" . $index_item['data_query_id'] . '] RECACHE SERVER COUNT: ' . $index_item['arg1'] . ", output: $output", $print_data_to_stdout, 'POLLER', debug_level($host_id, POLLER_VERBOSITY_MEDIUM));
 
 							break;
-						default: /* invalid reindex option */
-							cacti_log("Device[$host_id] RECACHE DQ[" . $index_item['data_query_id'] . '] ERROR: Invalid reindex option: ' . $index_item['action'], $print_data_to_stdout, 'POLLER');
+						default: // invalid reindex option
+							cacti_log("Device[$host_id] DQ[" . $index_item['data_query_id'] . '] RECACHE ERROR: Invalid reindex option: ' . $index_item['action'], $print_data_to_stdout, 'POLLER');
 						}
 
-						/* assert the result with the expected value in the db; recache if the assert fails */
+						/* assert the result with the expected value in the
+						 * db; recache if the assert fails
+						 */
 						/* TODO: remove magic ":" from poller_command["command"]; this may interfere with scripts */
 						if (($index_item['op'] == '=') && ($index_item['assert_value'] != trim($output))) {
-							cacti_log("ASSERT: '" . $index_item['assert_value'] . '=' . trim($output) .
-								"' failed. Recaching host '" . $item['hostname'] .
-								"', data query #" . $index_item['data_query_id'], $print_data_to_stdout, 'POLLER');
+							cacti_log("Device[$host_id] HT[1] DQ[" . $index_item['data_query_id'] . "] RECACHE ASSERT FAILED '" . $index_item['assert_value'] . '=' . trim($output), $print_data_to_stdout, 'POLLER');
 
 							db_execute_prepared('REPLACE INTO poller_command
 								(poller_id, time, action, command)
 								VALUES (?, NOW(), ?, ?)',
-								array($poller_id, POLLER_COMMAND_REINDEX, $item['host_id'] . ':' . $index_item['data_query_id']));
+								array($poller_id, POLLER_COMMAND_REINDEX, $item['host_id'] . ':' . $index_item['data_query_id']), true, $poller_db_cnn_id);
 
 							$assert_fail = true;
-						}else if (($index_item['op'] == '>') && ($index_item['assert_value'] < trim($output))) {
-							cacti_log("ASSERT: '" . $index_item['assert_value'] . '>' . trim($output) .
-								"' failed. Recaching host '" . $item['hostname'] .
-								"', data query #" . $index_item['data_query_id'], $print_data_to_stdout, 'POLLER');
+						} elseif (($index_item['op'] == '>') && ($index_item['assert_value'] < trim($output))) {
+							cacti_log("Device[$host_id] HT[1] DQ[" . $index_item['data_query_id'] . "] RECACHE ASSERT FAILED '" . $index_item['assert_value'] . '>' . trim($output), $print_data_to_stdout, 'POLLER');
 
 							db_execute_prepared('REPLACE INTO poller_command
 								(poller_id, time, action, command)
 								VALUES (?, NOW(), ?, ?)',
-								array($poller_id, POLLER_COMMAND_REINDEX, $item['host_id'] . ':' . $index_item['data_query_id']));
+								array($poller_id, POLLER_COMMAND_REINDEX, $item['host_id'] . ':' . $index_item['data_query_id']), true, $poller_db_cnn_id);
 
 							$assert_fail = true;
-						}else if (($index_item['op'] == '<') && ($index_item['assert_value'] > trim($output))) {
-							cacti_log("ASSERT: '" . $index_item['assert_value'] . '<' . trim($output) .
-								"' failed. Recaching host '" . $item['hostname'] .
-								"', data query #" . $index_item['data_query_id'], $print_data_to_stdout, 'POLLER');
+						} elseif (($index_item['op'] == '<') && ($index_item['assert_value'] > trim($output))) {
+							cacti_log("Device[$host_id] DQ[" . $index_item['data_query_id'] . "] RECACHE ASSERT FAILED '" . $index_item['assert_value'] . '<' . trim($output), $print_data_to_stdout, 'POLLER');
 
 							db_execute_prepared('REPLACE INTO poller_command
 								(poller_id, time, action, command)
 								VALUES (?, NOW(), ?, ?)',
-								array($poller_id, POLLER_COMMAND_REINDEX, $item['host_id'] . ':' . $index_item['data_query_id']));
+								array($poller_id, POLLER_COMMAND_REINDEX, $item['host_id'] . ':' . $index_item['data_query_id']), true, $poller_db_cnn_id);
 
 							$assert_fail = true;
 						}
@@ -627,10 +658,10 @@ if ((sizeof($polling_items) > 0) && (read_config_option('poller_enabled') == 'on
 								AND arg1 = ?',
 								array($output, $host_id, $index_item['data_query_id'], $index_item['arg1']));
 
-							/* spike kill logic */
+							// spike kill logic
 							if (($assert_fail) &&
 								(($index_item['op'] == '<') || ($index_item['arg1'] == '.1.3.6.1.2.1.1.3.0'))) {
-								/* don't spike kill unless we are certain */
+								// don't spike kill unless we are certain
 								if (!empty($output)) {
 									$set_spike_kill = true;
 
@@ -648,7 +679,7 @@ if ((sizeof($polling_items) > 0) && (read_config_option('poller_enabled') == 'on
 
 		if (!$host_down) {
 			switch ($item['action']) {
-			case POLLER_ACTION_SNMP: /* snmp */
+			case POLLER_ACTION_SNMP: // snmp
 				if (($item['snmp_version'] == 0) || (($item['snmp_community'] == '') && ($item['snmp_version'] != 3))) {
 					cacti_log("Device[$host_id] DS[$data_source] ERROR: Invalid SNMP Data Source.  Please either delete it from the database, or correct it.", $print_data_to_stdout, 'POLLER');
 					$output = 'U';
@@ -656,7 +687,7 @@ if ((sizeof($polling_items) > 0) && (read_config_option('poller_enabled') == 'on
 					open_snmp_session($host_id, $item);
 
 					if (isset($sessions[$host_id . '_' . $item['snmp_version'] . '_' . $item['snmp_port']])) {
-						$output = cacti_snmp_session_get($sessions[$host_id . '_' . $item['snmp_version'] . '_' . $item['snmp_port']], $item['arg1']);
+						$output = cacti_snmp_session_get($sessions[$host_id . '_' . $item['snmp_version'] . '_' . $item['snmp_port']], $item['arg1'], true);
 					} else {
 						$output = 'U';
 					}
@@ -680,7 +711,7 @@ if ((sizeof($polling_items) > 0) && (read_config_option('poller_enabled') == 'on
 				cacti_log("Device[$host_id] DS[$data_source] SNMP: v" . $item['snmp_version'] . ': ' . $item['hostname'] . ', dsname: ' . $item['rrd_name'] . ', oid: ' . $item['arg1'] . ", output: $output", $print_data_to_stdout, 'POLLER', debug_level($host_id, POLLER_VERBOSITY_MEDIUM));
 
 				break;
-			case POLLER_ACTION_SCRIPT: /* script (popen) */
+			case POLLER_ACTION_SCRIPT: // script (popen)
 				$output = trim(exec_poll($item['arg1']));
 
 				if (!is_numeric($output)) {
@@ -700,7 +731,7 @@ if ((sizeof($polling_items) > 0) && (read_config_option('poller_enabled') == 'on
 				cacti_log("Device[$host_id] DS[$data_source] CMD: " . $item['arg1'] . ", output: $output", $print_data_to_stdout, 'POLLER', debug_level($host_id, POLLER_VERBOSITY_MEDIUM));
 
 				break;
-			case POLLER_ACTION_SCRIPT_PHP: /* script (php script server) */
+			case POLLER_ACTION_SCRIPT_PHP: // script (php script server)
 				$output = trim(str_replace("\n", '', exec_poll_php($item['arg1'], $using_proc_function, $pipes, $cactiphp)));
 
 				if (!is_numeric($output)) {
@@ -720,17 +751,22 @@ if ((sizeof($polling_items) > 0) && (read_config_option('poller_enabled') == 'on
 				cacti_log("Device[$host_id] DS[$data_source] SERVER: " . $item['arg1'] . ", output: $output", $print_data_to_stdout, 'POLLER', debug_level($host_id, POLLER_VERBOSITY_MEDIUM));
 
 				break;
-			default: /* invalid polling option */
+			default: // invalid polling option
 				$error_ds[$data_source] = $data_source;
 
 				cacti_log("Device[$host_id] DS[$data_source] ERROR: Invalid polling option: " . $item['action'], $stdout, 'POLLER');
-			} /* End Switch */
+			} // end switch
 
 			if (isset($output)) {
-				/* insert a U in place of the actual value if the snmp agent restarts */
+				if (read_config_option('poller_debug') == 'on' && strlen($output) > $maxwidth) {
+					$width_dses[] = $data_source;
+					$width_errors++;
+				}
+
+				// insert a U in place of the actual value if the snmp agent restarts
 				if (($set_spike_kill) && (!substr_count($output, ':'))) {
 					$output_array[] = sprintf('(%d, %s, %s, "U")', $item['local_data_id'], db_qstr($item['rrd_name']), db_qstr($host_update_time));
-				/* otherwise, just insert the value received from the poller */
+				// otherwise, just insert the value received from the poller
 				} else {
 					$output_array[] = sprintf('(%d, %s, %s, %s)', $item['local_data_id'], db_qstr($item['rrd_name']), db_qstr($host_update_time), db_qstr($output));
 				}
@@ -738,12 +774,12 @@ if ((sizeof($polling_items) > 0) && (read_config_option('poller_enabled') == 'on
 				if ($output_count > 1000) {
 					db_execute('INSERT IGNORE INTO poller_output
 						(local_data_id, rrd_name, time, output)
-						VALUES ' . implode(', ', $output_array));
+						VALUES ' . implode(', ', $output_array), true, $poller_db_cnn_id);
 
-					if (read_config_option('boost_redirect') == 'on') {
+					if (read_config_option('boost_redirect') == 'on' && read_config_option('boost_rrd_update_enable') == 'on') {
 						db_execute('INSERT IGNORE INTO poller_output_boost
 							(local_data_id, rrd_name, time, output)
-							VALUES ' . implode(', ', $output_array));
+							VALUES ' . implode(', ', $output_array), true, $poller_db_cnn_id);
 					}
 
 					$output_array = array();
@@ -752,29 +788,33 @@ if ((sizeof($polling_items) > 0) && (read_config_option('poller_enabled') == 'on
 					$output_count++;
 				}
 			}
-		} /* Next Cache Item */
+		}
 
-		/* check for an over running poller */
+		// check for an over running poller
 		$now = microtime(true);
 		if ($now - $start > $polling_interval) {
 			cacti_log('WARNING: cmd.php poller over ran its polling intervale and therefore ending');
 			break;
 		}
-	} /* End foreach */
+	}
 
-	if (sizeof($error_ds)) {
-		cacti_log('WARNING: Invalid Response(s), Errors[' . sizeof($error_ds) . '] Device[' . $last_host . '] Thread[1] DS[' . implode(', ', $error_ds) . ']', false, 'POLLER');
+	if (cacti_sizeof($error_ds)) {
+		cacti_log('WARNING: Invalid Response(s), Errors[' . cacti_sizeof($error_ds) . '] Device[' . $last_host . '] Thread[1] DS[' . implode(', ', $error_ds) . ']', false, 'POLLER');
+	}
+
+	if (cacti_sizeof($width_dses)) {
+		cacti_log('WARNING: Long Responses Errors[' . cacti_sizeof($width_dses) . '] DS[' . implode(', ', $width_dses) . ']', false, 'POLLER');
 	}
 
 	if ($output_count > 0) {
 		db_execute('INSERT IGNORE INTO poller_output
 			(local_data_id, rrd_name, time, output)
-			VALUES ' . implode(', ', $output_array));
+			VALUES ' . implode(', ', $output_array), true, $poller_db_cnn_id);
 
-		if (read_config_option('boost_redirect') == 'on') {
+		if (read_config_option('boost_redirect') == 'on' && read_config_option('boost_rrd_update_enable') == 'on') {
 			db_execute('INSERT IGNORE INTO poller_output_boost
 				(local_data_id, rrd_name, time, output)
-				VALUES ' . implode(', ', $output_array));
+				VALUES ' . implode(', ', $output_array), true, $poller_db_cnn_id);
 		}
 	}
 
@@ -788,7 +828,7 @@ if ((sizeof($polling_items) > 0) && (read_config_option('poller_enabled') == 'on
 		$return_value = proc_close($cactiphp);
 	}
 
-	/* take time and log performance data */
+	// take time and log performance data
 	$end = microtime(true);
 
 	cacti_log(sprintf('Time: %01.4f s, ' .
@@ -802,9 +842,9 @@ if ((sizeof($polling_items) > 0) && (read_config_option('poller_enabled') == 'on
 	cacti_log('NOTE: There are no items in your poller for this polling cycle!', true, 'POLLER', POLLER_VERBOSITY_MEDIUM);
 }
 
-/* record the process as having completed */
+// record the process as having completed
 record_cmdphp_done();
 
-/* close the database connection */
+// close the database connection
 db_close();
 
