@@ -24,6 +24,7 @@
 
 include('./include/auth.php');
 include_once('./lib/data_query.php');
+include_once('./lib/poller.php');
 include_once('./lib/utility.php');
 
 $dq_actions = array(
@@ -172,11 +173,21 @@ function form_save() {
 				/* if the user changed the graph template, go through and delete everything that
 				was associated with the old graph template */
 				if (get_nfilter_request_var('graph_template_id') != get_nfilter_request_var('graph_template_id_prev')) {
-					db_execute_prepared('DELETE FROM snmp_query_graph_rrd_sv WHERE snmp_query_graph_id = ?', array($snmp_query_graph_id));
-					db_execute_prepared('DELETE FROM snmp_query_graph_sv WHERE snmp_query_graph_id = ?', array($snmp_query_graph_id));
+					db_execute_prepared('DELETE
+						FROM snmp_query_graph_rrd_sv
+						WHERE snmp_query_graph_id = ?',
+						array($snmp_query_graph_id));
+
+					db_execute_prepared('DELETE
+						FROM snmp_query_graph_sv
+						WHERE snmp_query_graph_id = ?',
+						array($snmp_query_graph_id));
 				}
 
-				db_execute_prepared('DELETE FROM snmp_query_graph_rrd WHERE snmp_query_graph_id = ?', array($snmp_query_graph_id));
+				db_execute_prepared('DELETE
+					FROM snmp_query_graph_rrd
+					WHERE snmp_query_graph_id = ?',
+					array($snmp_query_graph_id));
 
 				foreach ($_POST as $var => $val) {
 					if (preg_match('/^dsdt_([0-9]+)_([0-9]+)_check/i', $var)) {
@@ -190,7 +201,15 @@ function form_save() {
 						db_execute_prepared('REPLACE INTO snmp_query_graph_rrd
 							(snmp_query_graph_id, data_template_id, data_template_rrd_id, snmp_field_name)
 							VALUES (?, ?, ?, ?)',
-							array($snmp_query_graph_id, $data_template_id, $data_template_rrd_id, get_nfilter_request_var('dsdt_' . $data_template_id . '_' . $data_template_rrd_id . '_snmp_field_output')));
+							array(
+								$snmp_query_graph_id,
+								$data_template_id,
+								$data_template_rrd_id,
+								get_nfilter_request_var('dsdt_' .
+									$data_template_id . '_' .
+									$data_template_rrd_id . '_snmp_field_output')
+							)
+						);
 					}
 				}
 
@@ -213,6 +232,12 @@ function form_save() {
 		get_filter_request_var('graph_template_id');
 		/* ==================================================== */
 
+		if (isset_request_var('header') && get_nfilter_request_var('header') == 'false') {
+			$header = '&header=false';
+		} else {
+			$header = '';
+		}
+
 		if  (isempty_request_var('svg_text')) {
 			raise_message(39);
 			header('Location: data_queries.php?header=false&action=item_edit' . $header . '&id=' . get_request_var('id') . '&snmp_query_id=' . get_request_var('snmp_query_id'));
@@ -232,7 +257,14 @@ function form_save() {
 		db_execute_prepared('INSERT INTO snmp_query_graph_sv
 			(hash, snmp_query_graph_id, sequence, field_name, text)
 			VALUES (?, ?, ?, ?, ?)',
-			array($hash, get_request_var('id'), $sequence, get_nfilter_request_var('svg_field'), get_nfilter_request_var('svg_text')));
+			array(
+				$hash,
+				get_request_var('id'),
+				$sequence,
+				get_nfilter_request_var('svg_field'),
+				get_nfilter_request_var('svg_text')
+			)
+		);
 
 		clear_messages();
 
@@ -250,22 +282,28 @@ function form_save() {
 		get_filter_request_var('graph_template_id');
 		/* ==================================================== */
 
-		if  (isempty_request_var('svds_text')) {
-			raise_message(39);
-			header('Location: data_queries.php?header=false&action=item_edit' . $header . '&id=' . get_request_var('id') . '&snmp_query_id=' . get_request_var('snmp_query_id'));
-			return;
-		} elseif (isempty_request_var('svds_field')) {
-			raise_message(38);
-			header('Location: data_queries.php?header=false&action=item_edit' . $header . '&id=' . get_request_var('id') . '&snmp_query_id=' . get_request_var('snmp_query_id'));
-			return;
+		if (isset_request_var('header') && get_nfilter_request_var('header') == 'false') {
+			$header = '&header=false';
+		} else {
+			$header = '';
 		}
 
 		foreach ($_POST as $var => $val) {
-			if (preg_match('/^svds_([0-9]+)_text/i', $var, $matches)) {
+			if (preg_match('/^svds_([0-9]+)_x/i', $var, $matches)) {
 				/* ================= input validation ================= */
 				input_validate_input_number($matches[1]);
 				/* ==================================================== */
 
+				if  (isempty_request_var('svds_' . $matches[1] . '_text')) {
+					raise_message(39);
+					header('Location: data_queries.php?header=false&action=item_edit' . $header . '&id=' . get_request_var('id') . '&snmp_query_id=' . get_request_var('snmp_query_id'));
+					return;
+				} elseif (isempty_request_var('svds_' . $matches[1] . '_field')) {
+					raise_message(38);
+					header('Location: data_queries.php?header=false&action=item_edit' . $header . '&id=' . get_request_var('id') . '&snmp_query_id=' . get_request_var('snmp_query_id'));
+					return;
+				}
+
 				$sequence = get_sequence(0, 'sequence', 'snmp_query_graph_rrd_sv', 'snmp_query_graph_id=' . get_request_var('id')  . ' AND data_template_id=' . $matches[1] . " AND field_name='" . get_nfilter_request_var('svds_' . $matches[1] . '_field') . "'");
 
 				$hash = get_hash_data_query(0, 'data_query_sv_data_source');
@@ -273,7 +311,14 @@ function form_save() {
 				db_execute_prepared('INSERT INTO snmp_query_graph_rrd_sv
 					(hash, snmp_query_graph_id, data_template_id, sequence, field_name, text)
 					VALUES (?, ?, ?, ?, ?, ?)',
-					array($hash, get_request_var('id'), $matches[1], $sequence, get_nfilter_request_var('svds_' . $matches[1] . '_field'), get_nfilter_request_var('svds_' . $matches[1] . '_text')));
+					array(
+						$hash, get_request_var('id'),
+						$matches[1],
+						$sequence,
+						get_nfilter_request_var('svds_' . $matches[1] . '_field'),
+						get_nfilter_request_var('svds_' . $matches[1] . '_text')
+					)
+				);
 
 				clear_messages();
 
@@ -304,7 +349,7 @@ function form_actions() {
 
 		if ($selected_items != false) {
 			if (get_nfilter_request_var('drp_action') == '1') { /* delete */
-				for ($i=0;($i<count($selected_items));$i++) {
+				for ($i=0;($i<cacti_count($selected_items));$i++) {
 					 data_query_remove($selected_items[$i]);
 				}
 			}
@@ -324,7 +369,12 @@ function form_actions() {
 			input_validate_input_number($matches[1]);
 			/* ==================================================== */
 
-			$dq_list .= '<li>' . html_escape(db_fetch_cell_prepared('SELECT snmp_query.name FROM snmp_query WHERE id = ?', array($matches[1]))) . '</li>';
+			$name = db_fetch_cell_prepared('SELECT name
+				FROM snmp_query
+				WHERE id = ?',
+				array($matches[1]));
+
+			$dq_list .= '<li>' . html_escape($name) . '</li>';
 			$dq_array[$i] = $matches[1];
 
 			$i++;
@@ -337,29 +387,30 @@ function form_actions() {
 
 	html_start_box($dq_actions[get_nfilter_request_var('drp_action')], '60%', '', '3', 'center', '');
 
-	if (isset($dq_array) && sizeof($dq_array)) {
+	if (isset($dq_array) && cacti_sizeof($dq_array)) {
 		if (get_nfilter_request_var('drp_action') == '1') { /* delete */
 			$graphs = array();
 
 			print "<tr>
 				<td class='textArea' class='odd'>
-					<p>" . __n('Click \'Continue\' to delete the following Data Query.', 'Click \'Continue\' to delete following Data Queries.', sizeof($dq_array)) . "</p>
+					<p>" . __n('Click \'Continue\' to delete the following Data Query.', 'Click \'Continue\' to delete following Data Queries.', cacti_sizeof($dq_array)) . "</p>
 					<div class='itemlist'><ul>$dq_list</ul></div>
 				</td>
 			</tr>\n";
 		}
 
-		$save_html = "<input type='button' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __esc('Continue') . "' title='" . __n('Delete Data Query', 'Delete Data Query', sizeof($dq_array)) . "'>";
+		$save_html = "<input type='button' class='ui-button ui-corner-all ui-widget' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' class='ui-button ui-corner-all ui-widget' value='" . __esc('Continue') . "' title='" . __n('Delete Data Query', 'Delete Data Query', cacti_sizeof($dq_array)) . "'>";
 	} else {
-		print "<tr><td class='odd'><span class='textError'>" . __('You must select at least one data query.') . "</span></td></tr>\n";
-		$save_html = "<input type='button' value='" . __esc('Return') . "' onClick='cactiReturnTo()'>";
+		raise_message(40);
+		header('Location: data_queries.php?header=false');
+		exit;
 	}
 
 	print "<tr>
 		<td class='saveRow'>
 			<input type='hidden' name='action' value='actions'>
 			<input type='hidden' name='selected_items' value='" . (isset($dq_array) ? serialize($dq_array) : '') . "'>
-			<input type='hidden' name='drp_action' value='" . get_nfilter_request_var('drp_action') . "'>
+			<input type='hidden' name='drp_action' value='" . html_escape(get_nfilter_request_var('drp_action')) . "'>
 			$save_html
 		</td>
 	</tr>\n";
@@ -398,7 +449,9 @@ function data_query_item_remove_gsv() {
 	get_filter_request_var('id');
 	/* ==================================================== */
 
-	db_execute_prepared('DELETE FROM snmp_query_graph_sv WHERE id = ?', array(get_request_var('id')));
+	db_execute_prepared('DELETE FROM snmp_query_graph_sv
+		WHERE id = ?',
+		array(get_request_var('id')));
 }
 
 function data_query_item_movedown_dssv() {
@@ -477,7 +530,10 @@ function data_query_item_remove_dssv() {
 	get_filter_request_var('id');
 	/* ==================================================== */
 
-	db_execute_prepared('DELETE FROM snmp_query_graph_rrd_sv WHERE id = ?', array(get_request_var('id')));
+	db_execute_prepared('DELETE
+		FROM snmp_query_graph_rrd_sv
+		WHERE id = ?',
+		array(get_request_var('id')));
 }
 
 function data_query_item_remove_confirm() {
@@ -492,7 +548,10 @@ function data_query_item_remove_confirm() {
 
 	html_start_box('', '100%', '', '3', 'center', '');
 
-	$graph_template = db_fetch_row_prepared('SELECT * FROM snmp_query_graph WHERE id = ?', array(get_request_var('id')));
+	$graph_template = db_fetch_row_prepared('SELECT *
+		FROM snmp_query_graph
+		WHERE id = ?',
+		array(get_request_var('id')));
 
 	?>
 	<tr>
@@ -503,8 +562,8 @@ function data_query_item_remove_confirm() {
 	</tr>
 	<tr>
 		<td class='right'>
-			<input id='cancel' type='button' value='<?php print __esc('Cancel');?>' onClick='$("#cdialog").dialog("close");' name='cancel'>
-			<input id='continue' type='button' value='<?php print __esc('Continue');?>' name='continue' title='<?php print __esc('Remove VDEF Item');?>'>
+			<input type='button' class='ui-button ui-corner-all ui-widget' id='cancel' value='<?php print __esc('Cancel');?>' onClick='$("#cdialog").dialog("close");' name='cancel'>
+			<input type='button' class='ui-button ui-corner-all ui-widget' id='continue' value='<?php print __esc('Continue');?>' name='continue' title='<?php print __esc('Remove VDEF Item');?>'>
 		</td>
 	</tr>
 	<?php
@@ -536,10 +595,25 @@ function data_query_item_remove() {
 	get_filter_request_var('id');
 	/* ==================================================== */
 
-	db_execute_prepared('DELETE FROM snmp_query_graph WHERE id = ?', array(get_request_var('id')));
-	db_execute_prepared('DELETE FROM snmp_query_graph_rrd WHERE snmp_query_graph_id = ?', array(get_request_var('id')));
-	db_execute_prepared('DELETE FROM snmp_query_graph_rrd_sv WHERE snmp_query_graph_id = ?', array(get_request_var('id')));
-	db_execute_prepared('DELETE FROM snmp_query_graph_sv WHERE snmp_query_graph_id = ?', array(get_request_var('id')));
+	db_execute_prepared('DELETE
+		FROM snmp_query_graph
+		WHERE id = ?',
+		array(get_request_var('id')));
+
+	db_execute_prepared('DELETE
+		FROM snmp_query_graph_rrd
+		WHERE snmp_query_graph_id = ?',
+		array(get_request_var('id')));
+
+	db_execute_prepared('DELETE
+		FROM snmp_query_graph_rrd_sv
+		WHERE snmp_query_graph_id = ?',
+		array(get_request_var('id')));
+
+	db_execute_prepared('DELETE
+		FROM snmp_query_graph_sv
+		WHERE snmp_query_graph_id = ?',
+		array(get_request_var('id')));
 }
 
 function data_query_item_edit() {
@@ -588,9 +662,7 @@ function data_query_item_edit() {
 	if (!empty($snmp_query_item['id'])) {
 		html_start_box( __('Associated Data Templates'), '100%', '', '3', 'center', '');
 
-		$data_templates = db_fetch_assoc_prepared('SELECT
-			data_template.id,
-			data_template.name
+		$data_templates = db_fetch_assoc_prepared('SELECT data_template.id, data_template.name
 			FROM (data_template, data_template_rrd, graph_templates_item)
 			WHERE graph_templates_item.task_item_id = data_template_rrd.id
 			AND data_template_rrd.data_template_id = data_template.id
@@ -601,14 +673,14 @@ function data_query_item_edit() {
 			ORDER BY data_template.name', array($snmp_query_item['graph_template_id']));
 
 		$i = 0;
-		if (sizeof($data_templates)) {
+		if (cacti_sizeof($data_templates)) {
 			foreach ($data_templates as $data_template) {
 				print "<tr class='tableHeader'>
 						<th class='tableSubHeaderColumn'>" . __('Data Template - %s', $data_template['name']) . '</th>
 					</tr>';
 
-				$data_template_rrds = db_fetch_assoc_prepared('SELECT
-					dtr.id, dtr.data_source_name, sqgr.snmp_field_name, sqgr.snmp_query_graph_id
+				$data_template_rrds = db_fetch_assoc_prepared('SELECT dtr.id, dtr.data_source_name,
+					sqgr.snmp_field_name, sqgr.snmp_query_graph_id
 					FROM data_template_rrd AS dtr
 					LEFT JOIN snmp_query_graph_rrd AS sqgr
 					ON sqgr.data_template_rrd_id = dtr.id
@@ -620,7 +692,7 @@ function data_query_item_edit() {
 					array(get_request_var('id'), $data_template['id'], $data_template['id']));
 
 				$i = 0;
-				if (sizeof($data_template_rrds)) {
+				if (cacti_sizeof($data_template_rrds)) {
 					foreach ($data_template_rrds as $data_template_rrd) {
 						if (empty($data_template_rrd['snmp_query_graph_id'])) {
 							$old_value = '';
@@ -644,7 +716,7 @@ function data_query_item_edit() {
 										$snmp_queries = get_data_query_array(get_request_var('snmp_query_id'));
 										$xml_outputs  = array();
 
-										if (isset($snmp_queries['fields']) && sizeof($snmp_queries['fields'])) {
+										if (isset($snmp_queries['fields']) && cacti_sizeof($snmp_queries['fields'])) {
 											foreach ($snmp_queries['fields'] as $field_name => $field_array) {
 												if ($field_array['direction'] == 'output' || $field_array['direction'] == 'input-output') {
 													$xml_outputs[$field_name] = $field_name . ' (' . $field_array['name'] . ')';
@@ -685,7 +757,7 @@ function data_query_item_edit() {
 		), 2);
 
 		$i = 0;
-		$total_values = sizeof($suggested_values);
+		$total_values = cacti_sizeof($suggested_values);
 		if ($total_values) {
 			foreach ($suggested_values as $suggested_value) {
 				data_query_sv_check_sequences('gr', $suggested_value['snmp_query_graph_id'], $suggested_value['field_name']);
@@ -725,7 +797,7 @@ function data_query_item_edit() {
 					<?php print html_escape($suggested_value['text']);?>
 				</td>
 				<td class='right'>
-					<a class='remover deleteMarker fa fa-remove' title='<?php print html_escape(__('Delete'));?>' href='<?php print html_escape('data_queries.php?action=item_remove_gsv&snmp_query_graph_id=' . get_request_var('id') . '&id=' . $suggested_value['id'] . '&snmp_query_id=' . get_request_var('snmp_query_id'));?>'></a>
+					<a class='remover deleteMarker fa fa-times' title='<?php print html_escape(__('Delete'));?>' href='<?php print html_escape('data_queries.php?action=item_remove_gsv&snmp_query_graph_id=' . get_request_var('id') . '&id=' . $suggested_value['id'] . '&snmp_query_id=' . get_request_var('snmp_query_id'));?>'></a>
 				</td>
 				<?php
 
@@ -746,16 +818,16 @@ function data_query_item_edit() {
 						<?php print __('Field Name');?>
 					</td>
 					<td>
-						<input type='text' id='svg_field' size='15'>
+						<input type='text' class='ui-state-default ui-corner-all' id='svg_field' size='15'>
 					</td>
 					<td class='nowrap'>
 						<?php print __('Suggested Value');?>
 					</td>
 					<td>
-						<input type='text' id='svg_text' size='60'>
+						<input type='text' class='ui-state-default ui-corner-all' id='svg_text' size='60'>
 					</td>
 					<td>
-						<input id='svg_x' type='button' name='svg_x' value='<?php print __esc('Add');?>' title='<?php print __('Add Graph Title Suggested Name');?>'>
+						<input type='button' class='ui-button ui-corner-all ui-widget' id='svg_x' name='svg_x' value='<?php print __esc('Add');?>' title='<?php print __('Add Graph Title Suggested Name');?>'>
 					</td>
 				</tr>
 			</table>
@@ -768,7 +840,7 @@ function data_query_item_edit() {
 		html_start_box( __('Suggested Values - Data Sources'), '100%', '', '3', 'center', '');
 
 		/* suggested values for data templates */
-		if (sizeof($data_templates)) {
+		if (cacti_sizeof($data_templates)) {
 			foreach ($data_templates as $data_template) {
 				$suggested_values = db_fetch_assoc_prepared('SELECT text, field_name, snmp_query_graph_id, id
 					FROM snmp_query_graph_rrd_sv
@@ -783,7 +855,7 @@ function data_query_item_edit() {
 				), 2);
 
 				$i = 0;
-				$total_values = sizeof($suggested_values);
+				$total_values = cacti_sizeof($suggested_values);
 
 				if ($total_values) {
 					$prev_name = '';
@@ -825,7 +897,7 @@ function data_query_item_edit() {
 							<?php print html_escape($suggested_value['text']);?>
 						</td>
 						<td class='right'>
-							<a class='remover deleteMarker fa fa-remove' title='<?php print __('Delete');?>' href='<?php print html_escape('data_queries.php?action=item_remove_dssv&snmp_query_graph_id=' . get_request_var('id') . '&id=' . $suggested_value['id'] . '&snmp_query_id=' . get_request_var('snmp_query_id') . '&data_template_id=' . $data_template['id']);?>'></a>
+							<a class='remover deleteMarker fa fa-times' title='<?php print __('Delete');?>' href='<?php print html_escape('data_queries.php?action=item_remove_dssv&snmp_query_graph_id=' . get_request_var('id') . '&id=' . $suggested_value['id'] . '&snmp_query_id=' . get_request_var('snmp_query_id') . '&data_template_id=' . $data_template['id']);?>'></a>
 						</td>
 						<?php
 
@@ -847,16 +919,16 @@ function data_query_item_edit() {
 								<?php print __('Field Name');?>
 							</td>
 							<td>
-								<input id='svds_field' type='text' name='svds_<?php print $data_template['id'];?>_field' size='15'>
+								<input type='text' class='svds_field ui-state-default ui-corner-all' id='svds_<?php print $data_template['id'];?>_field' name='svds_<?php print $data_template['id'];?>_field' size='15'>
 							</td>
 							<td class='nowrap'>
 								<?php print __('Suggested Value');?>
 							</td>
 							<td>
-								<input id='svds_text' type='text' name='svds_<?php print $data_template['id'];?>_text' size='60'>
+								<input type='text' class='svds_text ui-state-default ui-corner-all' id='svds_<?php print $data_template['id'];?>_text' name='svds_<?php print $data_template['id'];?>_text' size='60'>
 							</td>
 							<td>
-								<input id='svds_x' type='button' name='svds_x' value='<?php print __esc('Add');?>' title='<?php print __('Add Data Source Name Suggested Name');?>'>
+								<input type='button' class='svds_x ui-button ui-corner-all ui-widget' id='svds_<?php print $data_template['id'];?>_x' name='svds_<?php print $data_template['id'];?>_x' value='<?php print __esc('Add');?>' title='<?php print __('Add Data Source Name Suggested Name');?>'>
 							</td>
 						</tr>
 					</table>
@@ -913,10 +985,12 @@ function data_query_item_edit() {
 		});
 	});
 
-	$('input[id="svds_x"]').click(function() {
-		var svds_text_name=$('#svds_text').attr('name');
-		var svds_field_name=$('#svds_field').attr('name');
-		var svds_x_name=$('#svds_x').attr('name');
+	$('input.svds_x').click(function() {
+		var $form = $(this).closest('form');
+		var svds_text_name=$form.find('input.svds_text').attr('name');
+		var svds_field_name=$form.find('input.svds_field').attr('name');
+		var svds_x_name=$form.find('input.svds_x').attr('name');
+
 		var jSON = $.parseJSON('{ ' +
 			'"graph_template_id_prev":"'+graph_template_id_prev + '", ' +
 			'"action":"save", ' +
@@ -927,9 +1001,10 @@ function data_query_item_edit() {
 			'"__csrf_magic":"'+csrfMagicToken+'", ' +
 			'"save_component_snmp_query_item":"1", ' +
 			'"snmp_query_id":"'+$('#snmp_query_id').val() + '", ' +
-			'"'+svds_field_name+'":"'+$('#svds_field').val() + '", ' +
-			'"'+svds_text_name+'":"'+$('#svds_text').val() + '", ' +
-			'"'+svds_x_name+'":"Add" }');
+			'"'+svds_field_name+'":"'+$form.find('input.svds_field').val() + '", ' +
+			'"'+svds_text_name+'":"'+$form.find('input.svds_text').val() + '", ' +
+			'"'+svds_x_name+'":"Add", ' +
+			'"svds_x":"Add" }');
 
 		$.post('data_queries.php', jSON).done(function(data) {
 			$('#main').html(data);
@@ -947,19 +1022,44 @@ function data_query_item_edit() {
    --------------------- */
 
 function data_query_remove($id) {
-	$snmp_query_graph = db_fetch_assoc_prepared('SELECT id FROM snmp_query_graph WHERE snmp_query_id = ?', array($id));
+	$snmp_query_graph = db_fetch_assoc_prepared('SELECT id
+		FROM snmp_query_graph
+		WHERE snmp_query_id = ?',
+		array($id));
 
-	if (sizeof($snmp_query_graph)) {
+	if (cacti_sizeof($snmp_query_graph)) {
 		foreach ($snmp_query_graph as $item) {
-			db_execute_prepared('DELETE FROM snmp_query_graph_rrd WHERE snmp_query_graph_id = ?', array($item['id']));
+			db_execute_prepared('DELETE
+				FROM snmp_query_graph_rrd
+				WHERE snmp_query_graph_id = ?',
+				array($item['id']));
 		}
 	}
 
-	db_execute_prepared('DELETE FROM snmp_query WHERE id = ?', array($id));
-	db_execute_prepared('DELETE FROM snmp_query_graph WHERE snmp_query_id = ?', array($id));
-	db_execute_prepared('DELETE FROM host_template_snmp_query WHERE snmp_query_id = ?', array($id));
-	db_execute_prepared('DELETE FROM host_snmp_query WHERE snmp_query_id = ?', array($id));
-	db_execute_prepared('DELETE FROM host_snmp_cache WHERE snmp_query_id = ?', array($id));
+	db_execute_prepared('DELETE
+		FROM snmp_query
+		WHERE id = ?',
+		array($id));
+
+	db_execute_prepared('DELETE
+		FROM snmp_query_graph
+		WHERE snmp_query_id = ?',
+		array($id));
+
+	db_execute_prepared('DELETE
+		FROM host_template_snmp_query
+		WHERE snmp_query_id = ?',
+		array($id));
+
+	db_execute_prepared('DELETE
+		FROM host_snmp_query
+		WHERE snmp_query_id = ?',
+		array($id));
+
+	db_execute_prepared('DELETE
+		FROM host_snmp_cache
+		WHERE snmp_query_id = ?',
+		array($id));
 
 	update_replication_crc(0, 'poller_replicate_snmp_query_crc');
 }
@@ -982,10 +1082,12 @@ function data_query_edit() {
 
 	html_start_box($header_label, '100%', true, '3', 'center', '');
 
-	draw_edit_form(array(
-		'config' => array('no_form_tag' => true),
-		'fields' => inject_form_variables($fields_data_query_edit, (isset($snmp_query) ? $snmp_query : array()))
-		));
+	draw_edit_form(
+		array(
+			'config' => array('no_form_tag' => true),
+			'fields' => inject_form_variables($fields_data_query_edit, (isset($snmp_query) ? $snmp_query : array()))
+		)
+	);
 
 	html_end_box(false, true);
 
@@ -1026,9 +1128,10 @@ function data_query_edit() {
 			AND gl.graph_template_id = sqg.graph_template_id
 			WHERE sqg.snmp_query_id = ?
 			GROUP BY sqg.id
-			ORDER BY sqg.name', array($snmp_query['id']));
+			ORDER BY sqg.name',
+			array($snmp_query['id']));
 
-		if (sizeof($snmp_query_graphs)) {
+		if (cacti_sizeof($snmp_query_graphs)) {
 			foreach ($snmp_query_graphs as $snmp_query_graph) {
 				form_alternate_row();
 				?>
@@ -1049,11 +1152,11 @@ function data_query_edit() {
 						<?php print $snmp_query_graph['id'];?>
 					</td><?php if ($snmp_query_graph['graphs'] == 0) {?>
 					<td class='right'>
-							<a class='delete deleteMarker fa fa-remove' title='<?php print __('Delete');?>' href='<?php print html_escape('data_queries.php?action=item_remove_confirm&id=' . $snmp_query_graph['id'] . '&snmp_query_id=' . $snmp_query['id']);?>'></a>
+							<a class='delete deleteMarker fa fa-times' title='<?php print __('Delete');?>' href='<?php print html_escape('data_queries.php?action=item_remove_confirm&id=' . $snmp_query_graph['id'] . '&snmp_query_id=' . $snmp_query['id']);?>'></a>
 					</td>
 					<?php } else { ?>
 					<td class='right'>
-							<a class='deleteMarkerDisabled fa fa-remove' title='<?php print __('Mapped Graph Templates with Graphs are read only');?>' href='#'></a>
+							<a class='deleteMarkerDisabled fa fa-times' title='<?php print __('Mapped Graph Templates with Graphs are read only');?>' href='#'></a>
 					</td>
 					<?php } ?>
 				</tr>
@@ -1154,7 +1257,7 @@ function data_query() {
 						<?php print __('Search');?>
 					</td>
 					<td>
-						<input id='filter' type='text' name='filter' size='25' value='<?php print html_escape_request_var('filter');?>'>
+						<input type='text' class='ui-state-default ui-corner-all' id='filter' name='filter' size='25' value='<?php print html_escape_request_var('filter');?>'>
 					</td>
 					<td>
 						<?php print __('Data Queries');?>
@@ -1163,7 +1266,7 @@ function data_query() {
 						<select id='rows' name='rows' onChange='applyFilter()'>
 							<option value='-1'<?php print (get_request_var('rows') == '-1' ? ' selected>':'>') . __('Default');?></option>
 							<?php
-							if (sizeof($item_rows)) {
+							if (cacti_sizeof($item_rows)) {
 								foreach ($item_rows as $key => $value) {
 									print "<option value='" . $key . "'"; if (get_request_var('rows') == $key) { print ' selected'; } print '>' . html_escape($value) . "</option>\n";
 								}
@@ -1173,8 +1276,8 @@ function data_query() {
 					</td>
 					<td>
 						<span>
-							<input type='button' id='refresh' value='<?php print __esc('Go');?>' title='<?php print __esc('Set/Refresh Filters');?>'>
-							<input type='button' id='clear' name='clear' value='<?php print __esc('Clear');?>' title='<?php print __esc('Clear Filters');?>'>
+							<input type='button' class='ui-button ui-corner-all ui-widget' id='refresh' value='<?php print __esc('Go');?>' title='<?php print __esc('Set/Refresh Filters');?>'>
+							<input type='button' class='ui-button ui-corner-all ui-widget' id='clear' name='clear' value='<?php print __esc('Clear');?>' title='<?php print __esc('Clear Filters');?>'>
 						</span>
 					</td>
 				</tr>
@@ -1216,7 +1319,7 @@ function data_query() {
 
 	/* form the 'where' clause for our main sql query */
 	if (get_request_var('filter') != '') {
-		$sql_where = "WHERE (sq.name like '%%" . get_request_var('filter') . "%%' OR di.name like '%%" . get_request_var('filter') . "%%')";
+		$sql_where = "WHERE (sq.name like '%" . get_request_var('filter') . "%' OR di.name like '%" . get_request_var('filter') . "%')";
 	} else {
 		$sql_where = '';
 	}
@@ -1266,7 +1369,7 @@ function data_query() {
 	html_header_sort_checkbox($display_text, get_request_var('sort_column'), get_request_var('sort_direction'), false);
 
 	$i = 0;
-	if (sizeof($snmp_queries)) {
+	if (cacti_sizeof($snmp_queries)) {
 		foreach ($snmp_queries as $snmp_query) {
 			if ($snmp_query['graphs'] == 0 && $snmp_query['templates'] == 0) {
 				$disabled = false;
@@ -1276,10 +1379,10 @@ function data_query() {
 
 			form_alternate_row('line' . $snmp_query['id'], true, $disabled);
 			form_selectable_cell(filter_value($snmp_query['name'], get_request_var('filter'), 'data_queries.php?action=edit&id=' . $snmp_query['id']), $snmp_query['id']);
-			form_selectable_cell($snmp_query['id'], $snmp_query['id'], '', 'text-align:right;');
-			form_selectable_cell($disabled ? __('No') : __('Yes'), $snmp_query['id'], '', 'text-align:right');
-			form_selectable_cell(number_format_i18n($snmp_query['graphs'], '-1'), $snmp_query['id'], '', 'text-align:right');
-			form_selectable_cell(number_format_i18n($snmp_query['templates'], '-1'), $snmp_query['id'], '', 'text-align:right');
+			form_selectable_cell($snmp_query['id'], $snmp_query['id'], '', 'right');
+			form_selectable_cell($disabled ? __('No'):__('Yes'), $snmp_query['id'], '', 'right');
+			form_selectable_cell(number_format_i18n($snmp_query['graphs'], '-1'), $snmp_query['id'], '', 'right');
+			form_selectable_cell(number_format_i18n($snmp_query['templates'], '-1'), $snmp_query['id'], '', 'right');
 			form_selectable_cell(filter_value($snmp_query['data_input_method'], get_request_var('filter')), $snmp_query['id']);
 			form_checkbox_cell($snmp_query['name'], $snmp_query['id'], $disabled);
 			form_end_row();
@@ -1290,7 +1393,7 @@ function data_query() {
 
 	html_end_box(false);
 
-	if (sizeof($snmp_queries)) {
+	if (cacti_sizeof($snmp_queries)) {
 		print $nav;
 	}
 
