@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2017 The Cacti Group                                 |
+ | Copyright (C) 2004-2018 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -22,36 +22,9 @@
  +-------------------------------------------------------------------------+
 */
 
-global $no_session_write;
-
-$oper_mode = api_plugin_hook_function('bottom_footer', OPER_MODE_NATIVE);
-if (($oper_mode == OPER_MODE_NATIVE) || ($oper_mode == OPER_MODE_IFRAME_NONAV)) {
-
-?>
-		</div>
-	</div>
-</div>
-<?php api_plugin_hook('page_bottom');?>
-</body>
-</html>
-
-<?php
-
+print "\t\t\t</div>\n\t\t</div>\n\t</div>\n";
+if (!isset_request_var('pagecontent')) {
+	api_plugin_hook('page_bottom');
+	print "\t</body>\n</html>\n";
 }
 
-/* we use this session var to store field values for when a save fails,
-this way we can restore the field's previous values. we reset it here, because
-they only need to be stored for a single page */
-kill_session_var('sess_field_values');
-
-/* make sure the debug log doesn't get too big */
-debug_log_clear();
-
-/* close the session */
-if (array_search(get_current_page(), $no_session_write) === false) {
-	session_write_close();
-}
-
-/* close the database connection */
-db_close();
-
