@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2017 The Cacti Group                                 |
+ | Copyright (C) 2004-2018 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -31,7 +31,7 @@ function render_external_links($style = 'FRONT') {
 	global $config;
 
 	$consoles = db_fetch_assoc_prepared('SELECT id, contentfile FROM external_links WHERE style = ?', array($style));
-	if (sizeof($consoles)) {
+	if (cacti_sizeof($consoles)) {
 		foreach($consoles as $page) {
 			if (is_realm_allowed($page['id']+10000)) {
 				if (preg_match('/^((((ht|f)tp(s?))\:\/\/){1}\S+)/i', $page['contentfile'])) {
@@ -56,11 +56,11 @@ function render_external_links($style = 'FRONT') {
 
 render_external_links('FRONTTOP');
 
-if (read_config_option('hide_console') != '1') {
+if (read_config_option('hide_console') != 'on') {
 ?>
 <table class='cactiTable'>
 	<tr>
-		<td class="textAreaNotes top left">
+		<td class='textAreaNotes top left'>
 			<?php print __('You are now logged into <a href="%s"><b>Cacti</b></a>. You can follow these basic steps to get started.', 'about.php');?>
 
 			<ul>
@@ -69,24 +69,24 @@ if (read_config_option('hide_console') != '1') {
 				<li><?php print __('<a href="%s">View</a> your new graphs', 'graph_view.php');?></li>
 			</ul>
 		</td>
-		<td class="textAreaNotes top right">
-			<strong><?php print __('Version %s', CACTI_VERSION);?></strong>
+		<td class='textAreaNotes top right'>
+			<strong><?php print get_cacti_version_text();?></strong>
 		</td>
 	</tr>
 	<?php if ($config['poller_id'] > 1) {?>
-	<tr><td><hr></td></tr>
-	<tr><td><strong><?php print __('Remote Data Collector Status:');?></strong>  <?php print '<i>' . ($config['connection'] == 'online' ? __('Online'):($config['connection'] == 'recovery' ? __('Recovery'):__('Offline'))) . '</i>';?></td></tr>
+	<tr><td colspan='2'><hr></td></tr>
+	<tr><td colspan='2'><strong><?php print __('Remote Data Collector Status:');?></strong>  <?php print '<i>' . ($config['connection'] == 'online' ? __('Online'):($config['connection'] == 'recovery' ? __('Recovery'):__('Offline'))) . '</i>';?></td></tr>
 	<?php if ($config['connection'] != 'online') {?>
-	<tr><td><strong><?php print __('Number of Offline Records:');?></strong>  <?php print '<i>' . number_format_i18n(db_fetch_cell('SELECT COUNT(*) FROM poller_output_boost', '', true, $local_db_cnn_id)) . '</i>';?></td></tr>
+	<tr><td colspan='2'><strong><?php print __('Number of Offline Records:');?></strong>  <?php print '<i>' . number_format_i18n(db_fetch_cell('SELECT COUNT(*) FROM poller_output_boost', '', true, $local_db_cnn_id)) . '</i>';?></td></tr>
 	<?php }?>
-	<tr><td><hr></td></tr>
+	<tr><td colspan='2'><hr></td></tr>
 	<tr>
-		<td class="textAreaNotes top left">
+		<td class='textAreaNotes top left' colspan='2'>
 			<?php print __('<strong>NOTE:</strong> You are logged into a Remote Data Collector.  When <b>\'online\'</b>, you will be able to view and control much of the Main Cacti Web Site just as if you were logged into it.  Also, it\'s important to note that Remote Data Collectors are required to use the Cacti\'s Performance Boosting Services <b>\'On Demand Updating\'</b> feature, and we always recommend using Spine.  When the Remote Data Collector is <b>\'offline\'</b>, the Remote Data Collectors Web Site will contain much less information.  However, it will cache all updates until the Main Cacti Database and Web Server are reachable.  Then it will dump it\'s Boost table output back to the Main Cacti Database for updating.');?>
 		</td>
 	</tr>
 	<tr>
-		<td class="textAreaNotes top left">
+		<td class='textAreaNotes top left' colspan='2'>
 			<?php print __('<strong>NOTE:</strong> None of the Core Cacti Plugins, to date, have been re-designed to work with Remote Data Collectors.  Therefore, Plugins such as MacTrack, and HMIB, which require direct access to devices will not work with Remote Data Collectors at this time.  However, plugins such as Thold will work so long as the Remote Data Collector is in <b>\'online\'</b> mode.');?>
 		</td>
 	</tr>
