@@ -117,7 +117,7 @@ function aggregate_graph_templates_graph_save($local_graph_id, $graph_template_i
 			WHERE aggregate_template_id = ?',
 			array($aggregate_template_id));
 
-		if (sizeof($aggregate_data)) {
+		if (cacti_sizeof($aggregate_data)) {
 			foreach ($aggregate_data as $field => $value) {
 				if (substr($field, 0, 2) == 't_' && $value == 'on') {
 					$value_field_name = substr($field, 2);
@@ -127,7 +127,7 @@ function aggregate_graph_templates_graph_save($local_graph_id, $graph_template_i
 		}
 	}
 
-	if (sizeof($existing_data) == 0) {
+	if (cacti_sizeof($existing_data) == 0) {
 		/* this is a new graph, use template data */
 		$graph_data = $template_data;
 
@@ -180,7 +180,6 @@ function aggregate_graph_templates_graph_save($local_graph_id, $graph_template_i
  * @param int $_graph_template_id		- template id of the old graph if the old graph is 0
  * @param int $_skip					- graph items to be skipped, array starts at 1
  * @param int $_totali                  - graph items to be totaled, array starts at 1
- * @param bool $_hr						- graph items that should have a <HR>
  * @param int $_graph_item_sequence		- sequence number of the next graph item to be inserted
  * @param int $_selected_graph_index	- index of current graph to be inserted
  * @param array $_color_templates		- the color templates to be used
@@ -236,7 +235,7 @@ function aggregate_graphs_insert_graph_items($_new_graph_id, $_old_graph_id, $_g
 	}
 
 	/* create new entry(s): graph_templates_item */
-	$num_items = sizeof($graph_items);
+	$num_items = cacti_sizeof($graph_items);
 	if ($num_items > 0) {
 		# take care of items having a HR that shall be skipped
 		$i = 0;
@@ -294,9 +293,9 @@ function aggregate_graphs_insert_graph_items($_new_graph_id, $_old_graph_id, $_g
 						FROM graph_templates_item
 						WHERE color_id>0
 						AND sequence = ' . $graph_item['sequence'] .
-						(sizeof($member_graphs) ? ' AND ' . array_to_sql_or($member_graphs, 'local_graph_id'):'') .
-						(sizeof($_skip) ? ' AND sequence NOT IN (' . implode(',', $_skip) . ')':'') .
-						(sizeof($_totali) ? ' AND sequence IN (' . implode(',', $_totali) . ')':'') . '
+						(cacti_sizeof($member_graphs) ? ' AND ' . array_to_sql_or($member_graphs, 'local_graph_id'):'') .
+						(cacti_sizeof($_skip) ? ' AND sequence NOT IN (' . implode(',', $_skip) . ')':'') .
+						(cacti_sizeof($_totali) ? ' AND sequence IN (' . implode(',', $_totali) . ')':'') . '
 						LIMIT 1');
 				}
 			}
@@ -350,12 +349,15 @@ function aggregate_graphs_insert_graph_items($_new_graph_id, $_old_graph_id, $_g
 			$save['graph_type_id'] = aggregate_change_graph_type($_selected_graph_index, $save['graph_type_id'], $_graph_type);
 
 			# new item text format required?
-			if ($prepend && ($_total_type == AGGREGATE_TOTAL_TYPE_ALL)) {
+			if ($prepend && $_total_type != '') {
 				# pointless to add any data source item name here, cause ALL are totaled
 				$save['text_format'] = $_gprint_prefix;
 
 				# no more prepending until next line break is encountered
 				$prepend = false;
+			} elseif (!$prepend && $_total_type != '' && strpos($save['text_format'], ':current:')) {
+				// Accomodate gprint summation types
+				$save['text_format'] = str_replace(':current:', ':total:', $save['text_format']);
 			} elseif ($prepend && $save['text_format'] != '' && $_gprint_prefix != '') {
 				$save['text_format'] = substitute_host_data($_gprint_prefix . ' ' . $save['text_format'], '|', '|', (isset($graph_local['host_id']) ? $graph_local['host_id']:0));
 				cacti_log(__FUNCTION__ . ' substituted:' . $save['text_format'], true, 'AGGREGATE', POLLER_VERBOSITY_DEBUG);
@@ -375,6 +377,7 @@ function aggregate_graphs_insert_graph_items($_new_graph_id, $_old_graph_id, $_g
 			if (isset($_hr[$i]) && $_hr[$i] > 0) {
 				$save['hard_return'] = 'on';
 			}
+
 			# if this item defines a line break, remember to prepend next line
 			if ($save['text_format'] != '') {
 				$prepend = ($save['hard_return'] == 'on');
@@ -526,7 +529,7 @@ function aggregate_validate_graph_params($posted, $has_override = false) {
 		if ($defs['type'] == 'bool') {
 			$params_new[$field] = (isset($posted[$field])) ? 'on' : '';
 		} else {
-			$params_new[$field] = (isset($posted[$field]) ? form_input_validate(htmlspecialchars($posted[$field]), $field, $defs['regex'], $defs['allow_empty'], 3) : $defs['default']);
+			$params_new[$field] = (isset($posted[$field]) ? form_input_validate(html_escape($posted[$field]), $field, $defs['regex'], $defs['allow_empty'], 3) : $defs['default']);
 		}
 	}
 
@@ -685,7 +688,7 @@ function aggregate_reorder_ds_graph($base, $graph_template_id, $aggregate, $reor
 		}
 
 		# now run all updates
-		if (sizeof($updates)) {
+		if (cacti_sizeof($updates)) {
 			foreach($updates as $update) {
 				cacti_log(__FUNCTION__ .  ' update: ' . $update, false, 'AGGREGATE', POLLER_VERBOSITY_DEVDBG);
 				db_execute($update);
@@ -868,14 +871,14 @@ function push_out_aggregates($aggregate_template_id, $local_graph_id = 0) {
 			WHERE aggregate_template_id = ?',
 			array($aggregate_template_id));
 
-		if (sizeof($graphs)) {
+		if (cacti_sizeof($graphs)) {
 			foreach($graphs as $g) {
 				$aggregate_graphs[] = $g['local_graph_id'];
 			}
 		}
 	}
 
-	if (sizeof($aggregate_graphs)) {
+	if (cacti_sizeof($aggregate_graphs)) {
 		foreach($aggregate_graphs as $ag) {
 			$member_graphs = array();
 			$graphs        = db_fetch_assoc_prepared('SELECT DISTINCT agi.local_graph_id
@@ -892,7 +895,7 @@ function push_out_aggregates($aggregate_template_id, $local_graph_id = 0) {
 					array($ag));
 			}
 
-			if (sizeof($graphs)) {
+			if (cacti_sizeof($graphs)) {
 				foreach($graphs as $mg) {
 					$member_graphs[] = $mg['local_graph_id'];
 				}
@@ -922,7 +925,7 @@ function aggregate_create_update(&$local_graph_id, $member_graphs, $attribs) {
 	/* install own error handler */
 	set_error_handler('aggregate_error_handler');
 
-	if (sizeof($member_graphs)) {
+	if (cacti_sizeof($member_graphs)) {
 		$graph_title          = (isset($attribs['graph_title']) ? $attribs['graph_title']:'');
 		$aggregate_template   = (isset($attribs['aggregate_template_id']) ? $attribs['aggregate_template_id']:0);
 		$graph_template_id    = (isset($attribs['graph_template_id']) ? $attribs['graph_template_id']:0);
@@ -1058,8 +1061,8 @@ function aggregate_create_update(&$local_graph_id, $member_graphs, $attribs) {
 				$cf_id = db_fetch_cell('SELECT consolidation_function_id
 					FROM graph_templates_item
 					WHERE color_id>0' .
-					(sizeof($member_graphs) ? ' AND ' . array_to_sql_or($member_graphs, 'local_graph_id'):'') .
-					(sizeof($skipped_items) ? ' AND local_graph_id NOT IN(' . implode(',', $skipped_items) . ')':'') . '
+					(cacti_sizeof($member_graphs) ? ' AND ' . array_to_sql_or($member_graphs, 'local_graph_id'):'') .
+					(cacti_sizeof($skipped_items) ? ' AND local_graph_id NOT IN(' . implode(',', $skipped_items) . ')':'') . '
 					LIMIT 1');
 
 				/* add an empty line before total items */
@@ -1077,8 +1080,8 @@ function aggregate_create_update(&$local_graph_id, $member_graphs, $attribs) {
 				}
 
 				# now skip all items, that are
-					# - explicitely marked as skipped (based on $skipped_items)
-					# - OR NOT marked as 'totalling' items
+				# - explicitely marked as skipped (based on $skipped_items)
+				# - OR NOT marked as 'totalling' items
 				for ($k=1; $k<=$item_no; $k++) {
 					cacti_log(__FUNCTION__ . ' old skip: ' . (isset($skipped_items[$k]) ? $skipped_items[$k]:''), true, 'AGGREGATE', POLLER_VERBOSITY_DEBUG);
 
@@ -1089,7 +1092,7 @@ function aggregate_create_update(&$local_graph_id, $member_graphs, $attribs) {
 				}
 
 				# add the 'templating' graph to the new graph, honoring skipped, hr and color
-				$foo = aggregate_graphs_insert_graph_items(
+				aggregate_graphs_insert_graph_items(
 					$local_graph_id,
 					$example_graph_id,
 					$graph_template_id,
@@ -1100,9 +1103,9 @@ function aggregate_create_update(&$local_graph_id, $member_graphs, $attribs) {
 					$color_templates,
 					$graph_item_types,
 					$cdefs,
-					$_graph_type,			#TODO: user may choose LINEx instead of assuming LINE1
+					$_graph_type, #TODO: user may choose LINEx instead of assuming LINE1
 					$gprint_prefix,
-					AGGREGATE_TOTAL_ALL,	# now add the totalling line(s)
+					AGGREGATE_TOTAL_ALL, # now add the totalling line(s)
 					$_total_type,
 					$member_graphs);
 
@@ -1163,14 +1166,14 @@ function aggregate_get_data_sources(&$graph_array, &$data_sources, &$graph_templ
 			AND graph_local.graph_template_id>0';
 		$used_graph_templates = db_fetch_assoc($sql);
 
-		if (sizeof($used_graph_templates) > 1) {
+		if (cacti_sizeof($used_graph_templates) > 1) {
 			# this is invalid! STOP
 			print "<tr><td colspan='2' class='textArea'>
 			<p>" . __('The Graphs chosen for the Aggregate Graph below represent Graphs from multiple Graph Templates.  Aggregate does not support creating Aggregate Graphs from multiple Graph Templates.') . "</p>";
 			print "<p>" . __('Press \'Return\' to return and select different Graphs') . "</p>\n";
 			print "<ul>";
 			foreach ($used_graph_templates as $graph_template) {
-				print '<li>' . htmlspecialchars($graph_template['name'], ENT_QUOTES) . "</li>\n";
+				print '<li>' . html_escape($graph_template['name']) . "</li>\n";
 			}
 			print '</ul></td></tr>';
 
@@ -1182,7 +1185,7 @@ function aggregate_get_data_sources(&$graph_array, &$data_sources, &$graph_templ
 			});
 			</script>
 			<?php
-		} elseif (sizeof($used_graph_templates) < 1) {
+		} elseif (cacti_sizeof($used_graph_templates) < 1) {
 			/* selected graphs do not use templates */
 			print "<tr><td colspan='2' class='textArea'>
 			<p>" . __('The Graphs chosen for the Aggregate Graph do not use Graph Templates.  Aggregate does not support creating Aggregate Graphs from non-templated graphs.') . "</p>";
@@ -1232,9 +1235,11 @@ function draw_aggregate_graph_items_list($_graph_id = 0, $_graph_template_id = 0
 	if ($_graph_id == 0) {
 		$item_list_where = "gti.local_graph_id=0 AND graph_template_id=$_graph_template_id ";
 	}
+
 	if ($_graph_template_id == 0) {
 		$item_list_where = "gti.local_graph_id=$_graph_id ";
 	}
+
 	$item_list = db_fetch_assoc("SELECT
 		gti.id, gti.text_format, gti.value, gti.hard_return, gti.graph_type_id,
 		gti.consolidation_function_id, cdef.name as cdef_name, colors.hex
@@ -1250,7 +1255,7 @@ function draw_aggregate_graph_items_list($_graph_id = 0, $_graph_template_id = 0
 	$current_vals = array();
 	$is_edit = false;
 	$is_templated = false;
-	if (sizeof($_object) > 0 && $_object['id'] > 0) {
+	if (cacti_sizeof($_object) > 0 && $_object['id'] > 0) {
 		/* drawing items for existing aggregate graph/template */
 		$is_edit =true;
 		/* fetch existing item values */
@@ -1307,13 +1312,13 @@ function draw_aggregate_graph_items_list($_graph_id = 0, $_graph_template_id = 0
 
 	$group_counter = 0; $_graph_type_name = ''; $i = 0;
 
-	if (sizeof($item_list)) {
+	if (cacti_sizeof($item_list)) {
 		foreach ($item_list as $item) {
 			/* graph grouping display logic */
-			$this_row_style = '';
+			$this_row_style   = '';
 			$use_custom_class = false;
-			$hard_return = '';
-			$matrix_title = '';
+			$hard_return      = '';
+			$matrix_title     = '';
 
 			if (!preg_match('/(GPRINT|TEXTALIGN|HRULE|VRULE|TICK)/', $graph_item_types[$item['graph_type_id']])) {
 				$this_row_style = 'font-weight: bold;';
@@ -1351,8 +1356,12 @@ function draw_aggregate_graph_items_list($_graph_id = 0, $_graph_template_id = 0
 					$matrix_title = 'VRULE: ' . $item['value'];
 					break;
 				case preg_match('/(COMMENT)/', $_graph_type_name):
-					$force_skip = true;
-					$matrix_title = 'COMMENT: ' . $item['text_format'];
+					if (preg_match('/(:bits:|:bytes:|\|sum:)/', $item['text_format'])) {
+						$matrix_title = 'COMMENT: ' . $item['text_format'];
+					} else {
+						$force_skip = true;
+						$matrix_title = 'COMMENT: ' . $item['text_format'];
+					}
 					break;
 			}
 
@@ -1388,7 +1397,7 @@ function draw_aggregate_graph_items_list($_graph_id = 0, $_graph_template_id = 0
 				$hard_return = '<strong><span style="color:#FF0000;">&lt;HR&gt;</span></strong>';
 			}
 
-			print "<td style='$this_row_style'>" . htmlspecialchars($matrix_title) . $hard_return . "</td>\n";
+			print "<td style='$this_row_style'>" . html_escape($matrix_title) . $hard_return . "</td>\n";
 
 			/* column 'Graph Item Type' */
 			print "<td style='$this_row_style'>" . $graph_item_types[$item['graph_type_id']] . "</td>\n";
@@ -1413,18 +1422,18 @@ function draw_aggregate_graph_items_list($_graph_id = 0, $_graph_template_id = 0
 			/* column "Skip" */
 			if (!$force_skip) {
 				print "<td style='width:1%;text-align:center;'>";
-				print "<input class='checkbox' id='agg_skip_" . $item['id'] . "' type='checkbox' name='agg_skip_" . $item['id'] . "' title='" . htmlspecialchars($item['text_format'], ENT_QUOTES) . "' " . ($is_edit && (!isset($current_vals[$item['id']]['item_total']) || (isset($current_vals[$item['id']]['item_skip']) && $current_vals[$item['id']]['item_skip'] == 'on')) ? 'checked':'') . '>';
+				print "<input class='checkbox' id='agg_skip_" . $item['id'] . "' type='checkbox' name='agg_skip_" . $item['id'] . "' title='" . html_escape($item['text_format']) . "' " . ($is_edit && (!isset($current_vals[$item['id']]['item_total']) || (isset($current_vals[$item['id']]['item_skip']) && $current_vals[$item['id']]['item_skip'] == 'on')) ? 'checked':'') . '>';
 				print '</td>';
 
 				/* column 'Total' */
 				print "<td style='width:1%;text-align:center;'>";
-				print "<input class='checkbox' id='agg_total_" . ($item['id']) . "' type='checkbox' name='agg_total_" . ($item['id']) . "' title='" . htmlspecialchars($item['text_format'], ENT_QUOTES) . "' " . ($is_edit && isset($current_vals[$item['id']]['item_total']) && $current_vals[$item['id']]['item_total'] == 'on' ? 'checked':'') . '>';
+				print "<input class='checkbox' id='agg_total_" . ($item['id']) . "' type='checkbox' name='agg_total_" . ($item['id']) . "' title='" . html_escape($item['text_format']) . "' " . ($is_edit && isset($current_vals[$item['id']]['item_total']) && $current_vals[$item['id']]['item_total'] == 'on' ? 'checked':'') . '>';
 				print '</td>';
 			} else {
-				print "<td style='width:1%;text-align:center;'><input class='checkbox' id='dummy_" . $item['id'] . "' disabled='disabled' type='checkbox' name='dummy_" . $item['id'] . "' title='" . htmlspecialchars($item['text_format'], ENT_QUOTES) . "' " . ($is_edit ? 'checked':'') . '></td>';
-				print "<td style='width:1%;text-align:center;'><input class='checkbox' id='dummy1_" . $item['id'] . "' disabled='disabled' type='checkbox' name='dummy1_" . $item['id'] . "' title='" . htmlspecialchars($item['text_format'], ENT_QUOTES) . "'>";
-				print "<input style='display:none;' class='checkbox' id='agg_skip_" . $item['id'] . "' type='checkbox' name='agg_skip_" . $item['id'] . "' title='" . htmlspecialchars($item['text_format'], ENT_QUOTES) . "' " . ($is_edit ? 'checked':'') . '>';
-				print "<input style='display:none;' class='checkbox' id='agg_total_" . ($item['id']) . "' type='checkbox' name='agg_total_" . ($item['id']) . "' title='" . htmlspecialchars($item['text_format'], ENT_QUOTES) . "'></td>";
+				print "<td style='width:1%;text-align:center;'><input class='checkbox' id='dummy_" . $item['id'] . "' disabled='disabled' type='checkbox' name='dummy_" . $item['id'] . "'" . ($is_edit ? 'checked':'') . '></td>';
+				print "<td style='width:1%;text-align:center;'><input class='checkbox' id='dummy1_" . $item['id'] . "' disabled='disabled' type='checkbox' name='dummy1_" . $item['id'] . "'>";
+				print "<input style='display:none;' class='checkbox' id='agg_skip_" . $item['id'] . "' type='checkbox' name='agg_skip_" . $item['id'] . "' title='" . html_escape($item['text_format']) . "' " . ($is_edit ? 'checked':'') . '>';
+				print "<input style='display:none;' class='checkbox' id='agg_total_" . ($item['id']) . "' type='checkbox' name='agg_total_" . ($item['id']) . "' title='" . html_escape($item['text_format']) . "'></td>";
 			}
 
 			print '</tr>';
@@ -1437,7 +1446,7 @@ function draw_aggregate_graph_items_list($_graph_id = 0, $_graph_template_id = 0
 
 	html_end_box();
 
-	form_hidden_box('item_no', sizeof($item_list), sizeof($item_list));
+	form_hidden_box('item_no', cacti_sizeof($item_list), cacti_sizeof($item_list));
 }
 
 
@@ -1473,7 +1482,7 @@ function draw_aggregate_template_graph_config($aggregate_template_id, $graph_tem
 
 			/* value from graph template or aggregate graph template
 			(based on value of t_$field_name of aggregate_template_graph) */
-			if (sizeof($aggregate_templates_graph) && $aggregate_templates_graph['t_'.$field_name] == 'on') {
+			if (cacti_sizeof($aggregate_templates_graph) && $aggregate_templates_graph['t_'.$field_name] == 'on') {
 				$value = $aggregate_templates_graph[$field_name];
 			} else {
 				$value = $graph_templates_graph[$field_name];
@@ -1483,7 +1492,7 @@ function draw_aggregate_template_graph_config($aggregate_template_id, $graph_tem
 			$form_array[$field_name]['sub_checkbox'] = array(
 				'name' => 't_' . $field_name,
 				'friendly_name' => __('Override this Value'). '<br>',
-				'value' => (sizeof($aggregate_templates_graph) ? $aggregate_templates_graph['t_' . $field_name] : ''),
+				'value' => (cacti_sizeof($aggregate_templates_graph) ? $aggregate_templates_graph['t_' . $field_name] : ''),
 				'on_change' => 'toggleFieldEnabled(this);'
 			);
 		} else {
@@ -1532,3 +1541,4 @@ function draw_aggregate_template_graph_config($aggregate_template_id, $graph_tem
 	</script>
 	<?php
 }
+
