@@ -34,13 +34,9 @@ function api_tree_lock($tree_id, $user_id = 0, $web = true) {
 	/* ==================================================== */
 
 	db_execute_prepared('UPDATE graph_tree
-		SET locked = 1, locked_date = NOW(), last_modified = NOW(), modified_by = ?
+		SET `locked` = 1, locked_date = NOW(), last_modified = NOW(), modified_by = ?
 		WHERE id = ?',
 		array($user_id, $tree_id));
-
-	if ($web) {
-		header('Location: tree.php?action=edit&header=false&id=' . $tree_id);
-	}
 }
 
 /* api_tree_unlock - unlockes a locked tree that has been locked for editing
@@ -55,13 +51,9 @@ function api_tree_unlock($tree_id, $user_id = 0, $web = true) {
 	/* ==================================================== */
 
 	db_execute_prepared('UPDATE graph_tree
-		SET locked = 0, last_modified = NOW(), modified_by = ?
+		SET `locked` = 0, last_modified = NOW(), modified_by = ?
 		WHERE id = ?',
 		array($user_id, $tree_id));
-
-	if ($web) {
-		header('Location: tree.php?action=edit&header=false&id=' . $tree_id);
-	}
 }
 
 /* api_tree_copy_node - given a tree id, a new node location,
@@ -86,6 +78,9 @@ function api_tree_copy_node($tree_id, $node_id, $new_parent, $new_position) {
 	if (isset($data['host']) && ($data['host'] < 0 || !is_numeric($data['host']))) {
 		cacti_log('ERROR: Copy node host data invalid, Function copy_node', false);
 		return;
+	} elseif(isset($data['site']) && ($data['site'] < 0 || !is_numeric($data['site']))) {
+		cacti_log('ERROR: Copy node site data invalid, Function copy_node', false);
+		return;
 	} elseif(isset($data['graph']) && ($data['graph'] < 0 || !is_numeric($data['graph']))) {
 		cacti_log('ERROR: Copy node graph data invalid, Function copy_node', false);
 		return;
@@ -118,6 +113,18 @@ function api_tree_copy_node($tree_id, $node_id, $new_parent, $new_position) {
 			AND local_graph_id = ?',
 			array($pdata['leaf_id'], $tree_id, $data['graph']));
 
+		if ($exists) {
+			print 'tbranch:' . $exists;
+			return;
+		}
+	} elseif ($data['site'] > 0) {
+		$exists = db_fetch_cell_prepared('SELECT id
+			FROM graph_tree_items
+			WHERE parent = ?
+			AND graph_tree_id = ?
+			AND site_id = ?',
+			array($pdata['leaf_id'], $tree_id, $data['site']));
+
 		if ($exists) {
 			print 'tbranch:' . $exists;
 			return;
@@ -134,8 +141,9 @@ function api_tree_copy_node($tree_id, $node_id, $new_parent, $new_position) {
 	$save['graph_tree_id']      = $tree_id;
 	$save['local_graph_id']     = $data['graph'];
 	$save['host_id']            = $data['host'];
+	$save['site_id']            = $data['site'];
 	$save['host_grouping_type'] = 1;
-	$save['sort_children_type'] = 1;
+	$save['sort_children_type'] = TREE_ORDERING_INHERIT;
 	$save['title']              = $title;
 
 	$id = sql_save($save, 'graph_tree_items');
@@ -179,13 +187,12 @@ function api_tree_release_lock($lockname) {
  * @arg $node_id - The branch/leaf to place the new branch/leaf
  * @arg $title - The new brnach/leaf title
  * @returns - json encoded new leaf information */
-function api_tree_create_node($tree_id, $node_id, $position, $title = 'New Branch') {
+function api_tree_create_node($tree_id, $node_id, $position, $title = '') {
 	input_validate_input_number($tree_id);
 	input_validate_input_number($position);
 
-	/* clean up text string */
-	if (isset($title)) {
-		$title = sanitize_search_string(htmlspecialchars_decode($title));
+	if ($title == '') {
+		$title = __('New Branch');
 	}
 
 	$data  = api_tree_parse_node_data($node_id);
@@ -198,9 +205,11 @@ function api_tree_create_node($tree_id, $node_id, $position, $title = 'New Branc
 	$i     = 0;
 	$found = false;
 	$orig  = $title;
+
 	while(true) {
 		$title = $orig . ($found ? ' (' . $i . ')':'');
 		$exists_id = api_tree_branch_exists($tree_id, $data['leaf_id'], $title);
+
 		if ($exists_id == false) {
 			break;
 		} else {
@@ -218,8 +227,9 @@ function api_tree_create_node($tree_id, $node_id, $position, $title = 'New Branc
 	$save['graph_tree_id']      = $tree_id;
 	$save['local_graph_id']     = 0;
 	$save['host_id']            = 0;
+	$save['site_id']            = 0;
 	$save['host_grouping_type'] = 1;
-	$save['sort_children_type'] = 1;
+	$save['sort_children_type'] = TREE_ORDERING_INHERIT;
 	$save['title']              = $title;
 
 	$id = sql_save($save, 'graph_tree_items');
@@ -236,7 +246,32 @@ function api_tree_create_node($tree_id, $node_id, $position, $title = 'New Branc
  * @arg $title - The branch name to search for
  * @returns - the id of the branch if it exists */
 function api_tree_branch_exists($tree_id, $parent, $title) {
-	$id =  db_fetch_cell_prepared('SELECT id FROM graph_tree_items WHERE graph_tree_id = ? AND parent = ? AND title = ?', array($tree_id, $parent, $title));
+	$id = db_fetch_cell_prepared('SELECT id
+		FROM graph_tree_items
+		WHERE graph_tree_id = ?
+		AND parent = ?
+		AND title = ?',
+		array($tree_id, $parent, $title));
+
+	if ($id > 0) {
+		return $id;
+	} else {
+		return false;
+	}
+}
+
+/* api_tree_site_exists - given a tree, parent branch, and a host_id, will check host on that branch
+ * @arg $tree_id - The tree_id to search
+ * @arg $parent - The parent leaf_id to search
+ * @arg $sist_id - The host_id to search for
+ * @returns - the id of the leaf if it exists */
+function api_tree_site_exists($tree_id, $parent, $host_id) {
+	$id = db_fetch_cell_prepared('SELECT id
+		FROM graph_tree_items
+		WHERE graph_tree_id = ?
+		AND parent = ?
+		AND site_id = ?',
+		array($tree_id, $parent, $site_id));
 
 	if ($id > 0) {
 		return $id;
@@ -251,7 +286,12 @@ function api_tree_branch_exists($tree_id, $parent, $title) {
  * @arg $host_id - The host_id to search for
  * @returns - the id of the leaf if it exists */
 function api_tree_host_exists($tree_id, $parent, $host_id) {
-	$id =  db_fetch_cell_prepared('SELECT id FROM graph_tree_items WHERE graph_tree_id = ? AND parent = ? AND host_id = ?', array($tree_id, $parent, $host_id));
+	$id = db_fetch_cell_prepared('SELECT id
+		FROM graph_tree_items
+		WHERE graph_tree_id = ?
+		AND parent = ?
+		AND host_id = ?',
+		array($tree_id, $parent, $host_id));
 
 	if ($id > 0) {
 		return $id;
@@ -266,7 +306,12 @@ function api_tree_host_exists($tree_id, $parent, $host_id) {
  * @arg $local_graph_id - The local_graph_id to search for
  * @returns - the id of the leaf if it exists */
 function api_tree_graph_exists($tree_id, $parent, $local_graph_id) {
-	$id =  db_fetch_cell_prepared('SELECT id FROM graph_tree_items WHERE graph_tree_id = ? AND parent = ? AND local_graph_id = ?', array($tree_id, $parent, $local_graph_id));
+	$id = db_fetch_cell_prepared('SELECT id
+		FROM graph_tree_items
+		WHERE graph_tree_id = ?
+		AND parent = ?
+		AND local_graph_id = ?',
+		array($tree_id, $parent, $local_graph_id));
 
 	if ($id > 0) {
 		return $id;
@@ -296,11 +341,14 @@ function api_tree_delete_node($tree_id, $node_id) {
 	$data  = api_tree_parse_node_data($node_id);
 
 	if (isset($data['leaf_id']) && $data['leaf_id'] > 0) {
-		if ($data['host'] == 0 && $data['graph'] == 0) {
+		if ($data['host'] == 0 && $data['graph'] == 0 && $data['site'] == 0) {
 			api_tree_delete_node_content($tree_id, $data['leaf_id']);
 		}
 
-		db_execute_prepared('DELETE FROM graph_tree_items WHERE graph_tree_id = ? AND id = ?', array($tree_id, $data['leaf_id']));
+		db_execute_prepared('DELETE FROM graph_tree_items
+			WHERE graph_tree_id = ?
+			AND id = ?',
+			array($tree_id, $data['leaf_id']));
 	}
 }
 
@@ -313,7 +361,7 @@ function api_tree_delete_node_content($tree_id, $leaf_id) {
 		FROM graph_tree_items
 		WHERE graph_tree_id = ? AND parent = ?', array($tree_id, $leaf_id));
 
-	if (sizeof($children)) {
+	if (cacti_sizeof($children)) {
 		foreach($children as $child) {
 			if ($child['host_id'] == 0 && $child['graph_id'] == 0) {
 				api_tree_delete_node_content($tree_id, $child['id']);
@@ -372,7 +420,7 @@ function api_tree_move_node($tree_id, $node_id, $new_parent, $new_position) {
 			AND position >= ?', array($pdata['leaf_id'], $data['leaf_id'], $new_position));
 
 		$position = $new_position + 1;
-		if (sizeof($others)) {
+		if (cacti_sizeof($others)) {
 			foreach($others as $other) {
 				db_execute_prepared('UPDATE graph_tree_items SET position = ? WHERE id = ?', array($position, $other['id']));
 				$position++;
@@ -394,7 +442,7 @@ function api_tree_move_node($tree_id, $node_id, $new_parent, $new_position) {
 			position >= ?', array($pdata['leaf_id'], $data['leaf_id'], $new_position));
 
 		$position = $new_position + 1;
-		if (sizeof($others)) {
+		if (cacti_sizeof($others)) {
 			foreach($others as $other) {
 				db_execute_prepared('UPDATE graph_tree_items SET position = ? WHERE id = ?', array($position, $other['id']));
 				$position++;
@@ -417,11 +465,12 @@ function api_tree_parse_node_data($variable) {
 	$leaf_id   = 0;
 	$graph_id  = 0;
 	$host_id   = 0;
+	$site_id   = 0;
 
 	if ($variable != '#') {
 		// Process the 'id' variable
 		$ndata   = explode('_', $variable);
-		if (sizeof($ndata)) {
+		if (cacti_sizeof($ndata)) {
 			foreach($ndata as $data) {
 				list($type, $tid) = explode(':', $data);
 
@@ -438,32 +487,35 @@ function api_tree_parse_node_data($variable) {
 					case 'thost':
 						$host_id  = $tid;
 						break;
+					case 'tsite':
+						$site_id  = $tid;
+						break;
 				}
 			}
 		}
 	}
 
 	if ($leaf_id > 0) {
-		$parent = db_fetch_cell_prepared('SELECT parent FROM graph_tree_items WHERE id = ?', array($leaf_id));
+		$parent = db_fetch_cell_prepared('SELECT parent
+			FROM graph_tree_items
+			WHERE id = ?',
+			array($leaf_id));
 	} else {
 		$parent = '0';
 	}
 
-	return array('leaf_id' => $leaf_id, 'graph' => $graph_id, 'host' => $host_id, 'parent' => $parent);
+	return array('leaf_id' => $leaf_id, 'graph' => $graph_id, 'host' => $host_id, 'site' => $site_id, 'parent' => $parent);
 }
 
 /* api_tree_rename_node - given the tree and the node information rename the tree branch/leaf.
  * This function is used for editing.
  * @arg $tree_id - The id of the tree you are parsing
  * @arg $node_id - The branch/leaf id of the node to be renamed
- * @arg $text - The new branch/leaf title
+ * @arg $title - The new branch/leaf title
  * @returns - string of the tree items in html format */
-function api_tree_rename_node($tree_id, $node_id = '', $text = '') {
+function api_tree_rename_node($tree_id, $node_id = '', $title = '') {
 	input_validate_input_number($tree_id);
 
-	/* clean up text string */
-	$text = sanitize_search_string(htmlspecialchars_decode($text));
-
 	// Basic Error Checking
 	if ($tree_id <= 0) {
 		cacti_log("ERROR: Invalid TreeID: '" . $tree_id . "', Function rename_node", false);
@@ -487,10 +539,11 @@ function api_tree_rename_node($tree_id, $node_id = '', $text = '') {
 	$leaf_id  = 0;
 	$graph_id = 0;
 	$host_id  = 0;
+	$site_id  = 0;
 
 	// Process the 'id' variable
 	$ndata = explode('_', $node_id);
-	if (sizeof($ndata)) {
+	if (cacti_sizeof($ndata)) {
 		foreach($ndata as $data) {
 			list($type, $tid) = explode(':', $data);
 
@@ -501,6 +554,9 @@ function api_tree_rename_node($tree_id, $node_id = '', $text = '') {
 				case 'tbranch':
 					$leaf_id  = $tid;
 					break;
+				case 'tsite':
+					$site_id = $tid;
+					break;
 				case 'tgraph':
 					$graph_id = $tid;
 					break;
@@ -512,13 +568,13 @@ function api_tree_rename_node($tree_id, $node_id = '', $text = '') {
 	}
 
 	if (isset($leaf_id) && $leaf_id > 0) {
-		if ($host_id > 0 || $graph_id > 0) {
+		if ($host_id > 0 || $graph_id > 0 || $site_id > 0) {
 			// Ignore.  Need to customize context
 		} else {
 			db_execute_prepared('UPDATE graph_tree_items
 				SET title = ?
 				WHERE graph_tree_id = ?
-				AND id = ?', array($text, $tree_id, $leaf_id));
+				AND id = ?', array($title, $tree_id, $leaf_id));
 		}
 	}
 
@@ -543,11 +599,11 @@ function api_tree_get_main($tree_id, $parent = 0) {
 				WHERE id = ?',
 				array($tree_id));
 
-			print "<ul><li class='jstree-closed' id='tree_anchor-$tree_id' data-jstree='{ \"type\" : \"tree\" }'><a href='" . htmlspecialchars('graph_view.php?action=tree&node=tree_anchor-' . $tree_id). "'>" . htmlspecialchars($name) . "</a>\n";
+			print "<ul><li class='jstree-closed' id='tree_anchor-$tree_id' data-jstree='{ \"type\" : \"tree\" }'><a href='" . html_escape('graph_view.php?action=tree&node=tree_anchor-' . $tree_id). "'>" . html_escape($name) . "</a>\n";
 
 			$heirarchy = draw_dhtml_tree_level_graphing($tree_id, $parent);
 
-			if (sizeof($heirarchy)) {
+			if (cacti_sizeof($heirarchy)) {
 				foreach($heirarchy as $h) {
 					print $h;
 				}
@@ -555,7 +611,7 @@ function api_tree_get_main($tree_id, $parent = 0) {
 		} else {
 			$heirarchy = draw_dhtml_tree_level_graphing($tree_id, $parent);
 
-			if (sizeof($heirarchy)) {
+			if (cacti_sizeof($heirarchy)) {
 				foreach($heirarchy as $h) {
 					print $h;
 				}
@@ -564,7 +620,7 @@ function api_tree_get_main($tree_id, $parent = 0) {
 	} else {
 		$heirarchy = draw_dhtml_tree_level_graphing($tree_id, $parent);
 
-		if (sizeof($heirarchy)) {
+		if (cacti_sizeof($heirarchy)) {
 			foreach($heirarchy as $h) {
 				print $h;
 			}
@@ -592,7 +648,7 @@ function api_tree_get_node($tree_id, $node_id, $editing = false) {
 		$heirarchy = draw_dhtml_tree_level($tree_id, $id, $editing);
 	}
 
-	if (sizeof($heirarchy)) {
+	if (cacti_sizeof($heirarchy)) {
 		foreach($heirarchy as $h) {
 			print $h;
 		}
@@ -607,12 +663,13 @@ function api_tree_get_node($tree_id, $node_id, $editing = false) {
  * @arg $title - The leaf title in the caseo a leaf
  * @arg $local_graph_id - The graph id in the case of a graph
  * @arg $host_id - The host id in the case of a graph
+ * @arg $site_id - The site id in the case of a graph
  * @arg $host_grouping_type - The sort order for the host under expanded hosts
- * @arg $sort_children - The sort type in the case of a leaf
+ * @arg $sort_children_type - The sort type in the case of a leaf
  * @arg $propagate_changes - Wether the changes should be cascaded through all children
  * @returns - boolean true or false depending on the outcome of the operation */
 function api_tree_item_save($id, $tree_id, $type, $parent_tree_item_id, $title, $local_graph_id,
-	$host_id, $host_grouping_type, $sort_children_type, $propagate_changes) {
+	$host_id, $site_id, $host_grouping_type, $sort_children_type, $propagate_changes) {
 	global $config;
 
 	input_validate_input_number($tree_id);
@@ -621,12 +678,35 @@ function api_tree_item_save($id, $tree_id, $type, $parent_tree_item_id, $title,
 	//api_tree_get_lock('tree-lock', 10);
 
 	if ($local_graph_id > 0) {
-		$exists = db_fetch_cell_prepared('SELECT id FROM graph_tree_items WHERE local_graph_id = ? AND parent = ? AND graph_tree_id = ?', array($local_graph_id, $parent_tree_item_id, $tree_id));
+		$exists = db_fetch_cell_prepared('SELECT id
+			FROM graph_tree_items
+			WHERE local_graph_id = ?
+			AND parent = ?
+			AND graph_tree_id = ?',
+			array($local_graph_id, $parent_tree_item_id, $tree_id));
+
+		if ($exists) {
+			return false;
+		}
+	} elseif ($site_id > 0) {
+		$exists = db_fetch_cell_prepared('SELECT id
+			FROM graph_tree_items
+			WHERE site_id = ?
+			AND parent = ?
+			AND graph_tree_id = ?',
+			array($site_id, $parent_tree_item_id, $tree_id));
+
 		if ($exists) {
 			return false;
 		}
 	} elseif ($host_id > 0) {
-		$exists = db_fetch_cell_prepared('SELECT id FROM graph_tree_items WHERE host_id = ? AND parent = ? AND graph_tree_id = ?', array($host_id, $parent_tree_item_id, $tree_id));
+		$exists = db_fetch_cell_prepared('SELECT id
+			FROM graph_tree_items
+			WHERE host_id = ?
+			AND parent = ?
+			AND graph_tree_id = ?',
+			array($host_id, $parent_tree_item_id, $tree_id));
+
 		if ($exists) {
 			return false;
 		}
@@ -665,16 +745,21 @@ function api_tree_item_save($id, $tree_id, $type, $parent_tree_item_id, $title,
    @returns - a string reprenting the type of the tree item. valid return
      values are 'header', 'graph', and 'host' */
 function api_tree_get_item_type($tree_item_id) {
-	$tree_item = db_fetch_row_prepared('SELECT title,local_graph_id,host_id FROM graph_tree_items WHERE id = ?', array($tree_item_id));
+	$tree_item = db_fetch_row_prepared('SELECT title, local_graph_id, site_id, host_id
+		FROM graph_tree_items
+		WHERE id = ?',
+		array($tree_item_id));
 
-	if (!sizeof($tree_item)) {
+	if (!cacti_sizeof($tree_item)) {
 		return '';
 	} elseif ($tree_item['local_graph_id'] > 0) {
 		return 'graph';
-	} elseif ($tree_item['title'] != '') {
-		return 'header';
+	} elseif ($tree_item['site_id'] > 0) {
+		return 'site';
 	} elseif ($tree_item['host_id'] > 0) {
 		return 'host';
+	} elseif ($tree_item['title'] != '') {
+		return 'header';
 	}
 
 	return '';
@@ -696,7 +781,7 @@ function naturally_sort_graphs($a, $b) {
 function api_tree_get_branch_ordering($leaf_id) {
 	$leaf = db_fetch_row_prepared('SELECT sort_children_type, parent, graph_tree_id FROM graph_tree_items WHERE id = ?', array($leaf_id));
 
-	if (sizeof($leaf)) {
+	if (cacti_sizeof($leaf)) {
 		if ($leaf['sort_children_type'] == 0) {
 			$parent = $leaf['parent'];
 
@@ -782,7 +867,7 @@ function api_tree_sort_branch($leaf_id, $tree_id = 0, $lock = true) {
 		AND local_graph_id = 0
 		AND host_id = 0 ' . $order_by, array($parent, $tree_id)), 'id', 'title');
 
-	if (sizeof($sort_array)) {
+	if (cacti_sizeof($sort_array)) {
 		if ($sort_style == TREE_ORDERING_NUMERIC) {
 			asort($sort_array, SORT_NUMERIC);
 		} elseif ($sort_style == TREE_ORDERING_ALPHABETIC) {
@@ -824,7 +909,7 @@ function api_tree_sort_branch($leaf_id, $tree_id = 0, $lock = true) {
 		AND graph_tree_id = ?
 		AND host_id > 0 ' . $order_by, array($parent, $tree_id)), 'id', 'description');
 
-	if (sizeof($sort_array)) {
+	if (cacti_sizeof($sort_array)) {
 		if ($sort_style == TREE_ORDERING_NUMERIC) {
 			asort($sort_array, SORT_NUMERIC);
 		} elseif ($sort_style == TREE_ORDERING_ALPHABETIC) {
@@ -857,7 +942,7 @@ function api_tree_sort_branch($leaf_id, $tree_id = 0, $lock = true) {
 		AND graph_tree_id = ?
 		AND gti.local_graph_id > 0 ' . $order_by, array($parent, $tree_id)), 'id', 'title_cache');
 
-	if (sizeof($sort_array)) {
+	if (cacti_sizeof($sort_array)) {
 		if ($sort_style == TREE_ORDERING_NUMERIC) {
 			asort($sort_array, SORT_NUMERIC);
 		} elseif ($sort_style == TREE_ORDERING_ALPHABETIC) {
