@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2017 The Cacti Group                                 |
+ | Copyright (C) 2004-2018 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -13,7 +13,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -147,7 +147,7 @@ class CactiTableFilter {
 	}
 
 	private function create_filter() {
-		if (!sizeof($this->filter_array)) {
+		if (!cacti_sizeof($this->filter_array)) {
 			$this->filter_array = $this->default_filter;
 		}
 
@@ -164,13 +164,13 @@ class CactiTableFilter {
 					switch($field_array['method']) {
 					case 'button':
 						print "<div class='formColumnButton'>\n";
-						print "<input type='button' id='" . $field_name . "' value='" . htmlspecialchars(get_request_var($field_name), ENT_QUOTES, 'UTF-8') . "'" . (isset($field_array->title) ? " title='" . htmlspecialchars($field_array->title, ENT_QUOTES, 'UTF-8'):'') . "'>";
+						print "<input type='button' class='ui-button ui-corner-all ui-widget' id='" . $field_name . "' value='" . html_escape_request_var($field_name) . "'" . (isset($field_array->title) ? " title='" . html_escape($field_array->title, ENT_QUOTES, 'UTF-8'):'') . "'>";
 						print "</div>\n";
 
 						break;
 					case 'submit':
 						print "<div class='formColumnButton'>\n";
-						print "<input type='submit' id='" . $field_name . "' value='" . htmlspecialchars(get_request_var($field_name), ENT_QUOTES, 'UTF-8') . "'" . (isset($field_array->title) ? " title='" . htmlspecialchars($field_array->title, ENT_QUOTES, 'UTF-8'):'') . "'>";
+						print "<input type='submit' class='ui-button ui-corner-all ui-widget' id='" . $field_name . "' value='" . html_escape_request_var($field_name) . "'" . (isset($field_array->title) ? " title='" . html_escape($field_array->title):'') . "'>";
 						print "</div>\n";
 
 						break;
