@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2017 The Cacti Group                                 |
+ | Copyright (C) 2004-2018 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -13,7 +13,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -42,10 +42,11 @@ function draw_nontemplated_fields_graph($graph_template_id, &$values_array, $fie
 	$draw_any_items = false;
 
 	/* fetch information about the graph template */
-	$graph_template = db_fetch_row_prepared('SELECT * 
-		FROM graph_templates_graph 
+	$graph_template = db_fetch_row_prepared('SELECT *
+		FROM graph_templates_graph
 		WHERE graph_template_id = ?
-		AND local_graph_id=0', array($graph_template_id));
+		AND local_graph_id = 0',
+		array($graph_template_id));
 
 	foreach ($struct_graph as $field_name => $field_array) {
 		/* find our field name */
@@ -66,7 +67,7 @@ function draw_nontemplated_fields_graph($graph_template_id, &$values_array, $fie
 			} else {
 				unset($form_array[$form_field_name]);
 			}
-		} elseif ((!empty($snmp_query_graph_id)) && (sizeof(db_fetch_assoc_prepared('SELECT id FROM snmp_query_graph_sv WHERE snmp_query_graph_id = ? AND field_name = ?', array($snmp_query_graph_id, $field_name))) > 0)) {
+		} elseif ((!empty($snmp_query_graph_id)) && (cacti_sizeof(db_fetch_assoc_prepared('SELECT id FROM snmp_query_graph_sv WHERE snmp_query_graph_id = ? AND field_name = ?', array($snmp_query_graph_id, $field_name))) > 0)) {
 			if ($include_hidden_fields == true) {
 				$form_array[$form_field_name]['method'] = 'hidden';
 			} else {
@@ -95,7 +96,7 @@ function draw_nontemplated_fields_graph($graph_template_id, &$values_array, $fie
 			)
 		);
 
-	return (isset($form_array) ? sizeof($form_array) : 0);
+	return (isset($form_array) ? cacti_sizeof($form_array) : 0);
 }
 
 /* draw_nontemplated_fields_graph_item - draws a form that consists of all non-templated graph item fields
@@ -115,16 +116,23 @@ function draw_nontemplated_fields_graph_item($graph_template_id, $local_graph_id
 	$draw_any_items = false;
 
 	/* fetch information about the graph template */
-	$input_item_list = db_fetch_assoc_prepared('SELECT * 
-		FROM graph_template_input 
+	$input_item_list = db_fetch_assoc_prepared('SELECT *
+		FROM graph_template_input
 		WHERE graph_template_id = ?
-		ORDER BY column_name, name', array($graph_template_id));
+		ORDER BY column_name, name',
+		array($graph_template_id));
 
 	/* modifications to the default graph items array */
 	if (!empty($local_graph_id)) {
-		$host_id = db_fetch_cell_prepared('SELECT host_id 
-			FROM graph_local 
-			WHERE id = ?', array($local_graph_id));
+		$host_id = db_fetch_cell_prepared('SELECT host_id
+			FROM graph_local
+			WHERE id = ?',
+			array($local_graph_id));
+
+		if (get_selected_theme() != 'classic') {
+			$struct_graph_item['task_item_id']['method'] = 'drop_callback';
+			$struct_graph_item['task_item_id']['action'] = 'ajax_get_graphitem';
+		}
 
 		$struct_graph_item['task_item_id']['sql'] = "SELECT
 			CONCAT_WS('',
@@ -142,49 +150,73 @@ function draw_nontemplated_fields_graph_item($graph_template_id, $local_graph_id
 			ORDER BY name";
 	}
 
-	if (sizeof($input_item_list) > 0) {
+	if (cacti_sizeof($input_item_list)) {
 		foreach ($input_item_list as $item) {
 			if (!empty($local_graph_id)) {
-				$current_def_value = db_fetch_row_prepared('SELECT
-					graph_templates_item.' . $item['column_name'] . ',
-					graph_templates_item.id
-					FROM (graph_templates_item,graph_template_input_defs)
-					WHERE graph_template_input_defs.graph_template_item_id=graph_templates_item.local_graph_template_item_id
-					AND graph_template_input_defs.graph_template_input_id = ?
-					AND graph_templates_item.local_graph_id = ?
-					LIMIT 1', array( $item['id'], $local_graph_id));
+				$current_def_value = db_fetch_row_prepared('SELECT gti.' . $item['column_name'] . ', gti.id
+					FROM graph_templates_item AS gti
+					INNER JOIN graph_template_input_defs AS gtid
+					ON gtid.graph_template_item_id=gti.local_graph_template_item_id
+					WHERE gtid.graph_template_input_id = ?
+					AND gti.local_graph_id = ?
+					LIMIT 1',
+					array($item['id'], $local_graph_id));
 			} else {
-				$current_def_value = db_fetch_row_prepared('SELECT
-					graph_templates_item.' . $item['column_name'] . ',
-					graph_templates_item.id
-					FROM (graph_templates_item,graph_template_input_defs)
-					WHERE graph_template_input_defs.graph_template_item_id=graph_templates_item.id
-					AND graph_template_input_defs.graph_template_input_id = ?
-					AND graph_templates_item.graph_template_id = ?
-					LIMIT 1', array($item['id'], $graph_template_id));
+				$current_def_value = db_fetch_row_prepared('SELECT gti.' . $item['column_name'] . ', gti.id
+					FROM graph_templates_item AS gti
+					INNER JOIN graph_template_input_defs AS gtid
+					ON gtid.graph_template_item_id=gti.id
+					WHERE gtid.graph_template_input_id = ?
+					AND gti.graph_template_id = ?
+					LIMIT 1',
+					array($item['id'], $graph_template_id));
 			}
 
 			/* find our field name */
 			$form_field_name = str_replace('|field|', $item['column_name'], $field_name_format);
 			$form_field_name = str_replace('|id|', $item['id'], $form_field_name);
 
-			$form_array += array($form_field_name => $struct_graph_item{$item['column_name']});
+			if (get_selected_theme() != 'classic') {
+				$struct_graph_item[$item['column_name']]['id'] = $current_def_value[$item['column_name']];
+				$struct_graph_item['task_item_id']['action']   = 'ajax_graph_items' . (isset($host_id) ? '&host_id=' . $host_id:'') . '&rrd_id=' . $current_def_value[$item['column_name']];
+			}
+
+			$form_array += array($form_field_name => $struct_graph_item[$item['column_name']]);
 
 			/* modifications to the default form array */
 			$form_array[$form_field_name]['friendly_name'] = $item['name'];
-			$form_array[$form_field_name]['value'] = $current_def_value{$item['column_name']};
+
+			if (isset($current_def_value[$item['column_name']])) {
+				$form_array[$form_field_name]['value'] = $current_def_value[$item['column_name']];
+			}
 
 			if ($locked == 'true') {
 				if (substr_count($form_field_name, 'task_item_id') > 0) {
 					$form_array[$form_field_name]['method'] = 'value';
 
+					if (isset($current_def_value[$item['column_name']])) {
+						$value = db_fetch_cell_prepared("SELECT
+							CONCAT_WS('',CASE WHEN host.description IS NULL THEN 'No Device - ' ELSE '' END,data_template_data.name_cache,' (',data_template_rrd.data_source_name,')') AS name
+							FROM (data_template_data,data_template_rrd,data_local)
+							LEFT JOIN host ON (data_local.host_id=host.id)
+							WHERE data_template_rrd.local_data_id=data_local.id
+							AND data_template_data.local_data_id=data_local.id
+							AND data_template_rrd.id = ?",
+							array($current_def_value[$item['column_name']]));
+
+						$form_array[$form_field_name]['value'] = $value;
+					}
+				}
+			} elseif (get_selected_theme() != 'classic') {
+				if (substr_count($form_field_name, 'task_item_id') > 0) {
 					$value = db_fetch_cell_prepared("SELECT
-                        CONCAT_WS('',CASE WHEN host.description IS NULL THEN 'No Device - ' ELSE '' END,data_template_data.name_cache,' (',data_template_rrd.data_source_name,')') AS name
-                        FROM (data_template_data,data_template_rrd,data_local)
-                        LEFT JOIN host ON (data_local.host_id=host.id)
-                        WHERE data_template_rrd.local_data_id=data_local.id
-                        AND data_template_data.local_data_id=data_local.id
-                        AND data_template_rrd.id = ?", array($current_def_value{$item['column_name']}));
+						CONCAT_WS('',CASE WHEN host.description IS NULL THEN 'No Device - ' ELSE '' END,data_template_data.name_cache,' (',data_template_rrd.data_source_name,')') AS name
+						FROM (data_template_data,data_template_rrd,data_local)
+						LEFT JOIN host ON (data_local.host_id=host.id)
+						WHERE data_template_rrd.local_data_id=data_local.id
+						AND data_template_data.local_data_id=data_local.id
+						AND data_template_rrd.id = ?",
+						array($current_def_value[$item['column_name']]));
 
 					$form_array[$form_field_name]['value'] = $value;
 				}
@@ -211,7 +243,7 @@ function draw_nontemplated_fields_graph_item($graph_template_id, $local_graph_id
 		$form_config_array = array('no_form_tag' => true, 'force_row_color' => true);
 	}
 
-	if (sizeof($input_item_list)) {
+	if (cacti_sizeof($input_item_list)) {
 		draw_edit_form(
 			array(
 				'config' => $form_config_array,
@@ -220,7 +252,7 @@ function draw_nontemplated_fields_graph_item($graph_template_id, $local_graph_id
 		);
 	}
 
-	return (isset($form_array) ? sizeof($form_array) : 0);
+	return (isset($form_array) ? cacti_sizeof($form_array) : 0);
 }
 
 /* draw_nontemplated_fields_data_source - draws a form that consists of all non-templated data source fields
@@ -244,10 +276,11 @@ function draw_nontemplated_fields_data_source($data_template_id, $local_data_id,
 	$draw_any_items = false;
 
 	/* fetch information about the data template */
-	$data_template = db_fetch_row_prepared('SELECT * 
-		FROM data_template_data 
+	$data_template = db_fetch_row_prepared('SELECT *
+		FROM data_template_data
 		WHERE data_template_id = ?
-		AND local_data_id=0', array($data_template_id));
+		AND local_data_id = 0',
+		array($data_template_id));
 
 	foreach ($struct_data_source as $field_name => $field_array) {
 		/* find our field name */
@@ -261,7 +294,7 @@ function draw_nontemplated_fields_data_source($data_template_id, $local_data_id,
 		unset($form_array[$form_field_name]['default']);
 
 		$current_flag = (isset($field_array['flags']) ? $field_array['flags'] : '');
-		$current_template_flag = (isset($data_template{'t_' . $field_name}) ? $data_template{'t_' . $field_name} : 'on');
+		$current_template_flag = (isset($data_template['t_' . $field_name]) ? $data_template['t_' . $field_name] : 'on');
 
 		if (($current_template_flag != 'on') || ($current_flag == 'ALWAYSTEMPLATE')) {
 			if ($include_hidden_fields == true) {
@@ -269,7 +302,7 @@ function draw_nontemplated_fields_data_source($data_template_id, $local_data_id,
 			} else {
 				unset($form_array[$form_field_name]);
 			}
-		} elseif ((!empty($snmp_query_graph_id)) && (sizeof(db_fetch_assoc_prepared('SELECT id FROM snmp_query_graph_rrd_sv WHERE snmp_query_graph_id = ? AND data_template_id = ? AND field_name = ?', array($snmp_query_graph_id, $data_template_id, $field_name))) > 0)) {
+		} elseif ((!empty($snmp_query_graph_id)) && (cacti_sizeof(db_fetch_assoc_prepared('SELECT id FROM snmp_query_graph_rrd_sv WHERE snmp_query_graph_id = ? AND data_template_id = ? AND field_name = ?', array($snmp_query_graph_id, $data_template_id, $field_name))) > 0)) {
 			if ($include_hidden_fields == true) {
 				$form_array[$form_field_name]['method'] = 'hidden';
 			} else {
@@ -304,7 +337,7 @@ function draw_nontemplated_fields_data_source($data_template_id, $local_data_id,
 		)
 	);
 
-	return (isset($form_array) ? sizeof($form_array) : 0);
+	return (isset($form_array) ? cacti_sizeof($form_array) : 0);
 }
 
 /* draw_nontemplated_fields_data_source_item - draws a form that consists of all non-templated data source
@@ -336,7 +369,7 @@ function draw_nontemplated_fields_data_source_item($data_template_id, &$values_a
 		$form_config_array = array('no_form_tag' => true, 'force_row_color' => true);
 	}
 
-	if (sizeof($values_array)) {
+	if (cacti_sizeof($values_array)) {
 		foreach ($values_array as $rrd) {
 			$form_array = array();
 
@@ -349,9 +382,10 @@ function draw_nontemplated_fields_data_source_item($data_template_id, &$values_a
 			if (empty($rrd['local_data_id'])) { /* this is a template */
 				$data_template_rrd = $rrd;
 			} else { /* this is not a template */
-				$data_template_rrd = db_fetch_row_prepared('SELECT * 
-					FROM data_template_rrd 
-					WHERE id = ?', array($rrd['local_data_template_rrd_id']));
+				$data_template_rrd = db_fetch_row_prepared('SELECT *
+					FROM data_template_rrd
+					WHERE id = ?',
+					array($rrd['local_data_template_rrd_id']));
 			}
 
 			foreach ($struct_data_source_item as $field_name => $field_array) {
@@ -368,16 +402,16 @@ function draw_nontemplated_fields_data_source_item($data_template_id, &$values_a
 
 				/* append the data source item name so the user will recognize it */
 				if ($draw_title_for_each_item == false) {
-					$form_array[$form_field_name]['friendly_name'] .= ' [' . $rrd['data_source_name'] . ']';
+					$form_array[$form_field_name]['friendly_name'] .= ' [' . html_escape($rrd['data_source_name']) . ']';
 				}
 
-				if ($data_template_rrd{'t_' . $field_name} != 'on') {
+				if ($data_template_rrd['t_' . $field_name] != 'on') {
 					if ($include_hidden_fields == true) {
 						$form_array[$form_field_name]['method'] = 'hidden';
 					} else {
 						unset($form_array[$form_field_name]);
 					}
-				} elseif ((!empty($snmp_query_graph_id)) && (sizeof(db_fetch_assoc_prepared('SELECT id FROM snmp_query_graph_rrd_sv WHERE snmp_query_graph_id = ? AND data_template_id = ? AND field_name = ?', array($snmp_query_graph_id, $data_template_id, $field_name))) > 0)) {
+				} elseif ((!empty($snmp_query_graph_id)) && (cacti_sizeof(db_fetch_assoc_prepared('SELECT id FROM snmp_query_graph_rrd_sv WHERE snmp_query_graph_id = ? AND data_template_id = ? AND field_name = ?', array($snmp_query_graph_id, $data_template_id, $field_name))) > 0)) {
 					if ($include_hidden_fields == true) {
 						$form_array[$form_field_name]['method'] = 'hidden';
 					} else {
@@ -387,7 +421,7 @@ function draw_nontemplated_fields_data_source_item($data_template_id, &$values_a
 					if (($draw_any_items == false) && ($draw_title_for_each_item == false) && ($header_title != '')) {
 						print "<div class='tableHeader'><div class='tableSubHeaderColumn'>$header_title</div></div>\n";
 					} elseif (($draw_any_items == false) && ($draw_title_for_each_item == true) && ($header_title != '')) {
-						print "<div class='tableHeader'><div class='tableSubHeaderColumn'>$header_title [" . $rrd['data_source_name'] . "]</div></div>\n";
+						print "<div class='tableHeader'><div class='tableSubHeaderColumn'>$header_title [" . html_escape($rrd['data_source_name']) . "]</div></div>\n";
 					}
 
 					$draw_any_items = true;
@@ -396,16 +430,17 @@ function draw_nontemplated_fields_data_source_item($data_template_id, &$values_a
 					   valid choices for the drop-down box must be fetched from the associated
 					   data input method */
 					if ($field_name == 'data_input_field_id') {
-						$data_input_id = db_fetch_cell_prepared('SELECT data_input_id 
-							FROM data_template_data 
-							WHERE data_template_id = ? 
-							AND local_data_id=0', array($rrd['data_template_id']));
+						$data_input_id = db_fetch_cell_prepared('SELECT data_input_id
+							FROM data_template_data
+							WHERE data_template_id = ?
+							AND local_data_id = 0',
+							array($rrd['data_template_id']));
 
-						$form_array[$form_field_name]['sql'] = "SELECT id, CONCAT(data_name,' - ',name) AS name 
-							FROM data_input_fields 
-							WHERE data_input_id=" . $data_input_id . " 
+						$form_array[$form_field_name]['sql'] = "SELECT id, CONCAT(data_name,' - ',name) AS name
+							FROM data_input_fields
+							WHERE data_input_id=" . $data_input_id . "
 							AND input_output = 'out'
-							AND update_rra='on' 
+							AND update_rra='on'
 							ORDER BY data_name,name";
 					}
 				}
@@ -418,7 +453,7 @@ function draw_nontemplated_fields_data_source_item($data_template_id, &$values_a
 				)
 			);
 
-			$num_fields_drawn += sizeof($form_array);
+			$num_fields_drawn += cacti_sizeof($form_array);
 		}
 	}
 
@@ -439,46 +474,48 @@ function draw_nontemplated_fields_data_source_item($data_template_id, &$values_a
      html input elements or omitted altogether?
    @arg $snmp_query_id - if this graph template is part of a data query, specify the data query id here. this
      will be used to determine if a given field is associated with a suggested value */
-function draw_nontemplated_fields_custom_data($data_template_data_id, $field_name_format = '|field|', 
+function draw_nontemplated_fields_custom_data($data_template_data_id, $field_name_format = '|field|',
 	$header_title = '', $alternate_colors = true, $include_hidden_fields = true, $snmp_query_id = 0) {
 
-	$data = db_fetch_row_prepared('SELECT id, data_input_id, data_template_id, name, local_data_id 
-		FROM data_template_data 
-		WHERE id = ?', array($data_template_data_id));
+	$data = db_fetch_row_prepared('SELECT id, data_input_id, data_template_id, name, local_data_id
+		FROM data_template_data
+		WHERE id = ?',
+		array($data_template_data_id));
 
-	$host_id = db_fetch_cell_prepared('SELECT host.id 
+	$host_id = db_fetch_cell_prepared('SELECT host.id
 		FROM host
-		INNER JOIN data_local 
+		INNER JOIN data_local
 		ON data_local.host_id=host.id
-		WHERE data_local.id = ?', 
+		WHERE data_local.id = ?',
 		array($data['local_data_id']));
 
-	$template_data = db_fetch_row_prepared('SELECT id, data_input_id 
-		FROM data_template_data 
-		WHERE data_template_id = ? AND local_data_id=0', 
+	$template_data = db_fetch_row_prepared('SELECT id, data_input_id
+		FROM data_template_data
+		WHERE data_template_id = ?
+		AND local_data_id = 0',
 		array($data['data_template_id']));
 
 	$draw_any_items = false;
 
 	/* get each INPUT field for this data input source */
-	$fields = db_fetch_assoc_prepared('SELECT * 
-		FROM data_input_fields 
-		WHERE data_input_id = ? 
+	$fields = db_fetch_assoc_prepared('SELECT *
+		FROM data_input_fields
+		WHERE data_input_id = ?
 		AND input_output = "in"
-		ORDER BY sequence', 
+		ORDER BY sequence',
 		array($data['data_input_id']));
 
 	/* loop through each field found */
 	$i = 0;
-	if (sizeof($fields)) {
+	if (cacti_sizeof($fields)) {
 		foreach ($fields as $field) {
-			$data_input_data = db_fetch_row_prepared('SELECT * 
-				FROM data_input_data 
-				WHERE data_template_data_id = ? 
-				AND data_input_field_id = ?', 
+			$data_input_data = db_fetch_row_prepared('SELECT *
+				FROM data_input_data
+				WHERE data_template_data_id = ?
+				AND data_input_field_id = ?',
 				array($data['id'], $field['id']));
 
-			if (sizeof($data_input_data)) {
+			if (cacti_sizeof($data_input_data)) {
 				$old_value = $data_input_data['value'];
 			} else {
 				$old_value = '';
@@ -488,10 +525,11 @@ function draw_nontemplated_fields_custom_data($data_template_data_id, $field_nam
 			if (empty($data['data_template_id'])) {
 				$can_template = 'on';
 			} else {
-				$can_template = db_fetch_cell_prepared('SELECT t_value 
-					FROM data_input_data 
-					WHERE data_template_data_id = ? 
-					AND data_input_field_id = ?', array($template_data['id'], $field['id']));
+				$can_template = db_fetch_cell_prepared('SELECT t_value
+					FROM data_input_data
+					WHERE data_template_data_id = ?
+					AND data_input_field_id = ?',
+					array($template_data['id'], $field['id']));
 			}
 
 			/* find our field name */
@@ -519,7 +557,7 @@ function draw_nontemplated_fields_custom_data($data_template_data_id, $field_nam
 
 				print "<div class='formRow'>\n";
 
-				print "<div class='formColumnLeft'><div class='formFieldName'>" . $field['name'] . "</div></div>\n";
+				print "<div class='formColumnLeft'><div class='formFieldName'>" . html_escape($field['name']) . "</div></div>\n";
 				print "<div class='formColumnRight'>";
 
 				draw_custom_data_row($form_field_name, $field['id'], $data['id'], $old_value);
@@ -545,9 +583,10 @@ function draw_nontemplated_fields_custom_data($data_template_data_id, $field_nam
      belongs to
    @arg $current_value - the current value of this field */
 function draw_custom_data_row($field_name, $data_input_field_id, $data_template_data_id, $current_value) {
-	$field = db_fetch_row_prepared('SELECT data_name, type_code 
-		FROM data_input_fields 
-		WHERE id = ?', array($data_input_field_id));
+	$field = db_fetch_row_prepared('SELECT data_name, type_code
+		FROM data_input_fields
+		WHERE id = ?',
+		array($data_input_field_id));
 
 	if (($field['type_code'] == 'index_type') && (db_fetch_cell_prepared('SELECT local_data_id FROM data_template_data WHERE id = ?', array($data_template_data_id)) > 0)) {
 		$index_type = db_fetch_assoc_prepared('SELECT
@@ -556,10 +595,11 @@ function draw_custom_data_row($field_name, $data_input_field_id, $data_template_
 			WHERE data_template_data.local_data_id=data_local.id
 			AND data_local.snmp_query_id=host_snmp_cache.snmp_query_id
 			AND data_template_data.id = ?
-			GROUP BY host_snmp_cache.field_name', array($data_template_data_id));
+			GROUP BY host_snmp_cache.field_name',
+			array($data_template_data_id));
 
-		if (sizeof($index_type) == 0) {
-			print "<em>" . __('Data Query Data Sources must be created through %s', "<a href='" . htmlspecialchars('graphs_new.php') . "'>" . __('New Graphs') . ".</a>") . "</em>\n";
+		if (cacti_sizeof($index_type) == 0) {
+			print "<em>" . __('Data Query Data Sources must be created through %s', "<a href='graphs_new.php'>" . __('New Graphs') . ".</a>") . "</em>\n";
 		} else {
 			form_dropdown($field_name, $index_type, 'field_name', 'field_name', $current_value, '', '', '');
 		}
@@ -571,10 +611,11 @@ function draw_custom_data_row($field_name, $data_input_field_id, $data_template_
 			WHERE data_template_data.local_data_id=data_local.id
 			AND data_local.snmp_query_id=snmp_query_graph.snmp_query_id
 			AND data_template_data.id = ?
-			GROUP BY snmp_query_graph.id', array($data_template_data_id));
+			GROUP BY snmp_query_graph.id',
+			array($data_template_data_id));
 
-		if (sizeof($output_type) == 0) {
-			print "<em>" . __('Data Query Data Sources must be created through %s', "<a href='" . htmlspecialchars('graphs_new.php') . "'>" . __('New Graphs') . ".</a>") . "</em>\n";
+		if (cacti_sizeof($output_type) == 0) {
+			print "<em>" . __('Data Query Data Sources must be created through %s', "<a href='graphs_new.php'>" . __('New Graphs') . ".</a>") . "</em>\n";
 		} else {
 			form_dropdown($field_name, $output_type, 'name', 'id', $current_value, '', '', '');
 		}
