@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2017 The Cacti Group                                 |
+ | Copyright (C) 2004-2018 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -59,7 +59,7 @@ function duplicate_reports($_id, $_title) {
 	$reports_id  = sql_save($save, 'reports');
 
 	/* create new rule items */
-	if (sizeof($reports_items) > 0) {
+	if (cacti_sizeof($reports_items) > 0) {
 		foreach ($reports_items as $reports_item) {
 			$save = $reports_item;
 			$save['id'] = 0;
@@ -69,20 +69,88 @@ function duplicate_reports($_id, $_title) {
 	}
 }
 
+function reports_add_graphs($report_id, $local_graph_id, $timespan, $align) {
+	$report_user = db_fetch_cell_prepared('SELECT user_id
+		FROM reports
+		WHERE id = ?',
+		array($report_id));
+
+	if ($report_user != $_SESSION['sess_user_id']) {
+		raise_message('reports_not_owner');
+
+		return false;
+	} else {
+		$sequence = db_fetch_cell_prepared('SELECT MAX(sequence)
+			FROM reports_items
+			WHERE report_id = ?',
+			array($report_id)) + 1;
+
+		$existing = db_fetch_cell_prepared('SELECT id
+			FROM reports_items
+			WHERE local_graph_id = ?
+			AND report_id = ?
+			AND timespan = ?',
+			array($local_graph_id, $report_id, $timespan));
+
+		if (!$existing) {
+			$gd = db_fetch_row_prepared('SELECT *
+				FROM graph_local
+				WHERE id = ?',
+				array($local_graph_id));
+
+			$host_template_id = db_fetch_cell_prepared('SELECT host_template_id
+				FROM host
+				WHERE id = ?',
+				array($gd['host_id']));
+
+			if (cacti_sizeof($gd)) {
+				db_execute_prepared('INSERT INTO reports_items
+					(report_id, item_type, host_template_id, host_id, graph_template_id, local_graph_id, timespan, align, sequence)
+					VALUES (?, 1, ?, ?, ?, ?, ?, ?, ?)',
+					array(
+						$report_id,
+						$host_template_id,
+						$gd['host_id'],
+						$gd['graph_template_id'],
+						$local_graph_id,
+						$timespan,
+						$align,
+						$sequence
+					)
+				);
+
+				return true;
+			} else {
+				raise_message('reports_graph_not_found');
+
+				return false;
+			}
+		} else {
+			return true;
+		}
+	}
+}
+
 /** reports_date_time_format		fetches the date/time formatting information for current user
  * @return string	- string defining the datetime format specific to this user
  */
 function reports_date_time_format() {
-	global $datechar;
+	$datechar = array(
+		GDC_HYPHEN => '-',
+		GDC_SLASH  => '/',
+		GDC_DOT    => '.'
+	);
 
 	$graph_date = '';
 
 	/* setup date format */
-	$date_fmt = read_user_setting('default_date_format');
+	$date_fmt        = read_config_option('default_date_format');
 	$dateCharSetting = read_config_option('default_datechar');
+
 	if (empty($dateCharSetting)) {
 		$dateCharSetting = GDC_SLASH;
 	}
+
 	$datecharacter = $datechar[$dateCharSetting];
 
 	switch ($date_fmt) {
@@ -198,6 +266,15 @@ function utime_add($timestamp, $yr=0, $mon=0, $day=0, $hr=0, $min=0, $sec=0) {
  @param bool $output 	- whether to output the log line to the browser using pring() or not
  @param string $environ - tell's from where the script was called from */
 function reports_log($string, $output = false, $environ='REPORTS', $level=POLLER_VERBOSITY_NONE) {
+	# Define REPORTS_DEBUG if not already set
+	if (!defined('REPORTS_DEBUG')) {
+		if (function_exists('read_config_option')) {
+			define('REPORTS_DEBUG', read_config_option('reports_log_verbosity'));
+		} else {
+			define('REPORTS_DEBUG', 1);
+		}
+	}
+
 	# if current verbosity >= level of current message, print it
 	if (strstr($string, 'STATS')) {
 		cacti_log($string, $output, 'SYSTEM');
@@ -212,16 +289,24 @@ function reports_log($string, $output = false, $environ='REPORTS', $level=POLLER
  */
 function generate_report($report, $force = false) {
 	global $config, $alignment;
+
 	include_once($config['base_path'] . '/lib/time.php');
 	include_once($config['base_path'] . '/lib/rrd.php');
+	include_once($config['base_path'] . '/lib/html_reports.php');
 
 	reports_log(__FUNCTION__ . ', report_id: ' . $report['id'], false, 'REPORTS TRACE', POLLER_VERBOSITY_MEDIUM);
 
+	if (!reports_html_account_exists($report['user_id'])) {
+		reports_html_report_disable($report['id']);
+		return false;
+	}
+
 	$theme = 'classic';
 
 	$body = reports_generate_html($report['id'], REPORTS_OUTPUT_EMAIL, $theme);
 
 	$time = time();
+
 	# get config option for first-day-of-the-week
 	$first_weekdayid = read_user_setting('first_weekdayid', false, false, $report['user_id']);
 
@@ -249,7 +334,7 @@ function generate_report($report, $force = false) {
 
 	$xport_meta = array();
 
-	if (sizeof($graphs)) {
+	if (cacti_sizeof($graphs)) {
 		foreach($graphs as $key => $local_graph_id) {
 			$arr = explode(':', $key);
 			$timesp = $arr[1];
@@ -398,21 +483,13 @@ function generate_report($report, $force = false) {
 	if ($error != '') {
 		if (isset_request_var('id')) {
 			$_SESSION['reports_error'] = "Problems sending Report '" . $report['name'] . "'.  Problem with e-mail Subsystem Error is '$error'";
-
-			if (!isset_request_var('selected_items')) {
-				raise_message('reports_error');
-			}
 		} else {
 			reports_log(__FUNCTION__ . ", Problems sending Report '" . $report['name'] . "'.  Problem with e-mail Subsystem Error is '$error'", false, 'REPORTS', POLLER_VERBOSITY_LOW);
 		}
 
 		return false;
 	} elseif (isset($_REQUEST)) {
-		$_SESSION['reports_message'] = "Report '" . $report['name'] . "' Sent Successfully";
-
-		if (!isset_request_var('selected_items')) {
-			raise_message('reports_message');
-		}
+		$_SESSION['reports_info'] = "Report '" . $report['name'] . "' Sent Successfully";
 
 		$int = read_config_option('poller_interval');
 
@@ -452,7 +529,7 @@ function reports_load_format_file($format_file, &$output, &$report_tag_included,
 	$output   = '';
 	$report_tag_included = false;
 
-	if (sizeof($contents)) {
+	if (cacti_sizeof($contents)) {
 		foreach($contents as $line) {
 			$line = trim($line);
 			if (substr_count($line, '<REPORT>')) {
@@ -460,7 +537,7 @@ function reports_load_format_file($format_file, &$output, &$report_tag_included,
 			}
 
 			if (substr($line, 0, 1) != '#') {
-				$output .= $line . "\n";
+				$output .= $line . PHP_EOL;
 			} elseif (strstr($line, 'Theme:') !== false) {
 				$tparts = explode(':', $line);
 				$theme  = trim($tparts[1]);
@@ -539,7 +616,7 @@ function reports_tree_has_graphs($tree_id, $branch_id, $effective_user, $search_
 	}
 
 	/* verify permissions */
-	if (sizeof($graphs)) {
+	if (cacti_sizeof($graphs)) {
 		foreach($graphs as $key => $id) {
 			if (!is_graph_allowed($id, $effective_user)) {
 				unset($graphs[$key]);
@@ -547,7 +624,7 @@ function reports_tree_has_graphs($tree_id, $branch_id, $effective_user, $search_
 		}
 	}
 
-	return sizeof($graphs);
+	return cacti_sizeof($graphs);
 }
 
 
@@ -557,7 +634,7 @@ function reports_tree_has_graphs($tree_id, $branch_id, $effective_user, $search_
  * @return string			- generated html output
  */
 function reports_generate_html($reports_id, $output = REPORTS_OUTPUT_STDOUT, &$theme = '') {
-	global $config, $colors;
+	global $config;
 	global $alignment;
 
 	include_once($config['base_path'] . '/lib/time.php');
@@ -607,27 +684,27 @@ function reports_generate_html($reports_id, $output = REPORTS_OUTPUT_STDOUT, &$t
 		$include_body = true;
 	}
 
-	reports_log(__FUNCTION__ . ', items found: ' . sizeof($reports_items), false, 'REPORTS TRACE', POLLER_VERBOSITY_MEDIUM);
+	reports_log(__FUNCTION__ . ', items found: ' . cacti_sizeof($reports_items), false, 'REPORTS TRACE', POLLER_VERBOSITY_MEDIUM);
 
-	if (sizeof($reports_items)) {
+	if (cacti_sizeof($reports_items)) {
 		if ($output == REPORTS_OUTPUT_EMAIL && $include_body) {
-			$outstr .= "<body>\n";
+			$outstr .= "<body>" . PHP_EOL;
 		}
 		if ($format_ok) {
-			$outstr .= "\t<table class='report_table'>\n";
+			$outstr .= "\t<table class='report_table'>" . PHP_EOL;
 		} else {
-			$outstr .= "\t<table class='report_table' " . ($output == REPORTS_OUTPUT_STDOUT ? "style='background-color:#F9F9F9;'":'') . ">\n";
+			$outstr .= "\t<table class='report_table' " . ($output == REPORTS_OUTPUT_STDOUT ? "style='background-color:#F9F9F9;'":'') . ">" . PHP_EOL;
 		}
 
-		$outstr .= "\t\t<tr class='title_row'>\n";
+		$outstr .= "\t\t<tr class='title_row'>" . PHP_EOL;
 		if ($format_ok) {
-			$outstr .= "\t\t\t<td class='title' style='text-align:" . $alignment[$report['alignment']] . ";'>\n";
+			$outstr .= "\t\t\t<td class='title' style='text-align:" . $alignment[$report['alignment']] . ";'>" . PHP_EOL;
 		} else {
-			$outstr .= "\t\t\t<td class='title' style='text-align:" . $alignment[$report['alignment']] . ";font-size:" . $report['font_size'] . "pt;'>\n";
+			$outstr .= "\t\t\t<td class='title' style='text-align:" . $alignment[$report['alignment']] . ";font-size:" . $report['font_size'] . "pt;'>" . PHP_EOL;
 		}
-		$outstr .= "\t\t\t\t" . $report['name'] . "\n";
-		$outstr .= "\t\t\t</td>\n";
-		$outstr .= "\t\t</tr>\n";
+		$outstr .= "\t\t\t\t" . $report['name'] . PHP_EOL;
+		$outstr .= "\t\t\t</td>" . PHP_EOL;
+		$outstr .= "\t\t</tr>" . PHP_EOL;
 		# this function should be called only at the appropriate targeted time when in batch mode
 		# but for preview mode we can't use the targeted time
 		# so let's use time()
@@ -649,48 +726,48 @@ function reports_generate_html($reports_id, $output = REPORTS_OUTPUT_STDOUT, &$t
 					get_timespan($timespan, $time, $item['timespan'], $first_weekdayid);
 
 					if ($column == 0) {
-						$outstr .= "\t\t<tr class='image_row'>\n";
-						$outstr .= "\t\t\t<td style='text-align:" . $alignment[$item['align']] . ";'>\n";
+						$outstr .= "\t\t<tr class='image_row'>" . PHP_EOL;
+						$outstr .= "\t\t\t<td style='text-align:" . $alignment[$item['align']] . ";'>" . PHP_EOL;
 
 						if ($format_ok) {
-							$outstr .= "\t\t\t\t<table class='image_table'>\n";
+							$outstr .= "\t\t\t\t<table class='image_table'>" . PHP_EOL;
 						} else {
-							$outstr .= "\t\t\t\t<table>\n";
+							$outstr .= "\t\t\t\t<table>" . PHP_EOL;
 						}
 
-						$outstr .= "\t\t\t\t\t<tr>\n";
+						$outstr .= "\t\t\t\t\t<tr>" . PHP_EOL;
 					}
 
 					if ($format_ok) {
-						$outstr .= "\t\t\t\t\t\t<td class='image_column' style='text-align:" . $alignment[$item['align']] . ";'>\n";
+						$outstr .= "\t\t\t\t\t\t<td class='image_column' style='text-align:" . $alignment[$item['align']] . ";'>" . PHP_EOL;
 					} else {
-						$outstr .= "\t\t\t\t\t\t<td style='padding:5px;text-align:" . $alignment[$item['align']] . ";'>\n";
+						$outstr .= "\t\t\t\t\t\t<td style='padding:5px;text-align:" . $alignment[$item['align']] . ";'>" . PHP_EOL;
 					}
 
-					$outstr .= "\t\t\t\t\t\t\t" . reports_graph_image($report, $item, $timespan, $output, $theme) . "\n";
-					$outstr .= "\t\t\t\t\t\t</td>\n";
+					$outstr .= "\t\t\t\t\t\t\t" . reports_graph_image($report, $item, $timespan, $output, $theme) . PHP_EOL;
+					$outstr .= "\t\t\t\t\t\t</td>" . PHP_EOL;
 
 					if ($report['graph_columns'] > 1) {
 						$column = ($column + 1) % ($report['graph_columns']);
 					}
 
 					if ($column == 0) {
-						$outstr .= "\t\t\t\t\t</tr>\n";
-						$outstr .= "\t\t\t\t</table>\n";
-						$outstr .= "\t\t\t</td>\n";
-						$outstr .= "\t\t</tr>\n";
+						$outstr .= "\t\t\t\t\t</tr>" . PHP_EOL;
+						$outstr .= "\t\t\t\t</table>" . PHP_EOL;
+						$outstr .= "\t\t\t</td>" . PHP_EOL;
+						$outstr .= "\t\t</tr>" . PHP_EOL;
 					}
 				}
 			} elseif ($item['item_type'] == REPORTS_ITEM_TEXT) {
-				$outstr .= "\t\t<tr class='text_row'>\n";
+				$outstr .= "\t\t<tr class='text_row'>" . PHP_EOL;
 				if ($format_ok) {
-					$outstr .= "\t\t\t<td style='text-align:" . $alignment[$item['align']] . ";' class='text'>\n";
+					$outstr .= "\t\t\t<td style='text-align:" . $alignment[$item['align']] . ";' class='text'>" . PHP_EOL;
 				} else {
-					$outstr .= "\t\t\t<td style='text-align:" . $alignment[$item['align']] . ";font-size: " . $item['font_size'] . "pt;' class='text'>\n";
+					$outstr .= "\t\t\t<td style='text-align:" . $alignment[$item['align']] . ";font-size: " . $item['font_size'] . "pt;' class='text'>" . PHP_EOL;
 				}
-				$outstr .= "\t\t\t\t" . $item['item_text'] . "\n";
-				$outstr .= "\t\t\t</td>\n";
-				$outstr .= "\t\t</tr>\n";
+				$outstr .= "\t\t\t\t" . $item['item_text'] . PHP_EOL;
+				$outstr .= "\t\t\t</td>" . PHP_EOL;
+				$outstr .= "\t\t</tr>" . PHP_EOL;
 
 				/* start a new section */
 				$column = 0;
@@ -707,7 +784,7 @@ function reports_generate_html($reports_id, $output = REPORTS_OUTPUT_STDOUT, &$t
 			}
 		}
 
-		$outstr .= "\t</table>\n";
+		$outstr .= "\t</table>" . PHP_EOL;
 		if ($output == REPORTS_OUTPUT_EMAIL && $include_body) {
 			$outstr .= '</body>';
 		}
@@ -717,7 +794,7 @@ function reports_generate_html($reports_id, $output = REPORTS_OUTPUT_STDOUT, &$t
 		if ($report_tag) {
 			return str_replace('<REPORT>', $outstr, $format_data);
 		} else {
-			return $format_data . "\n" . $outstr;
+			return $format_data . PHP_EOL . $outstr;
 		}
 	} else {
 		return $outstr;
@@ -739,7 +816,7 @@ function expand_branch(&$report, &$item, $branch_id, $output, $format_ok, $theme
 		AND graph_tree_id = ?
 		ORDER BY position', array($branch_id, $item['tree_id']));
 
-	if (sizeof($tree_branches)) {
+	if (cacti_sizeof($tree_branches)) {
 		foreach ($tree_branches as $branch) {
 			$outstr .= expand_branch($report, $item, $branch['id'], $output, $format_ok, $theme);
 		}
@@ -779,7 +856,7 @@ function expand_branch(&$report, &$item, $branch_id, $output, $format_ok, $theme
 		$out = "<a href='" . html_escape(read_config_option('base_url') . '/graph.php?action=view&local_graph_id='.$item['local_graph_id']."&rra_id=0") . "'>" . $out . '</a>';
 	}
 
-	return $out . "\n";
+	return $out . PHP_EOL;
 }
 
 
@@ -793,7 +870,7 @@ function expand_branch(&$report, &$item, $branch_id, $output, $format_ok, $theme
  * @return string			- html
  */
 function reports_expand_tree($report, $item, $parent, $output, $format_ok, $theme = 'classic', $nested = false) {
-	global $colors, $config, $alignment;
+	global $config, $alignment;
 
 	include($config['include_path'] . '/global_arrays.php');
 	include_once($config['library_path'] . '/data_query.php');
@@ -830,19 +907,21 @@ function reports_expand_tree($report, $item, $parent, $output, $format_ok, $them
 		$leaves = db_fetch_assoc_prepared('SELECT *
 			FROM graph_tree_items
 			WHERE graph_tree_id = ?
-			AND parent = ?',
+			AND parent = ?
+			ORDER BY position',
 			array($tree_id, $parent));
 	} elseif (is_device_allowed($device_id, $user)) {
 		$leaves = db_fetch_assoc_prepared('SELECT *
 			FROM graph_tree_items
 			WHERE graph_tree_id = ?
-			AND id = ?',
+			AND id = ?
+			ORDER BY position',
 			array($tree_id, $parent));
 	} else{
 		$leaves = array();
 	}
 
-	if (sizeof($leaves)) {
+	if (cacti_sizeof($leaves)) {
 		foreach ($leaves as $leaf) {
 			$sql_where       = '';
 			$title           = '';
@@ -943,18 +1022,18 @@ function reports_expand_tree($report, $item, $parent, $output, $format_ok, $them
 					}
 				}
 
-				if (sizeof($mygraphs)) {
+				if (cacti_sizeof($mygraphs)) {
 					/* start graph display */
 					if ($title != '') {
-						$outstr .= "\t\t<tr class='text_row'>\n";
+						$outstr .= "\t\t<tr class='text_row'>" . PHP_EOL;
 						if ($format_ok) {
-							$outstr .= "\t\t\t<td class='text' style='text-align:" . $alignment[$item['align']] . "'>\n";
+							$outstr .= "\t\t\t<td class='text' style='text-align:" . $alignment[$item['align']] . "'>" . PHP_EOL;
 						} else {
-							$outstr .= "\t\t\t<td class='text' style='text-align:" . $alignment[$item['align']] . ";font-size: " . $item['font_size'] . "pt;'>\n";
+							$outstr .= "\t\t\t<td class='text' style='text-align:" . $alignment[$item['align']] . ";font-size: " . $item['font_size'] . "pt;'>" . PHP_EOL;
 						}
-						$outstr .= "\t\t\t\t$title\n";
-						$outstr .= "\t\t\t</td>\n";
-						$outstr .= "\t\t</tr>\n";
+						$outstr .= "\t\t\t\t$title" . PHP_EOL;
+						$outstr .= "\t\t\t</td>" . PHP_EOL;
+						$outstr .= "\t\t</tr>" . PHP_EOL;
 					}
 
 					$outstr .= reports_graph_area($mygraphs, $report, $item, $timespan, $output, $format_ok, $theme);
@@ -972,15 +1051,15 @@ function reports_expand_tree($report, $item, $parent, $output, $format_ok, $them
 				/* start graph display */
 				if ($graph > 0) {
 					if ($title != '') {
-						$outstr .= "\t\t<tr class='text_row'>\n";
+						$outstr .= "\t\t<tr class='text_row'>" . PHP_EOL;
 						if ($format_ok) {
-							$outstr .= "\t\t\t<td class='text' style='text-align:" . $alignment[$item['align']] . ";'>\n";
+							$outstr .= "\t\t\t<td class='text' style='text-align:" . $alignment[$item['align']] . ";'>" . PHP_EOL;
 						} else {
-							$outstr .= "\t\t\t<td class='text' style='text-align:" . $alignment[$item['align']] . ";font-size: " . $item['font_size'] . "pt;'>\n";
+							$outstr .= "\t\t\t<td class='text' style='text-align:" . $alignment[$item['align']] . ";font-size: " . $item['font_size'] . "pt;'>" . PHP_EOL;
 						}
-						$outstr .= "\t\t\t\t$title\n";
-						$outstr .= "\t\t\t</td>\n";
-						$outstr .= "\t\t</tr>\n";
+						$outstr .= "\t\t\t\t$title" . PHP_EOL;
+						$outstr .= "\t\t\t</td>" . PHP_EOL;
+						$outstr .= "\t\t</tr>" . PHP_EOL;
 					}
 
 					$graph_list = array(array('local_graph_id' => $leaf['local_graph_id'], 'title_cache' => $graph_name));
@@ -1003,7 +1082,7 @@ function reports_expand_tree($report, $item, $parent, $output, $format_ok, $them
 						'id', 'name'
 					);
 
-					if (sizeof($graph_templates)) {
+					if (cacti_sizeof($graph_templates)) {
 						foreach($graph_templates AS $id => $name) {
 							if (!is_graph_template_allowed($id, $user)) {
 								unset($graph_templates[$id]);
@@ -1020,7 +1099,7 @@ function reports_expand_tree($report, $item, $parent, $output, $format_ok, $them
 					);
 
 					$outgraphs = array();
-					if (sizeof($graph_templates) > 0) {
+					if (cacti_sizeof($graph_templates) > 0) {
 						foreach ($graph_templates as $id => $name) {
 							$graphs = db_fetch_assoc('SELECT
 								gtg.local_graph_id, gtg.title_cache
@@ -1032,7 +1111,7 @@ function reports_expand_tree($report, $item, $parent, $output, $format_ok, $them
 								$sql_where
 								ORDER BY gtg.title_cache");
 
-							if (sizeof($graphs)) {
+							if (cacti_sizeof($graphs)) {
 								foreach($graphs as $key => $graph) {
 									if (!is_graph_allowed($graph['local_graph_id'], $user)) {
 										unset($graphs[$key]);
@@ -1042,23 +1121,23 @@ function reports_expand_tree($report, $item, $parent, $output, $format_ok, $them
 							$outgraphs = array_merge($outgraphs, $graphs);
 						}
 
-						if (sizeof($outgraphs)) {
+						if (cacti_sizeof($outgraphs)) {
 							/* let's sort the graphs naturally */
 							usort($outgraphs, 'necturally_sort_graphs');
 
 							/* start graph display */
 							if ($title != '') {
-								$outstr .= "\t\t<tr class='text_row'>\n";
+								$outstr .= "\t\t<tr class='text_row'>" . PHP_EOL;
 
 								if ($format_ok) {
-									$outstr .= "\t\t\t<td class='text' style='text-align:" . $alignment[$item['align']] . "';>\n";
+									$outstr .= "\t\t\t<td class='text' style='text-align:" . $alignment[$item['align']] . "';>" . PHP_EOL;
 								} else {
-									$outstr .= "\t\t\t<td class='text' style='text-align:" . $alignment[$item['align']] . ";font-size: " . $item['font_size'] . "pt;'>\n";
+									$outstr .= "\t\t\t<td class='text' style='text-align:" . $alignment[$item['align']] . ";font-size: " . $item['font_size'] . "pt;'>" . PHP_EOL;
 								}
 
-								$outstr .= "\t\t\t\t$title\n";
-								$outstr .= "\t\t\t</td>\n";
-								$outstr .= "\t\t</tr>\n";
+								$outstr .= "\t\t\t\t$title" . PHP_EOL;
+								$outstr .= "\t\t\t</td>" . PHP_EOL;
+								$outstr .= "\t\t</tr>" . PHP_EOL;
 							}
 
 							$outstr .= reports_graph_area($outgraphs, $report, $item, $timespan, $output, $format_ok, $theme);
@@ -1080,13 +1159,13 @@ function reports_expand_tree($report, $item, $parent, $output, $format_ok, $them
 						array_push($data_queries,
 							array(
 								'id' => '0',
-								'name' => 'Non Query Based'
+								'name' => __('(Non Query Based)')
 							)
 						);
 					}
 
 					$i = 0;
-					if (sizeof($data_queries)) {
+					if (cacti_sizeof($data_queries)) {
 						foreach ($data_queries as $data_query) {
 							/* fetch a list of field names that are sorted by the preferred sort field */
 							$sort_field_data = get_formatted_data_query_indexes($leaf['host_id'], $data_query['id']);
@@ -1102,7 +1181,7 @@ function reports_expand_tree($report, $item, $parent, $output, $format_ok, $them
 								$sql_where
 								ORDER BY gtg.title_cache");
 
-							if (sizeof($graphs)) {
+							if (cacti_sizeof($graphs)) {
 								foreach($graphs as $key => $graph) {
 									if (!is_graph_allowed($graph['local_graph_id'], $user)) {
 										unset($graphs[$key]);
@@ -1111,32 +1190,32 @@ function reports_expand_tree($report, $item, $parent, $output, $format_ok, $them
 							}
 
 							/* re-key the results on data query index */
-							if (sizeof($graphs)) {
+							if (cacti_sizeof($graphs)) {
 								if ($i == 0) {
 									/* start graph display */
 									if ($title != '') {
-										$outstr .= "\t\t<tr class='text_row'>\n";
+										$outstr .= "\t\t<tr class='text_row'>" . PHP_EOL;
 										if ($format_ok) {
-											$outstr .= "\t\t\t<td class='text' style='text-align:" . $alignment[$item['align']] . ";'>\n";
+											$outstr .= "\t\t\t<td class='text' style='text-align:" . $alignment[$item['align']] . ";'>" . PHP_EOL;
 										} else {
-											$outstr .= "\t\t\t<td class='text' style='text-align:" . $alignment[$item['align']] . ";font-size: " . $item['font_size'] . "pt;'>\n";
+											$outstr .= "\t\t\t<td class='text' style='text-align:" . $alignment[$item['align']] . ";font-size: " . $item['font_size'] . "pt;'>" . PHP_EOL;
 										}
-										$outstr .= "\t\t\t\t$title\n";
-										$outstr .= "\t\t\t</td>\n";
-										$outstr .= "\t\t</tr>\n";
+										$outstr .= "\t\t\t\t$title" . PHP_EOL;
+										$outstr .= "\t\t\t</td>" . PHP_EOL;
+										$outstr .= "\t\t</tr>" . PHP_EOL;
 									}
 								}
 								$i++;
 
-								$outstr .= "\t\t<tr class='text_row'>\n";
+								$outstr .= "\t\t<tr class='text_row'>" . PHP_EOL;
 								if ($format_ok) {
-									$outstr .= "\t\t\t<td class='text' style='text-align:" . $alignment[$item['align']] . ";'><strong>Data Query:</strong> " . $data_query['name'] . "\n";
-									$outstr .= "\t\t\t</td>\n";
-									$outstr .= "\t\t</tr>\n";
+									$outstr .= "\t\t\t<td class='text' style='text-align:" . $alignment[$item['align']] . ";'><strong>" . __('Data Query:') . "</strong> " . $data_query['name'] . PHP_EOL;
+									$outstr .= "\t\t\t</td>" . PHP_EOL;
+									$outstr .= "\t\t</tr>" . PHP_EOL;
 								} else {
-									$outstr .= "\t\t\t<td class='text' style='text-align:" . $alignment[$item['align']] . ";font-size: " . $item['font_size'] . "pt;'><strong>Data Query:</strong> " . $data_query['name'] . "\n";
-									$outstr .= "\t\t\t</td>\n";
-									$outstr .= "\t\t</tr>\n";
+									$outstr .= "\t\t\t<td class='text' style='text-align:" . $alignment[$item['align']] . ";font-size: " . $item['font_size'] . "pt;'><strong>" . __('Data Query:') . "</strong> " . $data_query['name'] . PHP_EOL;
+									$outstr .= "\t\t\t</td>" . PHP_EOL;
+									$outstr .= "\t\t</tr>" . PHP_EOL;
 								}
 
 								/* let's sort the graphs naturally */
@@ -1159,7 +1238,7 @@ function reports_expand_tree($report, $item, $parent, $output, $format_ok, $them
 								}
 							}
 
-							if (sizeof($graph_list)) {
+							if (cacti_sizeof($graph_list)) {
 								$outstr .= reports_graph_area($graph_list, $report, $item, $timespan, $output, $format_ok, $theme);
 							}
 						}
@@ -1200,43 +1279,43 @@ function reports_graph_area($graphs, $report, $item, $timespan, $output, $format
 	$column = 0;
 	$outstr = '';
 
-	if (sizeof($graphs)) {
+	if (cacti_sizeof($graphs)) {
 		foreach($graphs as $graph) {
 			$item['local_graph_id'] = $graph['local_graph_id'];
 
 			if ($column == 0) {
-				$outstr .= "\t\t<tr class='image_row'>\n";
-				$outstr .= "\t\t\t<td style='text-align:" . $alignment[$item['align']] . ";'>\n";
-				$outstr .= "\t\t\t\t<table style='width:100%;'>\n";
-				$outstr .= "\t\t\t\t\t<tr>\n";
+				$outstr .= "\t\t<tr class='image_row'>" . PHP_EOL;
+				$outstr .= "\t\t\t<td style='text-align:" . $alignment[$item['align']] . ";'>" . PHP_EOL;
+				$outstr .= "\t\t\t\t<table style='width:100%;'>" . PHP_EOL;
+				$outstr .= "\t\t\t\t\t<tr>" . PHP_EOL;
 			}
 			if ($format_ok) {
-				$outstr .= "\t\t\t\t\t\t<td class='image_column' style='text-align:" . $alignment[$item['align']] . ";'>\n";
+				$outstr .= "\t\t\t\t\t\t<td class='image_column' style='text-align:" . $alignment[$item['align']] . ";'>" . PHP_EOL;
 			} else {
-				$outstr .= "\t\t\t\t\t\t<td style='padding:5px;text-align='" . $alignment[$item['align']] . ";'>\n";
+				$outstr .= "\t\t\t\t\t\t<td style='padding:5px;text-align='" . $alignment[$item['align']] . ";'>" . PHP_EOL;
 			}
 
-			$outstr .= "\t\t\t\t\t\t\t" . reports_graph_image($report, $item, $timespan, $output, $theme) . "\n";
-			$outstr .= "\t\t\t\t\t\t</td>\n";
+			$outstr .= "\t\t\t\t\t\t\t" . reports_graph_image($report, $item, $timespan, $output, $theme) . PHP_EOL;
+			$outstr .= "\t\t\t\t\t\t</td>" . PHP_EOL;
 
 			if ($report['graph_columns'] > 1) {
 				$column = ($column + 1) % ($report['graph_columns']);
 			}
 
 			if ($column == 0) {
-				$outstr .= "\t\t\t\t\t</tr>\n";
-				$outstr .= "\t\t\t\t</table>\n";
-				$outstr .= "\t\t\t</td>\n";
-				$outstr .= "\t\t</tr>\n";
+				$outstr .= "\t\t\t\t\t</tr>" . PHP_EOL;
+				$outstr .= "\t\t\t\t</table>" . PHP_EOL;
+				$outstr .= "\t\t\t</td>" . PHP_EOL;
+				$outstr .= "\t\t</tr>" . PHP_EOL;
 			}
 		}
 	}
 
 	if ($column > 0) {
-		$outstr .= "\t\t\t\t\t</tr>\n";
-		$outstr .= "\t\t\t\t</table>\n";
-		$outstr .= "\t\t\t</td>\n";
-		$outstr .= "\t\t</tr>\n";
+		$outstr .= "\t\t\t\t\t</tr>" . PHP_EOL;
+		$outstr .= "\t\t\t\t</table>" . PHP_EOL;
+		$outstr .= "\t\t\t</td>" . PHP_EOL;
+		$outstr .= "\t\t</tr>" . PHP_EOL;
 	}
 
 	return $outstr;
@@ -1345,12 +1424,12 @@ function reports_get_format_files() {
 			closedir($dh);
 		}
 
-		if (sizeof($files)) {
+		if (cacti_sizeof($files)) {
 			foreach($files as $file) {
 				if (substr_count($file, '.format')) {
 					$contents = file($dir . '/' . $file);
 
-					if (sizeof($contents)) {
+					if (cacti_sizeof($contents)) {
 						foreach($contents as $line) {
 							$line = trim($line);
 							if (substr_count($line, 'Description:') && substr($line, 0, 1) == '#') {
@@ -1431,7 +1510,7 @@ function reports_error_handler($errno, $errmsg, $filename, $linenum, $vars) {
 		cacti_debug_backtrace('REPORTS', true);
 
 		if (isset($GLOBALS['error_fatal'])) {
-			if($GLOBALS['error_fatal'] & $errno) die('fatal');
+			if($GLOBALS['error_fatal'] & $errno) die("Fatal error $errno" . PHP_EOL);
 		}
 	}
 
@@ -1457,7 +1536,7 @@ function reports_graphs_action_array($action) {
  * returns array $save				-
  *  */
 function reports_graphs_action_prepare($save) {
-	global $colors, $config, $graph_timespans, $alignment;
+	global $config, $graph_timespans, $alignment;
 
 	if ($save['drp_action'] == 'reports') { /* report */
 		print "<tr>
@@ -1524,7 +1603,7 @@ function reports_graphs_action_execute($action) {
 						array($local_graph_id, $reports_id, get_nfilter_request_var('timespan')));
 
 					if (!$existing) {
-						$sequence = db_fetch_cell_prepared('SELECT max(sequence)
+						$sequence = db_fetch_cell_prepared('SELECT MAX(sequence)
 							FROM reports_items
 							WHERE report_id = ?',
 							array($reports_id));
@@ -1576,9 +1655,9 @@ function reports_graphs_action_execute($action) {
 		}
 
 		if ($message != '') {
-			$_SESSION['reports_message'] = $message;
+			$_SESSION['reports_info'] = $message;
 		}
-		raise_message('reports_message');
+		raise_message('reports_info');
 	} else {
 		return $action;
 	}
