@@ -22,19 +22,30 @@
  +-------------------------------------------------------------------------+
 */
 
-/* We are not talking to the browser */
-$no_http_headers = true;
-
-include('./include/global.php');
-include_once('./lib/api_device.php');
-include_once('./lib/data_query.php');
-include_once('./lib/poller.php');
-include_once('./lib/ping.php');
-include_once('./lib/snmp.php');
-include_once('./lib/rrd.php');
+require(__DIR__ . '/include/global.php');
+require_once($config['base_path'] . '/lib/api_device.php');
+require_once($config['base_path'] . '/lib/api_data_source.php');
+include_once($config['base_path'] . '/lib/data_query.php');
+require_once($config['base_path'] . '/lib/api_graph.php');
+require_once($config['base_path'] . '/lib/api_tree.php');
+require_once($config['base_path'] . '/lib/data_query.php');
+require_once($config['base_path'] . '/lib/html_form_template.php');
+require_once($config['base_path'] . '/lib/ping.php');
+require_once($config['base_path'] . '/lib/poller.php');
+require_once($config['base_path'] . '/lib/rrd.php');
+require_once($config['base_path'] . '/lib/snmp.php');
+require_once($config['base_path'] . '/lib/sort.php');
+require_once($config['base_path'] . '/lib/template.php');
+require_once($config['base_path'] . '/lib/utility.php');
 
 $debug = false;
 
+if ($config['poller_id'] > 1 && $config['connection'] == 'online') {
+	$poller_db_cnn_id = $remote_db_cnn_id;
+} else {
+	$poller_db_cnn_id = false;
+}
+
 if (!remote_client_authorized()) {
 	print 'FATAL: You are not authorized to use this service';
 	exit;
@@ -115,20 +126,11 @@ function strip_domain($host) {
 }
 
 function remote_client_authorized() {
+	global $poller_db_cnn_id;
+
 	/* don't allow to run from the command line */
-	if (isset($_SERVER['HTTP_CLIENT_IP'])) {
-		$client_addr = $_SERVER['HTTP_CLIENT_IP'];
-	} elseif (isset($_SERVER['X-Forwarded-For'])) {
-		$client_addr = $_SERVER['X-Forwarded-For'];
-	} elseif (isset($_SERVER['HTTP_X_FORWARDED_FOR'])) {
-		$client_addr = $_SERVER['HTTP_X_FORWARDED_FOR'];
-	} elseif (isset($_SERVER['HTTP_FORWARDED_FOR'])) {
-		$client_addr = $_SERVER['HTTP_FORWARDED_FOR'];
-	} elseif (isset($_SERVER['HTTP_FORWARDED'])) {
-		$client_addr = $_SERVER['HTTP_FORWARDED'];
-	} elseif (isset($_SERVER['REMOTE_ADDR'])) {
-		$client_addr = $_SERVER['REMOTE_ADDR'];
-	} else {
+	$client_addr = get_client_addr();
+	if ($client_addr === false) {
 		return false;
 	}
 
@@ -137,11 +139,17 @@ function remote_client_authorized() {
 		return false;
 	}
 
-	$client_name = strip_domain(gethostbyaddr($client_addr));
+	$client_name = gethostbyaddr($client_addr);
 
-	$pollers = db_fetch_assoc('SELECT * FROM poller');
+	if ($client_name == $client_addr) {
+		cacti_log('NOTE: Unable to resolve hostname from address ' . $client_addr, false, 'WEBUI', POLLER_VERBOSITY_MEDIUM);
+	} else {
+		$client_name = strip_domain($client_name);
+	}
 
-	if (sizeof($pollers)) {
+	$pollers = db_fetch_assoc('SELECT * FROM poller', true, $poller_db_cnn_id);
+
+	if (cacti_sizeof($pollers)) {
 		foreach($pollers as $poller) {
 			if (strip_domain($poller['hostname']) == $client_name) {
 				return true;
@@ -150,7 +158,9 @@ function remote_client_authorized() {
 			}
 		}
 	}
+
 	cacti_log("Unauthorized remote agent access attempt from $client_name ($client_addr)");
+
 	return false;
 }
 
@@ -266,7 +276,7 @@ function get_snmp_data_walk() {
 		}
 	}
 
-	if (sizeof($output)) {
+	if (cacti_sizeof($output)) {
 		print json_encode($output);
 	} else {
 		print 'U';
@@ -288,7 +298,7 @@ function poll_for_data() {
 
 	$i = 0;
 
-	if (sizeof($local_data_ids)) {
+	if (cacti_sizeof($local_data_ids)) {
 		foreach($local_data_ids as $local_data_id) {
 			input_validate_input_number($local_data_id);
 
@@ -305,7 +315,7 @@ function poll_for_data() {
 				AND action = 2',
 				array($host_id, $local_data_id));
 
-			if (sizeof($items)) {
+			if (cacti_sizeof($items)) {
 				foreach($items as $item) {
 					switch ($item['action']) {
 					case POLLER_ACTION_SNMP: /* snmp */
