@@ -17,21 +17,22 @@ function ss_count_oids($hostid = '', $oid = '') {
 	include_once($config['base_path'] . '/lib/snmp.php');
 
 	if ($hostid > 0) {
-		$host = db_fetch_row("SELECT hostname, snmp_community, snmp_version, snmp_username, snmp_password, 
-			snmp_auth_protocol, snmp_priv_passphrase, snmp_priv_protocol, snmp_context, 
-			snmp_port, snmp_timeout, max_oids 
-			FROM host 
-			WHERE id=$hostid");
+		$host = db_fetch_row_prepared('SELECT hostname, snmp_community, snmp_version, snmp_username, snmp_password,
+			snmp_auth_protocol, snmp_priv_passphrase, snmp_priv_protocol, snmp_context,
+			snmp_port, snmp_timeout, max_oids, snmp_engine_id
+			FROM host
+			WHERE id = ?',
+			array($hostid));
 
-		if (sizeof($host)) {
+		if (cacti_sizeof($host)) {
 			$walk = cacti_snmp_walk($host['hostname'], $host['snmp_community'], $oid, $host['snmp_version'],
 				$host['snmp_username'], $host['snmp_password'],
 				$host['snmp_auth_protocol'], $host['snmp_priv_passphrase'], $host['snmp_priv_protocol'],
 				$host['snmp_context'], $host['snmp_port'], $host['snmp_timeout'],
-				read_config_option('snmp_retries'), $host['max_oids'], SNMP_WEBUI);
+				read_config_option('snmp_retries'), $host['max_oids'], SNMP_WEBUI, $host['snmp_engine_id']);
 
-			if (sizeof($walk)) {
-				return sizeof($walk);
+			if (cacti_sizeof($walk)) {
+				return cacti_sizeof($walk);
 			}
 		}
 	}
@@ -39,4 +40,3 @@ function ss_count_oids($hostid = '', $oid = '') {
 	return '0';
 }
 
-?>
