@@ -4,26 +4,26 @@
 $no_http_headers = true;
 
 /* do NOT run this script through a web browser */
-if (!isset($_SERVER["argv"][0]) || isset($_SERVER['REQUEST_METHOD'])  || isset($_SERVER['REMOTE_ADDR'])) {
-   die("<br><strong>This script is only meant to run at the command line.</strong>");
+if (!isset($_SERVER['argv'][0]) || isset($_SERVER['REQUEST_METHOD'])  || isset($_SERVER['REMOTE_ADDR'])) {
+   die('<br><strong>This script is only meant to run at the command line.</strong>');
 }
 
 /* display no errors */
 error_reporting(0);
 
-include_once(dirname(__FILE__) . "/../include/global.php");
-include_once(dirname(__FILE__) . "/../lib/snmp.php");
-include_once(dirname(__FILE__) . "/../lib/ping.php");
+include_once(dirname(__FILE__) . '/../include/global.php');
+include_once(dirname(__FILE__) . '/../lib/snmp.php');
+include_once(dirname(__FILE__) . '/../lib/ping.php');
 
 if (!isset($called_by_script_server)) {
-	array_shift($_SERVER["argv"]);
-	print call_user_func_array("ss_fping", $_SERVER["argv"]);
+	array_shift($_SERVER['argv']);
+	print call_user_func_array('ss_fping', $_SERVER['argv']);
 }
 //End header.
 
-function ss_fping($hostname, $ping_sweeps=6, $ping_type="ICMP", $port=80) {
+function ss_fping($hostname, $ping_sweeps=6, $ping_type='ICMP', $port=80) {
 	/* record start time */
-	list($micro,$seconds) = explode(" ", microtime());
+	list($micro,$seconds) = explode(' ', microtime());
 	$ss_fping_start = $seconds + $micro;
 
 	$ping = new Net_Ping;
@@ -32,34 +32,31 @@ function ss_fping($hostname, $ping_sweeps=6, $ping_type="ICMP", $port=80) {
 	$total_time = 0;
 	$failed_results = 0;
 
-	$ping->host["hostname"] = gethostbyname($hostname);
+	$ping->host['hostname'] = gethostbyname($hostname);
 	$ping->retries = 1;
 	$ping->port = $port;
 	$max = 0.0;
 	$min = 9999.99;
 	$dev = 0.0;
 
-	$script_timeout = read_config_option("script_timeout");
-	$ping_timeout = read_config_option("ping_timeout");
+	$script_timeout = read_config_option('script_timeout');
+	$ping_timeout = read_config_option('ping_timeout');
 
 	switch ($ping_type) {
-	case "ICMP":
+	case 'ICMP':
 		$method = PING_ICMP;
 		break;
-	case "TCP":
+	case 'TCP':
 		$method = PING_TCP;
 		break;
-	case "UDP":
+	case 'UDP':
 		$method = PING_UDP;
 		break;
 	}
 
 	$i = 0;
 	while ($i < $ping_sweeps) {
-		$result = $ping->ping(AVAIL_PING,
-					$method,
-					read_config_option("ping_timeout"),
-					1);
+		$result = $ping->ping(AVAIL_PING, $method, read_config_option('ping_timeout'), 1);
 
 		if (!$result) {
 			$failed_results++;
@@ -73,18 +70,18 @@ function ss_fping($hostname, $ping_sweeps=6, $ping_type="ICMP", $port=80) {
 		$i++;
 
 		/* get current time */
-		list($micro,$seconds) = explode(" ", microtime());
+		list($micro,$seconds) = explode(' ', microtime());
 		$ss_fping_current = $seconds + $micro;
 
 		/* if called from script server, end one second before a timeout occurs */
-		if ((isset($called_by_script_server)) && (($ss_fping_current - $ss_fping_start + ($ping_timeout/1000) + 1) > $script_timeout)) {
+		if (isset($called_by_script_server) && ($ss_fping_current - $ss_fping_start + ($ping_timeout/1000) + 1) > $script_timeout) {
 			$ping_sweeps = $i;
 			break;
 		}
 	}
 
 	if ($failed_results == $ping_sweeps) {
-		return "min:U avg:U max:U dev:U loss:100.00";
+		return 'min:U avg:U max:U dev:U loss:100.00';
 	} else {
 		$loss = ($failed_results/$ping_sweeps) * 100;
 		$avg = $total_time/($ping_sweeps-$failed_results);
@@ -94,9 +91,9 @@ function ss_fping($hostname, $ping_sweeps=6, $ping_type="ICMP", $port=80) {
 		foreach($time as $sample) {
 			$predev += pow(($sample-$avg),2);
 		}
-		$dev = sqrt($predev / count($time));
+		$dev = sqrt($predev / cacti_count($time));
 
-		return sprintf("min:%0.4f avg:%0.4f max:%0.4f dev:%0.4f loss:%0.4f", $min, $avg, $max, $dev, $loss);
+		return sprintf('min:%0.4f avg:%0.4f max:%0.4f dev:%0.4f loss:%0.4f', $min, $avg, $max, $dev, $loss);
 	}
 }
 
