@@ -25,19 +25,19 @@ if (!isset($called_by_script_server)) {
 
 function ss_host_cpu($hostname, $host_id, $snmp_auth, $cmd, $arg1 = '', $arg2 = '') {
 	$snmp = explode(':', $snmp_auth);
-	$snmp_version 	= $snmp[0];
-	$snmp_port    	= $snmp[1];
-	$snmp_timeout 	= $snmp[2];
-	$ping_retries 	= $snmp[3];
-	$max_oids		= $snmp[4];
+	$snmp_version = $snmp[0];
+	$snmp_port    = $snmp[1];
+	$snmp_timeout = $snmp[2];
+	$ping_retries = $snmp[3];
+	$max_oids     = $snmp[4];
 
-	$snmp_auth_username   	= '';
-	$snmp_auth_password   	= '';
-	$snmp_auth_protocol  	= '';
-	$snmp_priv_passphrase 	= '';
-	$snmp_priv_protocol   	= '';
-	$snmp_context         	= '';
-	$snmp_community 		= '';
+	$snmp_auth_username   = '';
+	$snmp_auth_password   = '';
+	$snmp_auth_protocol   = '';
+	$snmp_priv_passphrase = '';
+	$snmp_priv_protocol   = '';
+	$snmp_context         = '';
+	$snmp_community       = '';
 
 	if ($snmp_version == 3) {
 		$snmp_auth_username   = $snmp[6];
@@ -76,10 +76,10 @@ function ss_host_cpu($hostname, $host_id, $snmp_auth, $cmd, $arg1 = '', $arg2 =
 		if (is_array($value)) {
 			$arr_index = ss_host_cpu_get_indexes($hostname, $snmp_community, $snmp_version, $snmp_auth_username, $snmp_auth_password, $snmp_auth_protocol, $snmp_priv_passphrase, $snmp_priv_protocol, $snmp_context, $snmp_port, $snmp_timeout, $ping_retries, $max_oids);
 
-			return sizeof($arr_index);
+			return cacti_sizeof($arr_index);
 		} else {
 			$indexes = explode(',', $value);
-			return sizeof($indexes);
+			return cacti_sizeof($indexes);
 		}
 	} elseif ($cmd == 'query') {
 		$value = api_plugin_hook_function('hmib_get_cpu_indexes', array('host_id' => $host_id));
@@ -115,8 +115,6 @@ function ss_host_cpu($hostname, $host_id, $snmp_auth, $cmd, $arg1 = '', $arg2 =
 			if (isset($arr_index[$index]) && isset($arr[$index])) {
 				return $arr[$index];
 			} else {
-				cacti_log('ERROR: Invalid Return Value in ss_host_cpu.php for get ' . $index . ' and host_id ' . $host_id, false);
-
 				return 'U';
 			}
 		} else {
@@ -138,8 +136,8 @@ function ss_host_cpu_get_cpu_usage($hostname, $snmp_community, $snmp_version, $s
 		}
 	}
 
-	if (sizeof($return_arr)) {
-		$return_arr[4000] = round($sum / sizeof($return_arr));
+	if (cacti_sizeof($return_arr)) {
+		$return_arr[4000] = round($sum / cacti_sizeof($return_arr));
 	} else {
 		$return_arr[4000] = 0;
 	}
@@ -151,13 +149,15 @@ function ss_host_cpu_get_indexes($hostname, $snmp_community, $snmp_version, $snm
 	$arr = ss_host_cpu_reindex(cacti_snmp_walk($hostname, $snmp_community, '.1.3.6.1.2.1.25.3.3.1.2', $snmp_version, $snmp_auth_username, $snmp_auth_password, $snmp_auth_protocol, $snmp_priv_passphrase, $snmp_priv_protocol, $snmp_context, $snmp_port, $snmp_timeout, $ping_retries, $max_oids, SNMP_POLLER));
 	$return_arr = array();
 
-	foreach($arr as $index => $value) {
-		if (is_numeric($value)) {
-			$return_arr[$index] = $index;
+	if (cacti_sizeof($arr)) {
+		foreach($arr as $index => $value) {
+			if (is_numeric($value)) {
+				$return_arr[$index] = $index;
+			}
 		}
-	}
 
-	$return_arr[4000] = 'Total';
+		$return_arr[4000] = 'Total';
+	}
 
 	return $return_arr;
 }
