@@ -58,40 +58,40 @@ function ss_net_snmp_disk_io($host_id_or_hostname) {
 	$indexes = array();
 	$host    = db_fetch_row_prepared('SELECT * FROM host WHERE id = ?', array($host_id));
 
-	$uptime  = cacti_snmp_get($host['hostname'], 
-		$host['snmp_community'], 
+	$uptime  = cacti_snmp_get($host['hostname'],
+		$host['snmp_community'],
 		'.1.3.6.1.2.1.1.3.0',
-		$host['snmp_version'], 
-		$host['snmp_username'], 
-		$host['snmp_password'], 
-		$host['snmp_auth_protocol'], 
-		$host['snmp_priv_passphrase'], 
-		$host['snmp_priv_protocol'], 
-		$host['snmp_context'], 
-		$host['snmp_port'], 
-		$host['snmp_timeout'], 
-		$host['ping_retries'], 
-		$host['max_oids'], 
+		$host['snmp_version'],
+		$host['snmp_username'],
+		$host['snmp_password'],
+		$host['snmp_auth_protocol'],
+		$host['snmp_priv_passphrase'],
+		$host['snmp_priv_protocol'],
+		$host['snmp_context'],
+		$host['snmp_port'],
+		$host['snmp_timeout'],
+		$host['ping_retries'],
+		$host['max_oids'],
 		SNMP_POLLER,
 		$host['snmp_engine_id']);
 
 	$current['uptime'] = $uptime;
 
-	$names  = cacti_snmp_walk($host['hostname'], 
-		$host['snmp_community'], 
+	$names  = cacti_snmp_walk($host['hostname'],
+		$host['snmp_community'],
 		'.1.3.6.1.4.1.2021.13.15.1.1.2',
-		$host['snmp_version'], 
-		$host['snmp_username'], 
-		$host['snmp_password'], 
-		$host['snmp_auth_protocol'], 
-		$host['snmp_priv_passphrase'], 
-		$host['snmp_priv_protocol'], 
-		$host['snmp_context'], 
-		$host['snmp_port'], 
-		$host['snmp_timeout'], 
-		$host['ping_retries'], 
-		$host['max_oids'], 
-		SNMP_POLLER, 
+		$host['snmp_version'],
+		$host['snmp_username'],
+		$host['snmp_password'],
+		$host['snmp_auth_protocol'],
+		$host['snmp_priv_passphrase'],
+		$host['snmp_priv_protocol'],
+		$host['snmp_context'],
+		$host['snmp_port'],
+		$host['snmp_timeout'],
+		$host['ping_retries'],
+		$host['max_oids'],
+		SNMP_POLLER,
 		$host['snmp_engine_id']);
 
 	foreach($names as $measure) {
@@ -101,33 +101,33 @@ function ss_net_snmp_disk_io($host_id_or_hostname) {
 			}
 
 			$parts = explode('.', $measure['oid']);
-			$indexes[$parts[sizeof($parts)-1]] = $parts[sizeof($parts)-1];
+			$indexes[$parts[cacti_sizeof($parts)-1]] = $parts[cacti_sizeof($parts)-1];
 		}
 	}
 
 	$reads = $writes = 0;
 
-	if (sizeof($indexes)) {
-		$iops = cacti_snmp_walk($host['hostname'], 
-			$host['snmp_community'], 
+	if (cacti_sizeof($indexes)) {
+		$iops = cacti_snmp_walk($host['hostname'],
+			$host['snmp_community'],
 			'.1.3.6.1.4.1.2021.13.15.1.1.5',
-			$host['snmp_version'], 
-			$host['snmp_username'], 
-			$host['snmp_password'], 
-			$host['snmp_auth_protocol'], 
-			$host['snmp_priv_passphrase'], 
-			$host['snmp_priv_protocol'], 
-			$host['snmp_context'], 
-			$host['snmp_port'], 
-			$host['snmp_timeout'], 
-			$host['ping_retries'], 
-			$host['max_oids'], 
-			SNMP_POLLER, 
+			$host['snmp_version'],
+			$host['snmp_username'],
+			$host['snmp_password'],
+			$host['snmp_auth_protocol'],
+			$host['snmp_priv_passphrase'],
+			$host['snmp_priv_protocol'],
+			$host['snmp_context'],
+			$host['snmp_port'],
+			$host['snmp_timeout'],
+			$host['ping_retries'],
+			$host['max_oids'],
+			SNMP_POLLER,
 			$host['snmp_engine_id']);
 
 		foreach($iops as $measure) {
 			$parts = explode('.', $measure['oid']);
-			$index = $parts[sizeof($parts)-1];
+			$index = $parts[cacti_sizeof($parts)-1];
 
 			if (array_key_exists($index, $indexes)) {
 				if (!isset($previous['uptime'])) {
@@ -146,26 +146,26 @@ function ss_net_snmp_disk_io($host_id_or_hostname) {
 			}
 		}
 
-		$iops = cacti_snmp_walk($host['hostname'], 
-			$host['snmp_community'], 
+		$iops = cacti_snmp_walk($host['hostname'],
+			$host['snmp_community'],
 			'.1.3.6.1.4.1.2021.13.15.1.1.6',
-			$host['snmp_version'], 
-			$host['snmp_username'], 
-			$host['snmp_password'], 
-			$host['snmp_auth_protocol'], 
-			$host['snmp_priv_passphrase'], 
-			$host['snmp_priv_protocol'], 
-			$host['snmp_context'], 
-			$host['snmp_port'], 
-			$host['snmp_timeout'], 
-			$host['ping_retries'], 
-			$host['max_oids'], 
-			SNMP_POLLER, 
+			$host['snmp_version'],
+			$host['snmp_username'],
+			$host['snmp_password'],
+			$host['snmp_auth_protocol'],
+			$host['snmp_priv_passphrase'],
+			$host['snmp_priv_protocol'],
+			$host['snmp_context'],
+			$host['snmp_port'],
+			$host['snmp_timeout'],
+			$host['ping_retries'],
+			$host['max_oids'],
+			SNMP_POLLER,
 			$host['snmp_engine_id']);
 
 		foreach($iops as $measure) {
 			$parts = explode('.', $measure['oid']);
-			$index = $parts[sizeof($parts)-1];
+			$index = $parts[cacti_sizeof($parts)-1];
 
 			if (array_key_exists($index, $indexes)) {
 				if (!isset($previous['uptime'])) {
@@ -194,3 +194,4 @@ function ss_net_snmp_disk_io($host_id_or_hostname) {
 		return 'reads:0 writes:0';
 	}
 }
+
