@@ -22,13 +22,7 @@
    +-------------------------------------------------------------------------+
 */
 
-/* do NOT run this script through a web browser */
-if (!isset($_SERVER["argv"][0]) || isset($_SERVER['REQUEST_METHOD'])  || isset($_SERVER['REMOTE_ADDR'])) {
-	die("<br><strong>This script is only meant to run at the command line.</strong>");
-}
-
-/* we are not talking to the browser */
-$no_http_headers = true;
+require(__DIR__ . '/include/cli_check.php');
 
 /* let's report all errors */
 error_reporting(E_ALL);
@@ -37,7 +31,6 @@ error_reporting(E_ALL);
 set_time_limit(0);
 
 chdir(dirname(__FILE__));
-include_once('./include/global.php');
 
 $last_time = time()-30;
 
@@ -50,7 +43,7 @@ $mibcache_changed = db_fetch_cell_prepared("SHOW TABLE STATUS WHERE `Name` LIKE
 if($mibcache_changed !== NULL || file_exists($path_mibcache) === false ) {
 	$objects = db_fetch_assoc("SELECT `oid`, LOWER(type) as type, `otype`, `max-access`, `value` FROM snmpagent_cache");
 
-	if($objects && sizeof($objects)>0) {
+	if($objects && cacti_sizeof($objects)>0) {
 		$oids = array();
 		foreach($objects as &$object) {
 			$oids[] = $object['oid'];
@@ -67,7 +60,7 @@ if($mibcache_changed !== NULL || file_exists($path_mibcache) === false ) {
 				if($last_accessible_object) {
 					$cache[$last_accessible_object]['next'] = $oid;
 				}
-				if(sizeof($next_accessible_object_required)>0) {
+				if(cacti_sizeof($next_accessible_object_required)>0) {
 					foreach($next_accessible_object_required as $next_accessible_object_required_oid) {
 						$cache[$next_accessible_object_required_oid]['next'] = $oid;
 					}
