@@ -108,6 +108,9 @@ switch (get_request_var('action')) {
 		tree_edit();
 		bottom_footer();
 		break;
+	case 'sites':
+		display_sites();
+		break;
 	case 'hosts':
 		display_hosts();
 		break;
@@ -125,9 +128,13 @@ switch (get_request_var('action')) {
 		break;
 	case 'lock':
 		api_tree_lock(get_request_var('id'), $_SESSION['sess_user_id']);
+
+		header('Location: tree.php?action=edit&header=false&id=' . get_request_var('id'));
 		break;
 	case 'unlock':
 		api_tree_unlock(get_request_var('id'), $_SESSION['sess_user_id']);
+
+		header('Location: tree.php?action=edit&header=false&id=' . get_request_var('id'));
 		break;
 	case 'copy_node':
 		api_tree_copy_node(get_request_var('tree_id'), get_request_var('id'), get_request_var('parent'), get_request_var('position'));
@@ -145,7 +152,7 @@ switch (get_request_var('action')) {
 		api_tree_rename_node(get_request_var('tree_id'), get_request_var('id'), get_nfilter_request_var('text'));
 		break;
 	case 'get_node':
-		api_tree_get_node(get_request_var('tree_id'), get_request_var('id'), true);
+		api_tree_get_node(get_request_var('tree_id'), get_request_var('id'));
 		break;
 	case 'get_host_sort':
 		get_host_sort_type();
@@ -294,14 +301,19 @@ function tree_dnd() {
 function get_host_sort_type() {
 	if (isset_request_var('nodeid')) {
 		$ndata = explode('_', get_request_var('nodeid'));
-		if (sizeof($ndata)) {
+		if (cacti_sizeof($ndata)) {
 			foreach($ndata as $n) {
 				$parts = explode(':', $n);
 
 				if (isset($parts[0]) && $parts[0] == 'tbranch') {
 					$branch = $parts[1];
 					input_validate_input_number($branch);
-					$sort_type = db_fetch_cell_prepared('SELECT host_grouping_type FROM graph_tree_items WHERE id = ?', array($branch));
+
+					$sort_type = db_fetch_cell_prepared('SELECT host_grouping_type
+						FROM graph_tree_items
+						WHERE id = ?',
+						array($branch));
+
 					if ($sort_type == HOST_GROUPING_GRAPH_TEMPLATE) {
 						print 'hsgt';
 					} else {
@@ -326,7 +338,7 @@ function set_host_sort_type() {
 
 	if (isset_request_var('nodeid')) {
 		$ndata = explode('_', get_request_var('nodeid'));
-		if (sizeof($ndata)) {
+		if (cacti_sizeof($ndata)) {
 			foreach($ndata as $n) {
 				$parts = explode(':', $n);
 
@@ -340,7 +352,11 @@ function set_host_sort_type() {
 						$type = HOST_GROUPING_DATA_QUERY_INDEX;
 					}
 
-					db_execute_prepared('UPDATE graph_tree_items SET host_grouping_type = ? WHERE id = ?', array($type, $branch));
+					db_execute_prepared('UPDATE graph_tree_items
+						SET host_grouping_type = ?
+						WHERE id = ?',
+						array($type, $branch));
+
 					break;
 				}
 			}
@@ -353,14 +369,20 @@ function set_host_sort_type() {
 function get_branch_sort_type() {
 	if (isset_request_var('nodeid')) {
 		$ndata = explode('_', get_request_var('nodeid'));
-		if (sizeof($ndata)) {
+		if (cacti_sizeof($ndata)) {
 		foreach($ndata as $n) {
 			$parts = explode(':', $n);
 
 			if (isset($parts[0]) && $parts[0] == 'tbranch') {
 				$branch = $parts[1];
+
 				input_validate_input_number($branch);
-				$sort_type = db_fetch_cell_prepared('SELECT sort_children_type FROM graph_tree_items WHERE id = ?', array($branch));
+
+				$sort_type = db_fetch_cell_prepared('SELECT sort_children_type
+					FROM graph_tree_items
+					WHERE id = ?',
+					array($branch));
+
 				switch($sort_type) {
 				case TREE_ORDERING_INHERIT:
 					print __x('ordering of tree items', 'inherit');
@@ -401,7 +423,7 @@ function set_branch_sort_type() {
 
 	if (isset_request_var('nodeid')) {
 		$ndata = explode('_', get_request_var('nodeid'));
-		if (sizeof($ndata)) {
+		if (cacti_sizeof($ndata)) {
 			foreach($ndata as $n) {
 				$parts = explode(':', $n);
 
@@ -523,24 +545,24 @@ function sort_recursive($branch, $tree_id) {
 		AND host_id = 0',
 		array($tree_id, $branch));
 
-	if (sizeof($leaves)) {
-	foreach($leaves as $leaf) {
-		if ($leaf['sort_children_type'] == TREE_ORDERING_INHERIT) {
-			$first_child = db_fetch_cell_prepared('SELECT id
-				FROM graph_tree_items
-				WHERE parent = ?',
-				array($leaf['id']));
+	if (cacti_sizeof($leaves)) {
+		foreach($leaves as $leaf) {
+			if ($leaf['sort_children_type'] == TREE_ORDERING_INHERIT) {
+				$first_child = db_fetch_cell_prepared('SELECT id
+					FROM graph_tree_items
+					WHERE parent = ?',
+					array($leaf['id']));
 
-			if (!empty($first_child)) {
-				api_tree_sort_branch($first_child, $tree_id);
+				if (!empty($first_child)) {
+					api_tree_sort_branch($first_child, $tree_id);
 
-				if (leaves_exist($leaf['id'], $tree_id)) {
-					sort_recursive($first_child, $tree_id);
+					if (leaves_exist($leaf['id'], $tree_id)) {
+						sort_recursive($first_child, $tree_id);
+					}
 				}
 			}
 		}
 	}
-	}
 }
 
 function leaves_exist($parent, $tree_id) {
@@ -600,7 +622,7 @@ function form_actions() {
 			input_validate_input_number($matches[1]);
 			/* ==================================================== */
 
-			$tree_list .= '<li>' . htmlspecialchars(db_fetch_cell_prepared('SELECT name FROM graph_tree WHERE id = ?', array($matches[1]))) . '</li>';
+			$tree_list .= '<li>' . html_escape(db_fetch_cell_prepared('SELECT name FROM graph_tree WHERE id = ?', array($matches[1]))) . '</li>';
 			$tree_array[$i] = $matches[1];
 
 			$i++;
@@ -613,45 +635,46 @@ function form_actions() {
 
 	html_start_box($tree_actions[get_nfilter_request_var('drp_action')], '60%', '', '3', 'center', '');
 
-	if (isset($tree_array) && sizeof($tree_array)) {
+	if (isset($tree_array) && cacti_sizeof($tree_array)) {
 		if (get_nfilter_request_var('drp_action') == '1') { // delete
 			print "<tr>
 				<td class='textArea' class='odd'>
-					<p>" . __n('Click \'Continue\' to delete the following Tree.', 'Click \'Continue\' to delete following Trees.', sizeof($tree_array)) . "</p>
+					<p>" . __n('Click \'Continue\' to delete the following Tree.', 'Click \'Continue\' to delete following Trees.', cacti_sizeof($tree_array)) . "</p>
 					<div class='itemlist'><ul>$tree_list</ul></div>
 				</td>
 			</tr>\n";
 
-			$save_html = "<input type='button' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __esc('Continue') . "' title='" . __n('Delete Tree', 'Delete Trees', sizeof($tree_array)) . "'>";
+			$save_html = "<input type='button' class='ui-button ui-corner-all ui-widget' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' class='ui-button ui-corner-all ui-widget' value='" . __esc('Continue') . "' title='" . __n('Delete Tree', 'Delete Trees', cacti_sizeof($tree_array)) . "'>";
 		} elseif (get_nfilter_request_var('drp_action') == '2') { // publish
 			print "<tr>
 				<td class='textArea' class='odd'>
-					<p>" . __n('Click \'Continue\' to publish the following Tree.', 'Click \'Continue\' to publish following Trees.', sizeof($tree_array)) . "</p>
+					<p>" . __n('Click \'Continue\' to publish the following Tree.', 'Click \'Continue\' to publish following Trees.', cacti_sizeof($tree_array)) . "</p>
 					<div class='itemlist'><ul>$tree_list</ul></div>
 				</td>
 			</tr>\n";
 
-			$save_html = "<input type='button' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __esc('Continue') . "' title='" . __n('Publish Tree', 'Publish Trees', sizeof($tree_array)) . "'>";
+			$save_html = "<input type='button' class='ui-button ui-corner-all ui-widget' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' class='ui-button ui-corner-all ui-widget' value='" . __esc('Continue') . "' title='" . __n('Publish Tree', 'Publish Trees', cacti_sizeof($tree_array)) . "'>";
 		} elseif (get_nfilter_request_var('drp_action') == '3') { // un-publish
 			print "<tr>
 				<td class='textArea' class='odd'>
-					<p>" . __n('Click \'Continue\' to un-publish the following Tree.', 'Click \'Continue\' to un-publish following Trees.', sizeof($tree_array)) . "</p>
+					<p>" . __n('Click \'Continue\' to un-publish the following Tree.', 'Click \'Continue\' to un-publish following Trees.', cacti_sizeof($tree_array)) . "</p>
 					<div class='itemlist'><ul>$tree_list</ul></div>
 				</td>
 			</tr>\n";
 
-			$save_html = "<input type='button' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __esc('Continue') . "' title='" . __n('Un-publish Tree', 'Un-publish Trees', sizeof($tree_array)) . "'>";
+			$save_html = "<input type='button' class='ui-button ui-corner-all ui-widget' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' class='ui-button ui-corner-all ui-widget' value='" . __esc('Continue') . "' title='" . __n('Un-publish Tree', 'Un-publish Trees', cacti_sizeof($tree_array)) . "'>";
 		}
 	} else {
-		print "<tr><td class='odd'><span class='textError'>" . __('You must select at least one Tree.') . "</span></td></tr>\n";
-		$save_html = "<input type='button' value='" . __esc('Return') . "' onClick='cactiReturnTo()'>";
+		raise_message(40);
+		header('Location: tree.php?header=false');
+		exit;
 	}
 
 	print "<tr>
 		<td class='saveRow'>
 			<input type='hidden' name='action' value='actions'>
 			<input type='hidden' name='selected_items' value='" . (isset($tree_array) ? serialize($tree_array) : '') . "'>
-			<input type='hidden' name='drp_action' value='" . get_nfilter_request_var('drp_action') . "'>
+			<input type='hidden' name='drp_action' value='" . html_escape(get_nfilter_request_var('drp_action')) . "'>
 			$save_html
 		</td>
 	</tr>\n";
@@ -684,9 +707,12 @@ function tree_edit() {
 	load_current_session_value('type', 'sess_tree_edit_type', '0');
 
 	if (!isempty_request_var('id')) {
-		$tree = db_fetch_row_prepared('SELECT * FROM graph_tree WHERE id = ?', array(get_request_var('id')));
+		$tree = db_fetch_row_prepared('SELECT *
+			FROM graph_tree
+			WHERE id = ?',
+			array(get_request_var('id')));
 
-		$header_label = __('Trees [edit: %s]', htmlspecialchars($tree['name']) );
+		$header_label = __('Trees [edit: %s]', html_escape($tree['name']) );
 
 		// Reset the cookie state if tree id has changed
 		if (isset($_SESSION['sess_tree_id']) && $_SESSION['sess_tree_id'] != get_request_var('id')) {
@@ -694,6 +720,7 @@ function tree_edit() {
 		} else {
 			$select_first = false;
 		}
+
 		$_SESSION['sess_tree_id'] = get_request_var('id');
 	} else {
 		$tree = array();
@@ -708,7 +735,7 @@ function tree_edit() {
 
 	html_start_box($header_label, '100%', true, '3', 'center', '');
 
-	if (!sizeof($tree)) {
+	if (!cacti_sizeof($tree)) {
 		unset($fields_tree_edit['enabled']);
 	}
 
@@ -724,10 +751,10 @@ function tree_edit() {
 	$lockdiv = '';
 
 	if (isset($tree['locked']) && $tree['locked'] == 0) {
-		$lockdiv = "<div style='padding:3px;'><table><tr><td><input id='lock' type='button' value='" . __esc('Edit Tree') . "'></td><td style='font-weight:bold;'>" . __('To Edit this tree, you must first lock it by pressing the Edit Tree button.') . "</td></tr></table></div>\n";
+		$lockdiv = "<div style='padding:3px;'><table><tr><td><input type='button' class='ui-button ui-corner-all ui-widget' id='lock' value='" . __esc('Edit Tree') . "'></td><td style='font-weight:bold;'>" . __('To Edit this tree, you must first lock it by pressing the Edit Tree button.') . "</td></tr></table></div>\n";
 		$editable = false;
 	} elseif (isset($tree['locked']) && $tree['locked'] == 1) {
-		$lockdiv = "<div style='padding:3px;'><table><tr><td><input id='unlock' type='button' value='" . __esc('Finish Editing Tree') . "'></td><td><input id='addbranch' type='button' value='" . __esc('Add Root Branch') . "' onClick='createNode()'></td><td style='font-weight:bold;'>" . __('This tree has been locked for Editing on %1$s by %2$s.', $tree['locked_date'], get_username($tree['modified_by']));
+		$lockdiv = "<div style='padding:3px;'><table><tr><td><input type='button' class='ui-button ui-corner-all ui-widget' id='unlock' value='" . __esc('Finish Editing Tree') . "'></td><td><input type='button' class='ui-button ui-corner-all ui-widget' id='addbranch' value='" . __esc('Add Root Branch') . "' onClick='createNode()'></td><td style='font-weight:bold;'>" . __('This tree has been locked for Editing on %1$s by %2$s.', $tree['locked_date'], get_username($tree['modified_by']));
 		if ($tree['modified_by'] == $_SESSION['sess_user_id']) {
 			$editable = true;
 			$lockdiv .= '</td></tr></table></div>';
@@ -747,17 +774,65 @@ function tree_edit() {
 	if (!isempty_request_var('id')) {
 		print $lockdiv;
 
-		print "<table class='treeTable'><tr><td class='treeArea'>\n";
+		print "<table class='treeTable' style='width:100%;'>\n";
 
-		html_start_box( __('Tree Items'), '100%', '', '3', 'center', '');
+		print "<tr class='even' id='tree_filter'>\n";
+		print "<td colspan='4'>";
+		print "<table><tr><td>" . __('Display') . "</td>";
+		print "<td>\n";
+		print "<select id='element'>\n";
+		print "<option id='0'>" . __('All') . "</option>";
+		print "<option id='1'>" . __('Sites') . "</option>";
+		print "<option id='2'>" . __('Devices') . "</option>";
+		print "<option id='3'>" . __('Graphs') . "</option>";
+		print "</select></td></tr></table></td></tr>";
 
-		echo "<tr><td style='padding:7px;'><div id='jstree'></div></td></tr>\n";
+		print "<tr><td class='treeArea'>\n";
+
+		html_start_box(__('Tree Items'), '100%', '', '3', 'center', '');
+
+		print "<tr><td style='padding:7px;'><div id='ctree'></div></td></tr>\n";
 
 		html_end_box();
 
-		print "</td><td></td><td class='treeItemsArea'>\n";
+		print "</td><td class='treeItemsArea treeItemsAreaSite'>\n";
 
-		html_start_box( __('Available Devices'), '100%', '', '3', 'center', '');
+		html_start_box(__('Available Sites'), '100%', '', '3', 'center', '');
+		?>
+		<tr class='even noprint'>
+			<td>
+			<form id='form_tree_sites' action='tree.php'>
+				<table class='filterTable'>
+					<tr>
+						<td>
+							<?php print __('Search'); ?>
+						</td>
+						<td>
+							<input type='text' class='ui-state-default ui-corner-all' id='sfilter' name='sfilter' size='25' value='<?php print html_escape_request_var('sfilter');?>'>
+						</td>
+					</tr>
+				</table>
+			</form>
+			</td>
+		</tr>
+		<?php
+
+		html_end_box(false);
+
+		$display_text = array(__('Site Name'));
+
+		html_start_box('', '100%', '', '3', 'center', '');
+		html_header($display_text);
+
+		print "<tr><td style='padding:7px;'><div id='sites'>\n";
+		display_sites();
+		print "</div></td></tr>\n";
+
+		html_end_box();
+
+		print "</td><td class='treeItemsArea treeItemsAreaDevice'>\n";
+
+		html_start_box(__('Available Devices'), '100%', '', '3', 'center', '');
 		?>
 		<tr class='even noprint'>
 			<td>
@@ -768,7 +843,7 @@ function tree_edit() {
 							<?php print __('Search'); ?>
 						</td>
 						<td>
-							<input id='hfilter' type='text' name='hfilter' size='25' value='<?php print html_escape_request_var('hfilter');?>'>
+							<input type='text' class='ui-state-default ui-corner-all' id='hfilter' name='hfilter' size='25' value='<?php print html_escape_request_var('hfilter');?>'>
 						</td>
 					</tr>
 				</table>
@@ -779,20 +854,20 @@ function tree_edit() {
 
 		html_end_box(false);
 
-		$display_text = array( __('Description'));
+		$display_text = array(__('Device Description'));
 
 		html_start_box('', '100%', '', '3', 'center', '');
 		html_header($display_text);
 
-		echo "<tr><td style='padding:7px;'><div id='hosts'>\n";
+		print "<tr><td style='padding:7px;'><div id='hosts'>\n";
 		display_hosts();
-		echo "</div></td></tr>\n";
+		print "</div></td></tr>\n";
 
 		html_end_box();
 
-		print "</td><td></td><td class='treeItemsArea'>\n";
+		print "</td><td class='treeItemsArea treeItemsAreaGraph'>\n";
 
-		html_start_box( __('Available Graphs'), '100%', '', '3', 'center', '');
+		html_start_box(__('Available Graphs'), '100%', '', '3', 'center', '');
 		?>
 		<tr class='even noprint'>
 			<td>
@@ -803,7 +878,7 @@ function tree_edit() {
 							<?php print __('Search'); ?>
 						</td>
 						<td>
-							<input id='grfilter' type='text' name='grfilter' size='25' value='<?php print html_escape_request_var('grfilter');?>'>
+							<input type='text'  class='ui-state-default ui-corner-all' id='grfilter' name='grfilter' size='25' value='<?php print html_escape_request_var('grfilter');?>'>
 						</td>
 					</tr>
 				</table>
@@ -813,14 +888,14 @@ function tree_edit() {
 		<?php
 		html_end_box(false);
 
-		$display_text = array( __('Graph Name'));
+		$display_text = array(__('Graph Name'));
 
 		html_start_box('', '100%', '', '3', 'center', '');
 		html_header($display_text);
 
-		echo "<tr><td style='padding:7px;'><div id='graphs'>\n";
+		print "<tr><td style='padding:7px;'><div id='graphs'>\n";
 		display_graphs();
-		echo "</div></td></tr>\n";
+		print "</div></td></tr>\n";
 
 		html_end_box();
 
@@ -838,17 +913,26 @@ function tree_edit() {
 
 		var graphMeTimer;
 		var hostMeTimer;
+		var siteMeTimer;
 		var hostSortInfo   = {};
 		var branchSortInfo = {};
 
 		function createNode() {
-			var ref = $('#jstree').jstree(true);
+			var ref = $('#ctree').jstree(true);
 			sel = ref.create_node('#', '<?php print __('New Node');?>', '0');
 			if (sel) {
 				ref.edit(sel);
 			}
 		};
 
+		function disableTree() {
+			$('.treeTable').each(function() {
+				$(this).mousedown(function(event) {
+					event.preventDefault();
+				});
+			});
+		}
+
 		function getGraphData() {
 			$.get('tree.php?action=graphs&filter='+$('#grfilter').val())
 				.done(function(data) {
@@ -873,6 +957,14 @@ function tree_edit() {
 				});
 		}
 
+		function getSiteData() {
+			$.get('tree.php?action=sites&filter='+$('#sfilter').val(), function(data) {
+				$('#sites').jstree('destroy');
+				$('#sites').html(data);
+				dragable('#sites');
+			});
+		}
+
 		function setHostSortIcon(nodeid) {
 			if (hostSortInfo[nodeid]) {
 				// Already set
@@ -939,12 +1031,22 @@ function tree_edit() {
 
 		graphsDropSet = '';
 		hostsDropSet  = '';
+		sitesDropSet  = '';
 
 		$(function() {
 			<?php if ($editable == false) {?>
-			$('select, input').not('#lock').prop('disabled', true);
+			$('select, input').not('#lock, #element').each(function() {
+				$(this).prop('disabled', true);
+				$(this).addClass('ui-state-disabled');
+				if ($(this).selectmenu('instance') !== undefined) {
+					$(this).selectmenu('disable');
+				}
+			});
+			disableTree();
 			<?php } else {?>
-			$('select, input').prop('disabled', false);
+			$('select, input').each(function() {
+				$(this).prop('disabled', false);
+			});
 			<?php }?>
 
 			$('form').unbind().submit(function(event) {
@@ -959,31 +1061,89 @@ function tree_edit() {
 			});
 
 			$('#lock').click(function() {
-				strURL = 'tree.php?action=lock&id=<?php print $tree['id'];?>&header=false';
-				loadPageNoHeader(strURL);
+				strURL = 'tree.php?action=lock&id=<?php print $tree['id'];?>';
+				loadPage(strURL);
 			});
 
 			$('#unlock').click(function() {
-				strURL = 'tree.php?action=unlock&id=<?php print $tree['id'];?>&header=false';
-				loadPageNoHeader(strURL);
+				strURL = 'tree.php?action=unlock&id=<?php print $tree['id'];?>';
+				loadPage(strURL);
 			});
 
-			var height      = parseInt($(window).height()-$('#jstree').offset().top-10)+'px';
-			var hheight     = parseInt($(window).height()-$('#hosts').offset().top-10)+'px';
-			var gheight     = parseInt($(window).height()-$('#graphs').offset().top-10)+'px';
+			var height  = parseInt($(window).height()-$('#ctree').offset().top-10)+'px';
+			var sheight = parseInt($(window).height()-$('#sites').offset().top-10)+'px';
+			var hheight = parseInt($(window).height()-$('#hosts').offset().top-10)+'px';
+			var gheight = parseInt($(window).height()-$('#graphs').offset().top-10)+'px';
+
+			$('#element').change(function() {
+				resizer();
+			});
 
 			$(window).resize(function() {
-				height      = parseInt($(window).height()-$('#jstree').offset().top-10)+'px';
-				hheight     = parseInt($(window).height()-$('#hosts').offset().top-10)+'px';
-				gheight     = parseInt($(window).height()-$('#graphs').offset().top-10)+'px';
-				$('#jstree').css('height', height).css('overflow','auto');;
-				$('#hosts').css('height', hheight).css('overflow','auto');;
-				$('#graphs').css('height', gheight).css('overflow','auto');;
+				resizer();
 			});
 
-			$("#jstree")
+			function resizer() {
+				if ($('#ctree').length) {
+					height  = parseInt($(window).height()-$('#ctree').offset().top-10)+'px';
+					sheight = parseInt($(window).height()-$('#sites').offset().top-10)+'px';
+					hheight = parseInt($(window).height()-$('#hosts').offset().top-10)+'px';
+					gheight = parseInt($(window).height()-$('#graphs').offset().top-10)+'px';
+					$('#ctree').css('height', height).css('overflow','auto');;
+					$('#hosts').css('height', hheight).css('overflow','auto');;
+					$('#sites').css('height', hheight).css('overflow','auto');;
+					$('#graphs').css('height', gheight).css('overflow','auto');;
+
+					switchDisplay();
+				}
+			}
+
+			function switchDisplay() {
+				var selected = $('#element').prop('selectedIndex');
+				var mainWidth = parseInt($('#main').outerWidth());
+				var treeWidth = parseInt($('.treeTable').outerWidth());
+
+				if (selected == 0) {
+					if (mainWidth != treeWidth && treeWidth > 0) {
+						$('#element').prop('selectedIndex', 1);
+						if (typeof $('#element').selectmenu() === 'object') {
+							$('#element').selectmenu('refresh');
+						}
+						selected = $('#element').prop('selectedIndex');
+					}
+				}
+
+				switch(selected) {
+					case 0:
+						$('.treeItemsAreaSite').show();
+						$('.treeItemsAreaDevice').show();
+						$('.treeItemsAreaGraph').show();
+						break;
+					case 1:
+						$('.treeItemsAreaSite').show();
+						$('.treeItemsAreaDevice').hide();
+						$('.treeItemsAreaGraph').hide();
+						break;
+					case 2:
+						$('.treeItemsAreaSite').hide();
+						$('.treeItemsAreaDevice').show();
+						$('.treeItemsAreaGraph').hide();
+						break;
+					case 3:
+						$('.treeItemsAreaSite').hide();
+						$('.treeItemsAreaDevice').hide();
+						$('.treeItemsAreaGraph').show();
+						break;
+				}
+			}
+
+			$("#ctree")
 			.jstree({
 				'types' : {
+					'site' : {
+						icon : 'images/site.png',
+						max_children : 0
+					},
 					'device' : {
 						icon : 'images/server.png',
 						max_children : 0
@@ -999,13 +1159,18 @@ function tree_edit() {
 							var dataType = 'graph';
 						}else if (node.id.search('thost') > 0) {
 							var dataType = 'host';
+						}else if (node.id.search('tsite') > 0) {
+							var dataType = 'site';
 						}else {
 							var dataType = 'branch';
 						}
+
 						if (dataType == 'graph') {
 							return graphContext(node.id);
 						}else if (dataType == 'host') {
 							return hostContext(node.id);
+						}else if (dataType == 'site') {
+							return siteContext(node.id);
 						} else {
 							return branchContext(node.id);
 						}
@@ -1033,7 +1198,7 @@ function tree_edit() {
 			})
 			.on('ready.jstree', function(e, data) {
 				if (reset == true) {
-					$('#jstree').jstree('clear_state');
+					$('#ctree').jstree('clear_state');
 				}
 			})<?php if ($editable) {?>.on('delete_node.jstree', function (e, data) {
 				$.get('?action=delete_node', { 'id' : data.node.id, 'tree_id' : $('#id').val() })
@@ -1045,7 +1210,7 @@ function tree_edit() {
 			.on('hover_node.jstree', function (e, data) {
 				if (data.node.id.search('thost') >= 0) {
 					setHostSortIcon(data.node.id);
-				}else if (data.node.id.search('thost') < 0 && data.node.id.search('tgraph') < 0) {
+				}else if (data.node.id.search('thost') < 0 && data.node.id.search('tgraph') < 0 && data.node.id.search('tsite')) {
 					setBranchSortIcon(data.node.id);
 				}
 			})
@@ -1092,6 +1257,8 @@ function tree_edit() {
 
 				if (oid.search('thost') >= 0) {
 					set = hostsDropSet;
+				}else if (oid.search('tsite') >= 0) {
+					set = sitesDropSet;
 				} else {
 					set = graphsDropSet;
 				}
@@ -1108,6 +1275,8 @@ function tree_edit() {
 
 					if (oid.search('thost') >= 0) {
 						$('#hosts').jstree().deselect_all();
+					} else if (oid.search('tsite') >= 0) {
+						$('#sites').jstree().deselect_all();
 					} else {
 						$('#graphs').jstree().deselect_all();
 					}
@@ -1122,16 +1291,22 @@ function tree_edit() {
 				return false;
 			})<?php }?>;
 
-			$('#jstree').css('height', height).css('overflow','auto');;
+			$('#ctree').css('height', height).css('overflow','auto');;
 
 			dragable('#graphs', 'graphs');
-			dragable('#hosts', 'hosts');
+			dragable('#sites',  'sites');
+			dragable('#hosts',  'hosts');
 		});
 
 		function dragable(element, type) {
 			$(element)
 				.jstree({
 					'types' : {
+						'site' : {
+							icon : 'images/site.png',
+							valid_children: 'none',
+							max_children : 0
+						},
 						'device' : {
 							icon : 'images/server.png',
 							valid_children: 'none',
@@ -1158,7 +1333,7 @@ function tree_edit() {
 				})
 				.on('ready.jstree', function(e, data) {
 					if (reset == true) {
-						$('#jstree').jstree('clear_state');
+						$('#ctree').jstree('clear_state');
 					}
 				})<?php if ($editable) {?>
 				.on('select_node.jstree', function(e, data) {
@@ -1200,7 +1375,7 @@ function tree_edit() {
 				'rename' : {
 					'separator_before'	: false,
 					'separator_after'	: false,
-					'icon'				: 'fa fa-pencil',
+					'icon'				: 'fa fa-pencil-alt',
 					'_disabled'			: false,
 					'label'				: '<?php print __('Rename');?>',
 					'action'			: function (data) {
@@ -1211,7 +1386,7 @@ function tree_edit() {
 				},
 				'remove' : {
 					'separator_before'	: false,
-					'icon'				: 'fa fa-remove',
+					'icon'				: 'fa fa-times',
 					'separator_after'	: false,
 					'_disabled'			: false,
 					'label'				: '<?php print __('Delete');?>',
@@ -1343,7 +1518,7 @@ function tree_edit() {
 						},
 						'paste' : {
 							'separator_before'	: false,
-							'icon'				: 'fa fa-paste',
+							'icon'				: 'fa fa-clipboard',
 							'_disabled'			: function (data) {
 								return !$.jstree.reference(data.reference).can_paste();
 							},
@@ -1364,7 +1539,7 @@ function tree_edit() {
 			return {
 				'remove' : {
 					'separator_before'	: false,
-					'icon'				: 'fa fa-remove',
+					'icon'				: 'fa fa-times',
 					'separator_after'	: false,
 					'_disabled'			: false, //(this.check('delete_node', data.reference, this.get_parent(data.reference), '')),
 					'label'				: '<?php print __('Delete');?>',
@@ -1420,11 +1595,32 @@ function tree_edit() {
 			};
 		}
 
+		function siteContext(nodeid) {
+			return {
+				'remove' : {
+					'separator_before'	: false,
+					'icon'				: 'fa fa-times',
+					'separator_after'	: false,
+					'_disabled'			: false,
+					'label'				: '<?php print __('Delete');?>',
+					'action'			: function (data) {
+						var inst = $.jstree.reference(data.reference);
+						var obj = inst.get_node(data.reference);
+						if(inst.is_selected(obj)) {
+							inst.delete_node(inst.get_selected());
+						} else {
+							inst.delete_node(obj);
+						}
+					}
+				}
+			};
+		}
+
 		function hostContext(nodeid) {
 			return {
 				'remove' : {
 					'separator_before'	: false,
-					'icon'				: 'fa fa-remove',
+					'icon'				: 'fa fa-times',
 					'separator_after'	: false,
 					'_disabled'			: false,
 					'label'				: '<?php print __('Delete');?>',
@@ -1516,11 +1712,35 @@ function tree_edit() {
 			hostMeTimer && clearTimeout(hostMeTimer);
 			hostMeTimer = setTimeout(getHostData, 300);
 		});
+
+		$('#sfilter').keyup(function(data) {
+			siteMeTimer && clearTimeout(siteMeTimer);
+			siteMeTimer = setTimeout(getSiteData, 300);
+		});
 		</script>
 		<?php
 	}
 }
 
+function display_sites() {
+	if (get_request_var('filter') != '') {
+		$sql_where = "WHERE name LIKE '%" . get_request_var('filter') . "%'
+			OR city LIKE '%" . get_request_var('filter') . "%'
+			OR state LIKE '%" . get_request_var('filter') . "%'
+			OR country LIKE '%" . get_request_var('filter') . "%'";
+	} else {
+		$sql_where = '';
+	}
+
+	$sites = db_fetch_assoc("SELECT * FROM sites $sql_where");
+
+	if (cacti_sizeof($sites)) {
+		foreach($sites as $s) {
+			print "<ul><li id='tsite:" . $s['id'] . "' data-jstree='{ \"type\" : \"site\"}'>" . $s['name'] . "</li></ul>\n";
+		}
+	}
+}
+
 function display_hosts() {
 	if (get_request_var('filter') != '') {
 		$sql_where = "h.hostname LIKE '%" . get_request_var('filter') . "%' OR h.description LIKE '%" . get_request_var('filter') . "%'";
@@ -1530,9 +1750,9 @@ function display_hosts() {
 
 	$hosts = get_allowed_devices($sql_where, 'description', '20');
 
-	if (sizeof($hosts)) {
+	if (cacti_sizeof($hosts)) {
 		foreach($hosts as $h) {
-			echo "<ul><li id='thost:" . $h['id'] . "' data-jstree='{ \"type\" : \"device\"}'>" . $h['description'] . ' (' . $h['hostname'] . ')' . "</li></ul>\n";
+			print "<ul><li id='thost:" . $h['id'] . "' data-jstree='{ \"type\" : \"device\"}'>" . $h['description'] . ' (' . $h['hostname'] . ')' . "</li></ul>\n";
 		}
 	}
 }
@@ -1555,10 +1775,10 @@ function display_graphs() {
 		ORDER BY title_cache
 		LIMIT 20");
 
-	if (sizeof($graphs)) {
+	if (cacti_sizeof($graphs)) {
 		foreach($graphs as $g) {
 			if (is_graph_allowed($g['id'])) {
-				echo "<ul><li id='tgraph:" . $g['id'] . "' data-jstree='{ \"type\": \"graph\" }'>" . $g['title'] . '</li></ul>';
+				print "<ul><li id='tgraph:" . $g['id'] . "' data-jstree='{ \"type\": \"graph\" }'>" . html_escape($g['title']) . '</li></ul>';
 			}
 		}
 	}
@@ -1657,13 +1877,13 @@ function tree() {
 			'href'     => 'tree.php?action=sortasc',
 			'callback' => true,
 			'title'    => __esc('Sort Trees Ascending'),
-			'class'    => 'fa fa-sort-alpha-asc'
+			'class'    => 'fa fa-sort-alpha-down'
 		),
 		array(
 			'href'     => 'tree.php?action=sortdesc',
 			'callback' => true,
 			'title'    => __esc('Sort Trees Descending'),
-			'class'    => 'fa fa-sort-alpha-desc'
+			'class'    => 'fa fa-sort-alpha-up'
 		)
 	);
 
@@ -1679,7 +1899,7 @@ function tree() {
 						<?php print __('Search'); ?>
 					</td>
 					<td>
-						<input id='filter' type='text' size='25' value='<?php print html_escape_request_var('filter');?>'>
+						<input type='text' class='ui-state-default ui-corner-all' id='filter' size='25' value='<?php print html_escape_request_var('filter');?>'>
 					</td>
 					<td>
 						<?php print __('Trees'); ?>
@@ -1688,9 +1908,9 @@ function tree() {
 						<select id='rows' onChange='applyFilter()'>
 							<option value='-1'<?php print (get_request_var('rows') == '-1' ? ' selected>':'>') . __('Default');?></option>
 							<?php
-							if (sizeof($item_rows)) {
+							if (cacti_sizeof($item_rows)) {
 								foreach ($item_rows as $key => $value) {
-									print "<option value='" . $key . "'"; if (get_request_var('rows') == $key) { print ' selected'; } print '>' . htmlspecialchars($value) . "</option>\n";
+									print "<option value='" . $key . "'"; if (get_request_var('rows') == $key) { print ' selected'; } print '>' . html_escape($value) . "</option>\n";
 								}
 							}
 							?>
@@ -1698,10 +1918,10 @@ function tree() {
 					</td>
 					<td>
 						<span>
-							<input type='button' id='refresh' value='<?php print __esc('Go');?>' title='<?php print __esc('Set/Refresh Filters');?>'>
-							<input type='button' id='clear' value='<?php print __esc('Clear');?>' title='<?php print __esc('Clear Filters');?>'>
-							<button type='button' id='sorta' title='<?php print __esc('Sort Trees Ascending');?>'><i class='fa fa-sort-alpha-asc'></i></button>
-							<button type='button' id='sortd' title='<?php print __esc('Sort Trees Descending');?>'><i class='fa fa-sort-alpha-desc'></i></button>
+							<input type='button' class='ui-button ui-corner-all ui-widget' id='refresh' value='<?php print __esc('Go');?>' title='<?php print __esc('Set/Refresh Filters');?>'>
+							<input type='button' class='ui-button ui-corner-all ui-widget' id='clear' value='<?php print __esc('Clear');?>' title='<?php print __esc('Clear Filters');?>'>
+							<button type='button' class='ui-button ui-corner-all ui-widget' id='sorta' title='<?php print __esc('Sort Trees Ascending');?>'><i class='fa fa-sort-alpha-down'></i></button>
+							<button type='button' class='ui-button ui-corner-all ui-widget' id='sortd' title='<?php print __esc('Sort Trees Descending');?>'><i class='fa fa-sort-alpha-up'></i></button>
 						</span>
 					</td>
 				</tr>
@@ -1724,9 +1944,10 @@ function tree() {
 	$sql_limit = ' LIMIT ' . ($rows*(get_request_var('page')-1)) . ',' . $rows;
 
 	$trees = db_fetch_assoc("SELECT t.*,
-		SUM(CASE WHEN ti.host_id>0 THEN 1 ELSE 0 END) AS hosts,
-		SUM(CASE WHEN ti.local_graph_id>0 THEN 1 ELSE 0 END) AS graphs,
-		SUM(CASE WHEN ti.local_graph_id=0 AND host_id=0 THEN 1 ELSE 0 END) AS branches
+		SUM(CASE WHEN ti.host_id > 0 THEN 1 ELSE 0 END) AS hosts,
+		SUM(CASE WHEN ti.local_graph_id > 0 THEN 1 ELSE 0 END) AS graphs,
+		SUM(CASE WHEN ti.local_graph_id = 0 AND host_id = 0 AND site_id = 0 THEN 1 ELSE 0 END) AS branches,
+		SUM(CASE WHEN ti.site_id > 0 THEN 1 ELSE 0 END) AS sites
 		FROM graph_tree AS t
 		LEFT JOIN graph_tree_items AS ti
 		ON t.id=ti.graph_tree_id
@@ -1758,6 +1979,7 @@ function tree() {
 		'sequence' => array('display' => __('Order'), 'align' => 'center', 'sort' => 'ASC', 'tip' => __('To change the order of the trees, first sort by this column, press the up or down arrows once they appear.')),
 		'last_modified' => array('display' => __('Last Edited'), 'align' => 'right', 'sort' => 'ASC', 'tip' => __('The date that this Tree was last edited.')),
 		'modified_by' => array('display' => __('Edited By'), 'align' => 'right', 'sort' => 'ASC', 'tip' => __('The last user to have modified this Tree.')),
+		'sites' => array('display' => __('Sites'), 'align' => 'right', 'sort' => 'DESC', 'tip' => __('The total number of Site Branches in this Tree.')),
 		'branches' => array('display' => __('Branches'), 'align' => 'right', 'sort' => 'DESC', 'tip' => __('The total number of Branches in this Tree.')),
 		'hosts' => array('display' => __('Devices'), 'align' => 'right', 'sort' => 'DESC', 'tip' => __('The total number of individual Devices in this Tree.')),
 		'graphs' => array('display' => __('Graphs'), 'align' => 'right', 'sort' => 'DESC', 'tip' => __('The total number of individual Graphs in this Tree.')));
@@ -1765,38 +1987,39 @@ function tree() {
 	html_header_sort_checkbox($display_text, get_request_var('sort_column'), get_request_var('sort_direction'), false);
 
 	$i = 1;
-	if (sizeof($trees)) {
+	if (cacti_sizeof($trees)) {
 		foreach ($trees as $tree) {
 			$sequence = '';
 			if (get_request_var('sort_column') == 'sequence' && get_request_var('sort_direction') == 'ASC') {
-				if ($i == 1 && sizeof($trees) == 1) {
+				if ($i == 1 && cacti_sizeof($trees) == 1) {
 					$sequence .= '<span class="moveArrowNone"></span>';
 					$sequence .= '<span class="moveArrowNone"></span>';
 				} elseif ($i == 1) {
 					$sequence .= '<a class="pic fa fa-caret-down moveArrow" href="' . htmlspecialchars('tree.php?action=tree_down&id=' . $tree['id']) . '" title="' . __esc('Move Down') . '"></a>';
 					$sequence .= '<span class="moveArrowNone"></span>';
-				} elseif ($i == sizeof($trees)) {
+				} elseif ($i == cacti_sizeof($trees)) {
 					$sequence .= '<span class="moveArrowNone"></span>';
-					$sequence .= '<a class="pic fa fa-caret-up moveArrow" href="' . htmlspecialchars('tree.php?action=tree_up&id=' . $tree['id']) . '" title="' . __esc('Move Up') . '"></a>';
+					$sequence .= '<a class="pic fa fa-caret-up moveArrow" href="' . html_escape('tree.php?action=tree_up&id=' . $tree['id']) . '" title="' . __esc('Move Up') . '"></a>';
 
 				} else {
-					$sequence .= '<a class="pic fa fa-caret-down moveArrow" href="' . htmlspecialchars('tree.php?action=tree_down&id=' . $tree['id']) . '" title="' . __esc('Move Down') . '"></a>';
-					$sequence .= '<a class="pic fa fa-caret-up moveArrow" href="' . htmlspecialchars('tree.php?action=tree_up&id=' . $tree['id']) . '" title="' . __esc('Move Up') . '"></a>';
+					$sequence .= '<a class="pic fa fa-caret-down moveArrow" href="' . html_escape('tree.php?action=tree_down&id=' . $tree['id']) . '" title="' . __esc('Move Down') . '"></a>';
+					$sequence .= '<a class="pic fa fa-caret-up moveArrow" href="' . html_escape('tree.php?action=tree_up&id=' . $tree['id']) . '" title="' . __esc('Move Up') . '"></a>';
 				}
 			}
 
 			form_alternate_row('line' . $tree['id'], true);
 			form_selectable_cell(filter_value($tree['name'], get_request_var('filter'), 'tree.php?action=edit&id=' . $tree['id']), $tree['id']);
-			form_selectable_cell($tree['id'], $tree['id'], '', 'text-align:right');
+			form_selectable_cell($tree['id'], $tree['id'], '', 'right');
 			form_selectable_cell($tree['enabled'] == 'on' ? __('Yes'):__('No'), $tree['id']);
 			form_selectable_cell($tree['locked'] == '1' ? __('Yes'):__('No'), $tree['id']);
 			form_selectable_cell(get_username($tree['user_id']), $tree['id']);
 			form_selectable_cell($sequence, $tree['id'], '', 'nowrap center');
-			form_selectable_cell(substr($tree['last_modified'],0,16), $tree['id'], '', 'text-align:right');
-			form_selectable_cell(get_username($tree['modified_by']), $tree['id'], '', 'text-align:right');
-			form_selectable_cell($tree['branches'] > 0 ? number_format_i18n($tree['branches'], '-1'):'-', $tree['id'], '', 'text-align:right');
-			form_selectable_cell($tree['hosts'] > 0 ? number_format_i18n($tree['hosts'], '-1'):'-', $tree['id'], '', 'text-align:right');
-			form_selectable_cell($tree['graphs'] > 0 ? number_format_i18n($tree['graphs'], '-1'):'-', $tree['id'], '', 'text-align:right');
+			form_selectable_cell(substr($tree['last_modified'],0,16), $tree['id'], '', 'right');
+			form_selectable_cell(get_username($tree['modified_by']), $tree['id'], '', 'right');
+			form_selectable_cell($tree['sites'] > 0 ? number_format_i18n($tree['sites'], '-1'):'-', $tree['id'], '', 'right');
+			form_selectable_cell($tree['branches'] > 0 ? number_format_i18n($tree['branches'], '-1'):'-', $tree['id'], '', 'right');
+			form_selectable_cell($tree['hosts'] > 0 ? number_format_i18n($tree['hosts'], '-1'):'-', $tree['id'], '', 'right');
+			form_selectable_cell($tree['graphs'] > 0 ? number_format_i18n($tree['graphs'], '-1'):'-', $tree['id'], '', 'right');
 			form_checkbox_cell($tree['name'], $tree['id']);
 			form_end_row();
 
@@ -1807,7 +2030,7 @@ function tree() {
 	}
 	html_end_box(false);
 
-	if (sizeof($trees)) {
+	if (cacti_sizeof($trees)) {
 		print $nav;
 	}
 
